@@ -77,8 +77,7 @@ sub new {
     $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
     $Self->{DFBackendObject}    = Kernel::System::DynamicField::Backend->new(%Param);
     $Self->{CommonObject}       = Kernel::GenericInterface::Operation::Common->new( %{$Self} );
-    $Self->{TicketCommonObject}
-        = Kernel::GenericInterface::Operation::Ticket::Common->new( %{$Self} );
+    $Self->{TicketCommonObject} = Kernel::GenericInterface::Operation::Ticket::Common->new( %{$Self} );
 
     $Self->{Config} = $Self->{ConfigObject}->Get('GenericInterface::Operation::TicketUpdate');
 
@@ -253,8 +252,10 @@ sub Run {
         );
     }
 
+    my $PermissionUserID = $UserID;
+
     if ( $UserType eq 'Customer' ) {
-        $UserID = $Self->{ConfigObject}->Get('CustomerPanelUserID')
+        $UserID = $Self->{ConfigObject}->Get('CustomerPanelUserID');
     }
 
     # check TicketID
@@ -291,10 +292,10 @@ sub Run {
     }
 
     # check basic needed permissions
-    my $Access = $Self->{TicketObject}->TicketPermission(
-        Type     => 'ro',
+    my $Access = $Self->{TicketCommonObject}->CheckAccessPermissions(
         TicketID => $TicketID,
-        UserID   => $UserID
+        UserID   => $PermissionUserID,
+        UserType => $UserType,
     );
 
     if ( !$Access ) {
@@ -419,7 +420,7 @@ sub Run {
             $Article->{ArticleType} = $Self->{Config}->{ArticleType} || '';
         }
         if ( !$Article->{SenderTypeID} && !$Article->{SenderType} ) {
-            $Article->{SenderType} = $UserType eq 'Agent' ? 'agent' : 'customer';
+            $Article->{SenderType} = $UserType eq 'User' ? 'agent' : 'customer';
         }
         if ( !$Article->{HistoryType} ) {
             $Article->{HistoryType} = $Self->{Config}->{HistoryType} || '';
@@ -1876,8 +1877,7 @@ sub _TicketUpdate {
 
             # use data from customer user (if customer user is in database)
             if ( IsHashRefWithData( \%CustomerUserData ) ) {
-                $From
-                    = '"'
+                $From = '"'
                     . $CustomerUserData{UserFirstname} . ' '
                     . $CustomerUserData{UserLastname} . '"'
                     . ' <' . $CustomerUserData{UserEmail} . '>';
