@@ -77,12 +77,11 @@ sub new {
         LogPrefix => 'GenericInterfaceProvider',
         %{$Self},
     );
-    $Self->{EncodeObject} = Kernel::System::Encode->new( %{$Self} );
-    $Self->{MainObject}   = Kernel::System::Main->new( %{$Self} );
-    $Self->{TimeObject}   = Kernel::System::Time->new( %{$Self} );
-    $Self->{DBObject}     = Kernel::System::DB->new( %{$Self} );
-    $Self->{WebserviceObject}
-        = Kernel::System::GenericInterface::Webservice->new( %{$Self} );
+    $Self->{EncodeObject}     = Kernel::System::Encode->new( %{$Self} );
+    $Self->{MainObject}       = Kernel::System::Main->new( %{$Self} );
+    $Self->{TimeObject}       = Kernel::System::Time->new( %{$Self} );
+    $Self->{DBObject}         = Kernel::System::DB->new( %{$Self} );
+    $Self->{WebserviceObject} = Kernel::System::GenericInterface::Webservice->new( %{$Self} );
 
     return $Self;
 }
@@ -110,8 +109,7 @@ sub Run {
     # on Microsoft IIS 7.0, $ENV{REQUEST_URI} is not set. See bug#9172.
     my $RequestURI = $ENV{REQUEST_URI} || $ENV{PATH_INFO};
 
-    my ($WebserviceID)
-        = $RequestURI =~ m{ nph-genericinterface[.]pl [/] WebserviceID [/] (\d+) }smx;
+    my ($WebserviceID) = $RequestURI =~ m{ nph-genericinterface[.]pl [/] WebserviceID [/] (\d+) }smx;
 
     if ($WebserviceID) {
 
@@ -122,8 +120,7 @@ sub Run {
     }
     else {
 
-        my ($WebserviceName)
-            = $RequestURI =~ m{ nph-genericinterface[.]pl [/] Webservice [/] ([^/?]+) }smx;
+        my ($WebserviceName) = $RequestURI =~ m{ nph-genericinterface[.]pl [/] Webservice [/] ([^/?]+) }smx;
 
         if ( !$WebserviceName ) {
             $Self->{LogObject}->Log(
