@@ -35,8 +35,7 @@ sub new {
     $Self->{WebserviceObject} =
         Kernel::System::GenericInterface::Webservice->new( %{$Self} );
 
-    $Self->{DeletedString}
-        = '_GenericInterface_Mapping_Simple_DeletedString_Dont_Use_It_String_Please';
+    $Self->{DeletedString} = '_GenericInterface_Mapping_Simple_DeletedString_Dont_Use_It_String_Please';
 
     return $Self;
 }
@@ -58,14 +57,12 @@ sub Run {
     my $Action = $Operation || $Invoker;
 
     # set mapping direction for display
-    my $MappingDirection
-        = $Direction eq 'MappingOutbound'
+    my $MappingDirection = $Direction eq 'MappingOutbound'
         ? 'Simple Mapping for Outgoing Data'
         : 'Simple Mapping for Incoming Data';
 
     # get configured Actions
-    my $ActionsConfig
-        = $Self->{ConfigObject}->Get( 'GenericInterface::' . $ActionType . '::Module' );
+    my $ActionsConfig = $Self->{ConfigObject}->Get( 'GenericInterface::' . $ActionType . '::Module' );
 
     # check for valid action backend
     if ( !IsHashRefWithData($ActionsConfig) ) {
@@ -93,8 +90,7 @@ sub Run {
     }
 
     # get the action type (back-end)
-    my $ActionBackend
-        = $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}->{$Action}->{'Type'};
+    my $ActionBackend = $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}->{$Action}->{'Type'};
 
     # check for valid action backend
     if ( !$ActionBackend ) {
@@ -143,13 +139,11 @@ sub Run {
                         )
                     {
                         $ValueIndex++;
-                        my $NewVal
-                            = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName},
+                        my $NewVal = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName},
 
                             $Mapping{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } = $ValueName;
-                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex } = $NewVal;
-                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex }
-                            = $ValueMapType;
+                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex }      = $NewVal;
+                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex } = $ValueMapType;
 
                     }
                 }
@@ -221,8 +215,7 @@ sub Run {
 
         for my $KeyCounter ( 1 .. $GetParam->{KeyCounter} ) {
             $NewMapping{ $GetParam->{ 'KeyMapTypeStrg' . $KeyCounter } }
-                ->{ $GetParam->{ 'KeyName' . $KeyCounter } }
-                =
+                ->{ $GetParam->{ 'KeyName' . $KeyCounter } } =
                 $GetParam->{ 'KeyMapNew' . $KeyCounter };
 
             for my $ValueCounter ( 1 .. $GetParam->{ 'ValueCounter' . $KeyCounter } ) {
@@ -235,8 +228,7 @@ sub Run {
 
         # set new mapping
         $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}->{$Action}->{$Direction}
-            ->{Config}
-            = \%NewMapping;
+            ->{Config} = \%NewMapping;
 
         # otherwise save configuration and return to overview screen
         my $Success = $Self->{WebserviceObject}->WebserviceUpdate(
@@ -256,8 +248,7 @@ sub Run {
 
         # save and finish button: go to Webservice.
         if ( $Self->{ParamObject}->GetParam( Param => 'ReturnToAction' ) ) {
-            my $RedirectURL
-                = "Action=$ActionFrontendModule;Subaction=Change;$ActionType=$Action;"
+            my $RedirectURL = "Action=$ActionFrontendModule;Subaction=Change;$ActionType=$Action;"
                 . "WebserviceID=$WebserviceID;";
 
             return $Self->{LayoutObject}->Redirect(
@@ -295,13 +286,11 @@ sub Run {
                         )
                     {
                         $ValueIndex++;
-                        my $NewVal
-                            = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName},
+                        my $NewVal = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName},
 
                             $Mapping{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } = $ValueName;
-                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex } = $NewVal;
-                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex }
-                            = $ValueMapType;
+                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex }      = $NewVal;
+                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex } = $ValueMapType;
 
                     }
                 }
@@ -521,9 +510,9 @@ sub _ShowEdit {
             $Self->{LayoutObject}->Block(
                 Name => 'ValueTemplateRow',
                 Data => {
-                    KeyIndex   => $KeyIndex,
-                    ValueIndex => $ValueIndex,
-                    ValueName  => $MappingConfig->{ 'ValueName' . $KeyIndex . '_' . $ValueIndex },
+                    KeyIndex       => $KeyIndex,
+                    ValueIndex     => $ValueIndex,
+                    ValueName      => $MappingConfig->{ 'ValueName' . $KeyIndex . '_' . $ValueIndex },
                     ValueNameError => $Error{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } || '',
                     ValueMapNew =>
                         $MappingConfig->{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex },
@@ -602,7 +591,9 @@ sub _GetParams {
         next if !$Self->{ParamObject}->GetParam( Param => 'KeyIndex' . $KeyCounter );
         $KeyIndex++;
         for my $KeyItem (qw(KeyMapTypeStrg KeyName KeyMapNew ValueCounter)) {
-            my $KeyAux = $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter ) || '';
+            my $KeyAux = defined $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter )
+                ? $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter )
+                : '';
             $GetParam->{ $KeyItem . $KeyIndex } = $KeyAux;
             if ( $KeyItem eq 'ValueCounter' && $KeyAux eq '' ) {
                 $GetParam->{ $KeyItem . $KeyIndex } = 0;
@@ -621,8 +612,7 @@ sub _GetParams {
                 $Self->{DeletedString};
             $ValueIndex++;
             for my $ValueItem (qw(ValueMapTypeStrg ValueName ValueMapNew)) {
-                my $ValAux
-                    = defined $Self->{ParamObject}->GetParam( Param => $ValueItem . $Suffix )
+                my $ValAux = defined $Self->{ParamObject}->GetParam( Param => $ValueItem . $Suffix )
                     ? $Self->{ParamObject}->GetParam( Param => $ValueItem . $Suffix )
                     : '';
                 $GetParam->{ $ValueItem . $KeyIndex . '_' . $ValueIndex } = $ValAux;
