@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminNotificationEvent.pm - to manage event-based notifications
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminNotificationEvent.pm,v 1.43 2012/11/20 14:39:44 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,9 +24,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.43 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -396,16 +391,16 @@ sub _Edit {
         SelectedID => $Param{Data}->{RecipientAgents},
     );
     $Param{RecipientGroupsStrg} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{GroupObject}->GroupList( Valid => 1 ) },
-        Size => 6,
-        Name => 'RecipientGroups',
+        Data       => { $Self->{GroupObject}->GroupList( Valid => 1 ) },
+        Size       => 6,
+        Name       => 'RecipientGroups',
         Multiple   => 1,
         SelectedID => $Param{Data}->{RecipientGroups},
     );
     $Param{RecipientRolesStrg} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{GroupObject}->RoleList( Valid => 1 ) },
-        Size => 6,
-        Name => 'RecipientRoles',
+        Data       => { $Self->{GroupObject}->RoleList( Valid => 1 ) },
+        Size       => 6,
+        Name       => 'RecipientRoles',
         Multiple   => 1,
         SelectedID => $Param{Data}->{RecipientRoles},
     );
@@ -543,7 +538,9 @@ sub _Edit {
 
     # build type string
     if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
-        my %Type = $Self->{TypeObject}->TypeList( UserID => $Self->{UserID}, );
+        my %Type = $Self->{TypeObject}->TypeList(
+            UserID => $Self->{UserID},
+        );
         $Param{TypesStrg} = $Self->{LayoutObject}->BuildSelection(
             Data        => \%Type,
             Name        => 'TypeID',
@@ -563,7 +560,11 @@ sub _Edit {
     if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
 
         # get list type
-        my %Service = $Self->{ServiceObject}->ServiceList( UserID => $Self->{UserID}, );
+        my %Service = $Self->{ServiceObject}->ServiceList(
+            Valid        => 1,
+            KeepChildren => 1,
+            UserID       => $Self->{UserID},
+        );
         $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
             Data        => \%Service,
             Name        => 'ServiceID',
@@ -572,8 +573,11 @@ sub _Edit {
             Multiple    => 1,
             Translation => 0,
             Max         => 200,
+            TreeView    => 1,
+        );
+        my %SLA = $Self->{SLAObject}->SLAList(
+            UserID => $Self->{UserID},
         );
-        my %SLA = $Self->{SLAObject}->SLAList( UserID => $Self->{UserID}, );
         $Param{SLAsStrg} = $Self->{LayoutObject}->BuildSelection(
             Data        => \%SLA,
             Name        => 'SLAID',
@@ -630,8 +634,8 @@ sub _Edit {
     }
 
     $Param{ArticleTypesStrg} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{TicketObject}->ArticleTypeList( Result => 'HASH' ), },
-        Name => 'ArticleTypeID',
+        Data        => { $Self->{TicketObject}->ArticleTypeList( Result => 'HASH' ), },
+        Name        => 'ArticleTypeID',
         SelectedID  => $Param{Data}->{ArticleTypeID},
         Size        => 5,
         Multiple    => 1,
@@ -640,8 +644,8 @@ sub _Edit {
     );
 
     $Param{ArticleSenderTypesStrg} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{TicketObject}->ArticleSenderTypeList( Result => 'HASH' ), },
-        Name => 'ArticleSenderTypeID',
+        Data        => { $Self->{TicketObject}->ArticleSenderTypeList( Result => 'HASH' ), },
+        Name        => 'ArticleSenderTypeID',
         SelectedID  => $Param{Data}->{ArticleSenderTypeID},
         Size        => 5,
         Multiple    => 1,
@@ -710,7 +714,9 @@ sub _Overview {
         my %ValidList = $Self->{ValidObject}->ValidList();
         for ( sort { $List{$a} cmp $List{$b} } keys %List ) {
 
-            my %Data = $Self->{NotificationEventObject}->NotificationGet( ID => $_, );
+            my %Data = $Self->{NotificationEventObject}->NotificationGet(
+                ID => $_,
+            );
             $Self->{LayoutObject}->Block(
                 Name => 'OverviewResultRow',
                 Data => {
