@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminPackageManager.pm - manage software packages
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminPackageManager.pm,v 1.98 2011/01/30 09:49:39 mb Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,11 +12,11 @@ package Kernel::Modules::AdminPackageManager;
 use strict;
 use warnings;
 
+use XML::FeedPP;
+
 use Kernel::System::Package;
 use Kernel::System::Web::UploadCache;
-
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.98 $) [1];
+use Kernel::System::Cache;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -36,6 +34,7 @@ sub new {
 
     $Self->{PackageObject}     = Kernel::System::Package->new(%Param);
     $Self->{UploadCacheObject} = Kernel::System::Web::UploadCache->new(%Param);
+    $Self->{CacheObject}       = Kernel::System::Cache->new(%Param);
 
     return $Self;
 }
@@ -49,13 +48,14 @@ sub Run {
     # ------------------------------------------------------------ #
     # check mod perl version and Apache::Reload
     # ------------------------------------------------------------ #
+
     if ( exists $ENV{MOD_PERL} ) {
-        if ( defined $mod_perl::VERSION ) {
-            if ( $mod_perl::VERSION >= 1.99 ) {
+        if ( defined $mod_perl::VERSION ) {    ## no critic
+            if ( $mod_perl::VERSION >= 1.99 ) {    ## no critic
 
                 # check if Apache::Reload is loaded
                 my $ApacheReload = 0;
-                for my $Module ( keys %INC ) {
+                for my $Module ( sort keys %INC ) {
                     $Module =~ s/\//::/g;
                     $Module =~ s/\.pm$//g;
                     if ( $Module eq 'Apache::Reload' || $Module eq 'Apache2::Reload' ) {
@@ -76,7 +76,7 @@ sub Run {
         }
     }
 
-    # secure mode message (don't allow this action untill secure mode is enabled)
+    # secure mode message (don't allow this action until secure mode is enabled)
     if ( !$Self->{ConfigObject}->Get('SecureMode') ) {
         $Self->{LayoutObject}->SecureMode();
     }
@@ -100,9 +100,6 @@ sub Run {
         }
         my %Structure = $Self->{PackageObject}->PackageParse( String => $Package );
         my $File = '';
-        if ( !$Location ) {
-
-        }
         if ( ref $Structure{Filelist} eq 'ARRAY' ) {
             for my $Hash ( @{ $Structure{Filelist} } ) {
                 if ( $Hash->{Location} eq $Location ) {
@@ -111,14 +108,28 @@ sub Run {
             }
         }
         my $LocalFile = $Self->{ConfigObject}->Get('Home') . "/$Location";
-        if ( !-e $LocalFile ) {
+
+        # do not allow to read file with including .. path (security related)
+        $LocalFile =~ s/\.\.//g;
+        if ( !$File ) {
             $Self->{LayoutObject}->Block(
                 Name => 'FileDiff',
                 Data => {
                     Location => $Location,
                     Name     => $Name,
                     Version  => $Version,
-                    Diff     => "No such file $LocalFile!",
+                    Diff     => "No such file $LocalFile in package!",
+                },
+            );
+        }
+        elsif ( !-e $LocalFile ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'FileDiff',
+                Data => {
+                    Location => $Location,
+                    Name     => $Name,
+                    Version  => $Version,
+                    Diff     => "No such file $LocalFile in local file system!",
                 },
             );
         }
@@ -187,9 +198,16 @@ sub Run {
         my $Verified = $Self->{PackageObject}->PackageVerify(
             Package   => $Package,
             Structure => \%Structure,
-        );
+        ) || 'verified';
         my %VerifyInfo = $Self->{PackageObject}->PackageVerifyInfo();
 
+        # translate description
+        if ( $Self->{LayoutObject}->{LanguageObject} ) {
+            $VerifyInfo{Description} = $Self->{LayoutObject}->{LanguageObject}->Get(
+                $VerifyInfo{Description}
+            );
+        }
+
         # deploy check
         my $Deployed = $Self->{PackageObject}->DeployCheck(
             Name    => $Name,
@@ -198,7 +216,11 @@ sub Run {
         my %DeployInfo = $Self->{PackageObject}->DeployCheckInfo();
         $Self->{LayoutObject}->Block(
             Name => 'Package',
-            Data => { %Param, %Frontend, Name => $Name, Version => $Version, },
+            Data => {
+                %Param, %Frontend,
+                Name    => $Name,
+                Version => $Version,
+            },
         );
         for my $PackageAction (qw(DownloadLocal Rebuild Reinstall)) {
             $Self->{LayoutObject}->Block(
@@ -232,7 +254,10 @@ sub Run {
                 if ( $Key =~ /^(Description|Filelist)$/ ) {
                     $Self->{LayoutObject}->Block(
                         Name => "PackageItem$Key",
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
                 elsif ( $Key =~ /^Database(Install|Reinstall|Upgrade|Uninstall)$/ ) {
@@ -242,14 +267,21 @@ sub Run {
                                 if ( $Hash->{Tag} =~ /^Table/ ) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabase",
-                                        Data => { %{$Hash}, TagName => $Key, Type => $Type },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                            Type    => $Type
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
                                 else {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSub",
-                                        Data => { %{$Hash}, TagName => $Key, },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
@@ -264,7 +296,10 @@ sub Run {
                                 for my $SQL (@SQL) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSQL",
-                                        Data => { TagName => $Key, SQL => $SQL, },
+                                        Data => {
+                                            TagName => $Key,
+                                            SQL     => $SQL,
+                                        },
                                     );
                                 }
                                 @DatabaseBuffer = ();
@@ -275,7 +310,10 @@ sub Run {
                 else {
                     $Self->{LayoutObject}->Block(
                         Name => 'PackageItemGeneric',
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
             }
@@ -284,7 +322,10 @@ sub Run {
                     if ( $Key =~ /^(Description|ChangeLog)$/ ) {
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItem$Key",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Key =~ /^Code/ ) {
@@ -295,17 +336,22 @@ sub Run {
                         );
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemCode",
-                            Data => { Tag => $Key, %{$Hash} },
+                            Data => {
+                                Tag => $Key,
+                                %{$Hash}
+                            },
                         );
                     }
                     elsif ( $Key =~ /^(Intro)/ ) {
                         if ( $Hash->{Format} && $Hash->{Format} =~ /plain/i ) {
-                            $Hash->{Content}
-                                = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
+                            $Hash->{Content} = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
                         }
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemIntro",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Hash->{Tag} =~ /^(File)$/ ) {
@@ -375,7 +421,10 @@ sub Run {
                     else {
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemGeneric",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                 }
@@ -394,18 +443,16 @@ sub Run {
                     . $Version,
             );
         }
-        if ( !$Verified ) {
-            my %VerifyInfo = $Self->{PackageObject}->DeployCheckInfo();
+
+        if ( $Verified ne 'verified' ) {
+
             $Output .= $Self->{LayoutObject}->Notify(
                 Priority => 'Error',
-                Data =>
-                    '$Text{"Package verification failed!"} $Text{"For more info see:"} http://otrs.org/verify/',
-                Link => 'http://otrs.org/verify?Name'
-                    . $Name
-                    . ';Version='
-                    . $Version,
+                Data     => "$Name $Version - "
+                    . '$Text{"Package not verified by the OTRS Group! It is recommended not to use this package."}',
             );
         }
+
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminPackageManager',
         );
@@ -436,7 +483,10 @@ sub Run {
         );
         $Self->{LayoutObject}->Block(
             Name => 'PackageDownloadRemote',
-            Data => { %Param, %Frontend, File => $File, },
+            Data => {
+                %Param, %Frontend,
+                File => $File,
+            },
         );
 
         # check if file is requested
@@ -459,7 +509,10 @@ sub Run {
                 if ( $Key =~ /^(Description|Filelist)$/ ) {
                     $Self->{LayoutObject}->Block(
                         Name => "PackageItem$Key",
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
                 elsif ( $Key =~ /^Database(Install|Reinstall|Upgrade|Uninstall)$/ ) {
@@ -469,14 +522,21 @@ sub Run {
                                 if ( $Hash->{Tag} =~ /^Table/ ) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabase",
-                                        Data => { %{$Hash}, TagName => $Key, Type => $Type },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                            Type    => $Type
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
                                 else {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSub",
-                                        Data => { %{$Hash}, TagName => $Key, },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
@@ -491,7 +551,10 @@ sub Run {
                                 for my $SQL (@SQL) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSQL",
-                                        Data => { TagName => $Key, SQL => $SQL, },
+                                        Data => {
+                                            TagName => $Key,
+                                            SQL     => $SQL,
+                                        },
                                     );
                                 }
                                 @DatabaseBuffer = ();
@@ -502,7 +565,10 @@ sub Run {
                 else {
                     $Self->{LayoutObject}->Block(
                         Name => 'PackageItemGeneric',
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
             }
@@ -511,7 +577,10 @@ sub Run {
                     if ( $Key =~ /^(Description|ChangeLog)$/ ) {
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItem$Key",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Key =~ /^Code/ ) {
@@ -522,17 +591,22 @@ sub Run {
                         );
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemCode",
-                            Data => { Tag => $Key, %{$Hash} },
+                            Data => {
+                                Tag => $Key,
+                                %{$Hash}
+                            },
                         );
                     }
                     elsif ( $Key =~ /^(Intro)/ ) {
                         if ( $Hash->{Format} && $Hash->{Format} =~ /plain/i ) {
-                            $Hash->{Content}
-                                = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
+                            $Hash->{Content} = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
                         }
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemIntro",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Hash->{Tag} =~ /^(File)$/ ) {
@@ -565,7 +639,10 @@ sub Run {
                     else {
                         $Self->{LayoutObject}->Block(
                             Name => 'PackageItemGeneric',
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                 }
@@ -631,6 +708,10 @@ sub Run {
     # change repository
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ChangeRepository' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Source = $Self->{ParamObject}->GetParam( Param => 'Source' ) || '';
         $Self->{SessionObject}->UpdateSessionID(
             SessionID => $Self->{SessionID},
@@ -644,6 +725,10 @@ sub Run {
     # install package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Install' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
 
@@ -661,6 +746,10 @@ sub Run {
     # install remote package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'InstallRemote' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $File = $Self->{ParamObject}->GetParam( Param => 'File' ) || '';
 
         # download package
@@ -680,6 +769,10 @@ sub Run {
     # upgrade remote package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'UpgradeRemote' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $File = $Self->{ParamObject}->GetParam( Param => 'File' ) || '';
 
         # download package
@@ -699,6 +792,10 @@ sub Run {
     # reinstall package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Reinstall' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
         my $IntroReinstallPre = $Self->{ParamObject}->GetParam( Param => 'IntroReinstallPre' )
@@ -715,12 +812,17 @@ sub Run {
         }
 
         # check if we have to show reinstall intro pre
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # intro screen
         my %Data;
         if ( $Structure{IntroReinstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroReinstall}, Type => 'pre' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroReinstall},
+                Type => 'pre'
+            );
         }
         if ( %Data && !$IntroReinstallPre ) {
             $Self->{LayoutObject}->Block(
@@ -771,6 +873,10 @@ sub Run {
     # reinstall action package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ReinstallAction' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
         my $IntroReinstallPost = $Self->{ParamObject}->GetParam( Param => 'IntroReinstallPost' )
@@ -786,7 +892,9 @@ sub Run {
         }
 
         # check if we have to show reinstall intro pre
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # intro screen
         if ( !$Self->{PackageObject}->PackageReinstall( String => $Package ) ) {
@@ -794,7 +902,10 @@ sub Run {
         }
         my %Data;
         if ( $Structure{IntroReinstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroReinstall}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroReinstall},
+                Type => 'post'
+            );
         }
         if ( %Data && !$IntroReinstallPost ) {
             $Self->{LayoutObject}->Block(
@@ -825,6 +936,10 @@ sub Run {
     # uninstall package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Uninstall' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
         my $IntroUninstallPre = $Self->{ParamObject}->GetParam( Param => 'IntroUninstallPre' )
@@ -841,12 +956,17 @@ sub Run {
         }
 
         # check if we have to show uninstall intro pre
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # intro screen
         my %Data;
         if ( $Structure{IntroUninstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroUninstall}, Type => 'pre' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroUninstall},
+                Type => 'pre'
+            );
         }
         if ( %Data && !$IntroUninstallPre ) {
             $Self->{LayoutObject}->Block(
@@ -896,6 +1016,10 @@ sub Run {
     # uninstall action package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'UninstallAction' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
         my $IntroUninstallPost = $Self->{ParamObject}->GetParam( Param => 'IntroUninstallPost' )
@@ -911,7 +1035,9 @@ sub Run {
         }
 
         # parse package
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # unsinstall the package
         if ( !$Self->{PackageObject}->PackageUninstall( String => $Package ) ) {
@@ -921,7 +1047,10 @@ sub Run {
         # intro screen
         my %Data;
         if ( $Structure{IntroUninstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroUninstall}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroUninstall},
+                Type => 'post'
+            );
         }
         if ( %Data && !$IntroUninstallPost ) {
             my %Data = $Self->_MessageGet( Info => $Structure{IntroUninstallPost} );
@@ -953,6 +1082,10 @@ sub Run {
     # install package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'InstallUpload' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $FormID = $Self->{ParamObject}->GetParam( Param => 'FormID' ) || '';
         my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
             Param  => 'FileUpload',
@@ -986,8 +1119,7 @@ sub Run {
             }
         }
         if ( !%Errors ) {
-            my $Feedback
-                = $Self->{PackageObject}->PackageIsInstalled( String => $UploadStuff{Content} );
+            my $Feedback = $Self->{PackageObject}->PackageIsInstalled( String => $UploadStuff{Content} );
 
             if ($Feedback) {
                 return $Self->_UpgradeHandling(
@@ -1006,6 +1138,10 @@ sub Run {
     # rebuild package
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'RebuildPackage' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Name    = $Self->{ParamObject}->GetParam( Param => 'Name' )    || '';
         my $Version = $Self->{ParamObject}->GetParam( Param => 'Version' ) || '';
 
@@ -1018,7 +1154,9 @@ sub Run {
         if ( !$Package ) {
             return $Self->{LayoutObject}->ErrorScreen( Message => 'No such package!' );
         }
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
         my $File = $Self->{PackageObject}->PackageBuild(%Structure);
         return $Self->{LayoutObject}->Attachment(
             Content     => $File,
@@ -1043,10 +1181,12 @@ sub Run {
         %RepositoryRoot = $Self->{PackageObject}->PackageOnlineRepositories();
     }
     $Frontend{SourceList} = $Self->{LayoutObject}->BuildSelection(
-        Data => { %List, %RepositoryRoot, },
-        Name => 'Source',
-        Max  => 40,
-        SelectedID => $Source,
+        Data        => { %List, %RepositoryRoot, },
+        Name        => 'Source',
+        Max         => 40,
+        Translation => 0,
+        SelectedID  => $Source,
+        Class       => "W100pc",
     );
     $Self->{LayoutObject}->Block(
         Name => 'Overview',
@@ -1058,7 +1198,9 @@ sub Run {
             Lang => $Self->{LayoutObject}->{UserLanguage},
         );
         if ( !@List ) {
-            $OutputNotify .= $Self->{LayoutObject}->Notify( Priority => 'Error', );
+            $OutputNotify .= $Self->{LayoutObject}->Notify(
+                Priority => 'Error',
+            );
             if ( !$OutputNotify ) {
                 $OutputNotify .= $Self->{LayoutObject}->Notify(
                     Priority => 'Info',
@@ -1098,13 +1240,19 @@ sub Run {
             if ( $Data->{Upgrade} ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'ShowRemotePackageUpgrade',
-                    Data => { %{$Data}, Source => $Source, },
+                    Data => {
+                        %{$Data},
+                        Source => $Source,
+                    },
                 );
             }
             elsif ( !$Data->{Installed} ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'ShowRemotePackageInstall',
-                    Data => { %{$Data}, Source => $Source, },
+                    Data => {
+                        %{$Data},
+                        Source => $Source,
+                    },
                 );
             }
         }
@@ -1118,15 +1266,23 @@ sub Run {
         );
     }
 
+    my @RepositoryList = $Self->{PackageObject}->RepositoryList();
+
     # if there are no local packages to show, a msg is displayed
-    if ( !$Self->{PackageObject}->RepositoryList() ) {
+    if ( !@RepositoryList ) {
         $Self->{LayoutObject}->Block(
             Name => 'NoDataFoundMsg2',
-            Data => {},
         );
     }
 
-    for my $Package ( $Self->{PackageObject}->RepositoryList() ) {
+    # verify packages if we have some
+    my %VerificationData;
+    if (@RepositoryList) {
+        %VerificationData = $Self->{PackageObject}->PackageVerifyAll();
+    }
+
+    my %NotVerifiedPackages;
+    for my $Package (@RepositoryList) {
 
         my %Data = $Self->_MessageGet( Info => $Package->{Description} );
 
@@ -1142,6 +1298,16 @@ sub Run {
             },
         );
 
+        if (
+            $VerificationData{ $Package->{Name}->{Content} }
+            && $VerificationData{ $Package->{Name}->{Content} } eq 'verified'
+            )
+        {
+            $Self->{LayoutObject}->Block(
+                Name => 'ShowLocalPackageVerifyLogo',
+            );
+        }
+
         # show documentation link
         my %DocFile = $Self->_DocumentationGet( Filelist => $Package->{Filelist} );
         if (%DocFile) {
@@ -1198,6 +1364,14 @@ sub Run {
                 },
             );
         }
+
+        if (
+            $VerificationData{ $Package->{Name}->{Content} }
+            && $VerificationData{ $Package->{Name}->{Content} } eq 'not_verified'
+            )
+        {
+            $NotVerifiedPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
+        }
     }
 
     # show file upload
@@ -1211,6 +1385,24 @@ sub Run {
         );
     }
 
+    # FeatureAddons
+    if ( $Self->{ConfigObject}->Get('Package::ShowFeatureAddons') ) {
+        my $FeatureAddonData = $Self->_GetFeatureAddonData();
+
+        if ( ref $FeatureAddonData eq 'ARRAY' && scalar @{$FeatureAddonData} > 0 ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'FeatureAddonList',
+            );
+
+            for my $Item ( @{$FeatureAddonData} ) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'FeatureAddonData',
+                    Data => $Item,
+                );
+            }
+        }
+    }
+
     my $Output = $Self->{LayoutObject}->Header();
     $Output .= $Self->{LayoutObject}->NavigationBar();
     $Output .= $OutputNotify;
@@ -1218,13 +1410,27 @@ sub Run {
         $Output .= $Self->{LayoutObject}->Notify(
             Priority => 'Error',
             Data     => "$ReinstallKey $NeedReinstall{$ReinstallKey}"
-                . ' - $Text{"Package not correctly deployed! You should reinstall the Package again!"}',
+                . ' - $Text{"Package not correctly deployed! Please reinstall the package."}',
             Link => '$Env{"Baselink"}Action=$Env{"Action"};Subaction=View;Name='
                 . $ReinstallKey
                 . ';Version='
                 . $NeedReinstall{$ReinstallKey},
         );
     }
+
+    VERIFICATION:
+    for my $Package ( sort keys %NotVerifiedPackages ) {
+
+        next VERIFICATION if !$Package;
+        next VERIFICATION if !$NotVerifiedPackages{$Package};
+
+        $Output .= $Self->{LayoutObject}->Notify(
+            Priority => 'Error',
+            Data     => "$Package $NotVerifiedPackages{$Package} - "
+                . '$Text{"Package not verified by the OTRS Group! It is recommended not to use this package."}',
+        );
+    }
+
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminPackageManager',
     );
@@ -1238,6 +1444,10 @@ sub _MessageGet {
     my $Title       = '';
     my $Description = '';
     my $Use         = 0;
+
+    my $Language = $Self->{LayoutObject}->{UserLanguage}
+        || $Self->{ConfigObject}->Get('DefaultLanguage');
+
     if ( $Param{Info} ) {
         for my $Tag ( @{ $Param{Info} } ) {
             if ( $Param{Type} ) {
@@ -1251,14 +1461,8 @@ sub _MessageGet {
                 $Description = $Tag->{Content};
                 $Title       = $Tag->{Title};
             }
-            if (
-                ( $Self->{UserLanguage} && $Tag->{Lang} eq $Self->{UserLanguage} )
-                || (
-                    !$Self->{UserLanguage}
-                    && $Tag->{Lang} eq $Self->{ConfigObject}->Get('DefaultLanguage')
-                )
-                )
-            {
+
+            if ( $Tag->{Lang} eq $Language ) {
                 $Description = $Tag->{Content};
                 $Title       = $Tag->{Title};
             }
@@ -1371,11 +1575,19 @@ sub _InstallHandling {
     my $Verified = $Self->{PackageObject}->PackageVerify(
         Package   => $Param{Package},
         Structure => \%Structure,
-    );
+    ) || 'verified';
     my %VerifyInfo = $Self->{PackageObject}->PackageVerifyInfo();
 
+    # translate description
+    if ( $Self->{LayoutObject}->{LanguageObject} ) {
+        $VerifyInfo{Description} = $Self->{LayoutObject}->{LanguageObject}->Get(
+            $VerifyInfo{Description}
+        );
+    }
+
     # vendor screen
-    if ( !$IntroInstallVendor && !$IntroInstallPre && !$Verified ) {
+    if ( !$IntroInstallVendor && !$IntroInstallPre && $Verified ne 'verified' ) {
+
         $Self->{LayoutObject}->Block(
             Name => 'Intro',
             Data => {
@@ -1387,9 +1599,11 @@ sub _InstallHandling {
                 Version   => $Structure{Version}->{Content},
             },
         );
+
         $Self->{LayoutObject}->Block(
             Name => 'IntroCancel',
         );
+
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
@@ -1402,7 +1616,10 @@ sub _InstallHandling {
     # intro screen
     my %Data;
     if ( $Structure{IntroInstall} ) {
-        %Data = $Self->_MessageGet( Info => $Structure{IntroInstall}, Type => 'pre' );
+        %Data = $Self->_MessageGet(
+            Info => $Structure{IntroInstall},
+            Type => 'pre'
+        );
     }
 
     # intro before installation
@@ -1419,6 +1636,13 @@ sub _InstallHandling {
                 Version   => $Structure{Version}->{Content},
             },
         );
+
+        if ( $Verified eq 'verified' ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'OTRSVerifyLogo',
+            );
+        }
+
         $Self->{LayoutObject}->Block(
             Name => 'IntroCancel',
         );
@@ -1437,7 +1661,10 @@ sub _InstallHandling {
         # intro screen
         my %Data;
         if ( $Structure{IntroInstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroInstall}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroInstall},
+                Type => 'post'
+            );
         }
         if (%Data) {
             $Self->{LayoutObject}->Block(
@@ -1451,6 +1678,13 @@ sub _InstallHandling {
                     Version   => $Structure{Version}->{Content},
                 },
             );
+
+            if ( $Verified eq 'verified' ) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'OTRSVerifyLogo',
+                );
+            }
+
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
             $Output .= $Self->{LayoutObject}->Output(
@@ -1483,12 +1717,17 @@ sub _UpgradeHandling {
     my $IntroUpgradePre = $Self->{ParamObject}->GetParam( Param => 'IntroUpgradePre' ) || '';
 
     # check if we have to show upgrade intro pre
-    my %Structure = $Self->{PackageObject}->PackageParse( String => $Param{Package}, );
+    my %Structure = $Self->{PackageObject}->PackageParse(
+        String => $Param{Package},
+    );
 
     # intro screen
     my %Data;
     if ( $Structure{IntroUpgrade} ) {
-        %Data = $Self->_MessageGet( Info => $Structure{IntroUpgrade}, Type => 'pre' );
+        %Data = $Self->_MessageGet(
+            Info => $Structure{IntroUpgrade},
+            Type => 'pre'
+        );
     }
     if ( %Data && !$IntroUpgradePre ) {
         $Self->{LayoutObject}->Block(
@@ -1520,7 +1759,10 @@ sub _UpgradeHandling {
         # intro screen
         my %Data;
         if ( $Structure{IntroUpgrade} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroUpgrade}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroUpgrade},
+                Type => 'post'
+            );
         }
         if (%Data) {
             $Self->{LayoutObject}->Block(
@@ -1546,7 +1788,79 @@ sub _UpgradeHandling {
         # redirect
         return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
     }
+
     return $Self->{LayoutObject}->ErrorScreen();
 }
 
+sub _GetFeatureAddonData {
+    my ( $Self, %Param ) = @_;
+
+    # Default URL
+    my $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=en';
+
+    my $Language = $Self->{LayoutObject}->{UserLanguage};
+
+    # Check if URL for UserLanguage is available
+    if ( $Language =~ m/^de/ ) {
+        $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=de';
+    }
+
+    if ( $Language =~ m/^es/ ) {
+        $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=es';
+    }
+
+    my $CacheKey  = "FeatureAddonData::$FeedURL";
+    my $CacheTTL  = 60 * 60 * 24;                   # 1 day
+    my $CacheType = 'PackageManager';
+
+    my $CacheResult = $Self->{CacheObject}->Get(
+        Type => $CacheType,
+        Key  => $CacheKey,
+    );
+
+    return $CacheResult if ref $CacheResult eq 'ARRAY';
+
+    # set proxy settings can't use Kernel::System::WebAgent because of used
+    # XML::FeedPP to get RSS files
+    my $Proxy = $Self->{ConfigObject}->Get('WebUserAgent::Proxy');
+    if ($Proxy) {
+        $ENV{CGI_HTTP_PROXY} = $Proxy;
+    }
+
+    # get content
+    my $Feed = eval {
+        XML::FeedPP->new(
+            $FeedURL,
+            'xml_deref' => 1,
+            'utf8_flag' => 1,
+        );
+    };
+
+    return if !$Feed;
+
+    my @Result;
+    my $Count = 0;
+    ITEM:
+    for my $Item ( $Feed->get_item() ) {
+        $Count++;
+        last ITEM if $Count > 100;
+
+        push @Result, {
+            Title       => $Item->title(),
+            Link        => $Item->link(),
+            Description => $Item->get('content:encoded'),
+        };
+    }
+
+    # set cache
+    $Self->{CacheObject}->Set(
+        Type  => $CacheType,
+        Key   => $CacheKey,
+        Value => \@Result,
+        TTL   => $CacheTTL,
+    );
+
+    return \@Result;
+}
+
 1;
