@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminPostMasterFilter.pm - to add/update/delete filters
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminPostMasterFilter.pm,v 1.36.2.1 2011-04-06 16:37:27 en Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,11 +12,9 @@ package Kernel::Modules::AdminPostMasterFilter;
 use strict;
 use warnings;
 
+use Kernel::System::DynamicField;
 use Kernel::System::PostMaster::Filter;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.36.2.1 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -33,7 +29,8 @@ sub new {
         }
     }
 
-    $Self->{PostMasterFilter} = Kernel::System::PostMaster::Filter->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{PostMasterFilter}   = Kernel::System::PostMaster::Filter->new(%Param);
 
     return $Self;
 }
@@ -46,19 +43,20 @@ sub Run {
     my $StopAfterMatch = $Self->{ParamObject}->GetParam( Param => 'StopAfterMatch' ) || 0;
     my %GetParam = ();
     for my $Number ( 1 .. 12 ) {
-        $GetParam{"MatchHeader$Number"}
-            = $Self->{ParamObject}->GetParam( Param => "MatchHeader$Number" );
-        $GetParam{"MatchValue$Number"}
-            = $Self->{ParamObject}->GetParam( Param => "MatchValue$Number" );
-        $GetParam{"SetHeader$Number"}
-            = $Self->{ParamObject}->GetParam( Param => "SetHeader$Number" );
-        $GetParam{"SetValue$Number"} = $Self->{ParamObject}->GetParam( Param => "SetValue$Number" );
+        $GetParam{"MatchHeader$Number"} = $Self->{ParamObject}->GetParam( Param => "MatchHeader$Number" );
+        $GetParam{"MatchValue$Number"}  = $Self->{ParamObject}->GetParam( Param => "MatchValue$Number" );
+        $GetParam{"SetHeader$Number"}   = $Self->{ParamObject}->GetParam( Param => "SetHeader$Number" );
+        $GetParam{"SetValue$Number"}    = $Self->{ParamObject}->GetParam( Param => "SetValue$Number" );
     }
 
     # ------------------------------------------------------------ #
     # delete
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Delete' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         if ( !$Self->{PostMasterFilter}->FilterDelete( Name => $Name ) ) {
             return $Self->{LayoutObject}->ErrorScreen();
         }
@@ -184,7 +182,9 @@ sub Run {
             for my $Key ( sort keys %List ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'OverviewResultRow',
-                    Data => { Name => $Key, },
+                    Data => {
+                        Name => $Key,
+                    },
                 );
             }
         }
@@ -239,16 +239,26 @@ sub _MaskUpdate {
     $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
 
     # all headers
-    my %Header = ();
-    for my $ConfigHeader ( @{ $Self->{ConfigObject}->Get('PostmasterX-Header') } ) {
-        $Header{$ConfigHeader} = $ConfigHeader;
+    my @Headers = @{ $Self->{ConfigObject}->Get('PostmasterX-Header') };
+
+    # add Dynamic Field headers
+    my $DynamicFields = $Self->{DynamicFieldObject}->DynamicFieldList(
+        Valid      => 1,
+        ObjectType => [ 'Ticket', 'Article' ],
+        ResultType => 'HASH',
+    );
+    for my $DynamicField ( values %$DynamicFields ) {
+        push @Headers, 'X-OTRS-DynamicField-' . $DynamicField;
+        push @Headers, 'X-OTRS-FollowUp-DynamicField-' . $DynamicField;
     }
+
+    my %Header = map { $_ => $_ } @Headers;
     $Header{''} = '-';
     $Header{Body} = 'Body';
 
     # otrs header
     my %SetHeader = ();
-    for my $HeaderKey ( keys %Header ) {
+    for my $HeaderKey ( sort keys %Header ) {
         if ( $HeaderKey =~ /^x-otrs/i ) {
             $SetHeader{$HeaderKey} = $HeaderKey;
         }
@@ -275,17 +285,23 @@ sub _MaskUpdate {
         );
     }
     $Data{"StopAfterMatch"} = $Self->{LayoutObject}->BuildSelection(
-        Data => { 0 => 'No', 1 => 'Yes' },
-        Name => 'StopAfterMatch',
-        SelectedID => $Data{StopAfterMatch} || 0,
-        Class => 'Validate_RequiredDropdown',
+        Data => {
+            0 => 'No',
+            1 => 'Yes'
+        },
+        Name        => 'StopAfterMatch',
+        SelectedID  => $Data{StopAfterMatch} || 0,
+        Class       => 'Validate_RequiredDropdown',
         Translation => 1,
         HTMLQuote   => 1,
     );
 
     $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
-        Data => { %Param, %Data, OldName => $Data{Name}, },
+        Data => {
+            %Param, %Data,
+            OldName => $Data{Name},
+        },
     );
 
     # shows header
