@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminSLA.pm - admin frontend to manage slas
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminSLA.pm,v 1.36 2011-04-05 12:28:57 mb Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,9 +16,6 @@ use Kernel::System::Service;
 use Kernel::System::SLA;
 use Kernel::System::Valid;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.36 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -154,11 +149,16 @@ sub Run {
                     if (@Params) {
                         my %GetParam = ();
                         for my $ParamItem (@Params) {
-                            my @Array
-                                = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
+                            my @Array = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
                             $GetParam{ $ParamItem->{Name} } = \@Array;
                         }
-                        if ( !$Object->Run( GetParam => \%GetParam, SLAData => \%SLAData ) ) {
+                        if (
+                            !$Object->Run(
+                                GetParam => \%GetParam,
+                                SLAData  => \%SLAData
+                            )
+                            )
+                        {
                             $Note .= $Self->{LayoutObject}->Notify( Info => $Object->Error() );
                         }
                     }
@@ -230,8 +230,9 @@ sub Run {
 
         # get service list
         my %ServiceList = $Self->{ServiceObject}->ServiceList(
-            Valid  => 0,
-            UserID => $Self->{UserID},
+            Valid        => 1,
+            KeepChildren => 1,
+            UserID       => $Self->{UserID},
         );
 
         # get valid list
@@ -333,8 +334,9 @@ sub _MaskNew {
 
     # get service list
     my %ServiceList = $Self->{ServiceObject}->ServiceList(
-        Valid  => 0,
-        UserID => $Self->{UserID},
+        Valid        => 1,
+        KeepChildren => 1,
+        UserID       => $Self->{UserID},
     );
 
     # generate ServiceOptionStrg
@@ -346,6 +348,7 @@ sub _MaskNew {
         Size        => 5,
         Translation => 0,
         Max         => 200,
+        TreeView    => 1,
     );
 
     # generate CalendarOptionStrg
@@ -480,7 +483,10 @@ sub _MaskNew {
     }
 
     # get output back
-    return $Self->{LayoutObject}->Output( TemplateFile => 'AdminSLA', Data => \%Param );
+    return $Self->{LayoutObject}->Output(
+        TemplateFile => 'AdminSLA',
+        Data         => \%Param
+    );
 }
 
 1;
