@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentBook.pm - addressbook module
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentBook.pm,v 1.23 2012/11/20 14:45:53 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +14,6 @@ use warnings;
 
 use Kernel::System::CustomerUser;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.23 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -51,19 +46,22 @@ sub Run {
     my $Search = $Self->{ParamObject}->GetParam( Param => 'Search' );
     my %CustomerUserList;
     if ($Search) {
-        %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch( Search => $Search, );
+        %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
+            Search => $Search,
+        );
     }
     my %List;
     for ( sort keys %CustomerUserList ) {
-        my %CustomerUserData = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $_, );
+        my %CustomerUserData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+            User => $_,
+        );
         if ( $CustomerUserData{UserEmail} ) {
             $List{ $CustomerUserData{UserEmail} } = $CustomerUserList{$_};
         }
     }
 
     # build customer search autocomplete field
-    my $AutoCompleteConfig
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerSearchAutoComplete');
+    my $AutoCompleteConfig = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerSearchAutoComplete');
     $Self->{LayoutObject}->Block(
         Name => 'CustomerSearchAutoComplete',
         Data => {
@@ -96,7 +94,10 @@ sub Run {
 
     # start with page ...
     my $Output = $Self->{LayoutObject}->Header( Type => 'Small' );
-    $Output .= $Self->{LayoutObject}->Output( TemplateFile => 'AgentBook', Data => \%Param );
+    $Output .= $Self->{LayoutObject}->Output(
+        TemplateFile => 'AgentBook',
+        Data         => \%Param
+    );
     $Output .= $Self->{LayoutObject}->Footer( Type => 'Small' );
 
     return $Output;
