@@ -2,8 +2,6 @@
 # Kernel/Modules/AgentTicketBulk.pm - to do bulk actions on tickets
 # Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: AgentTicketBulk.pm,v 1.95.2.2 2013-01-11 10:47:48 mn Exp $
-# --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
@@ -21,9 +19,6 @@ use Kernel::System::Web::UploadCache;
 use Kernel::System::CustomerUser;
 use Kernel::System::TemplateGenerator;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.95.2.2 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -80,8 +75,7 @@ sub Run {
     }
 
     # get involved tickets, filtering empty TicketIDs
-    my @TicketIDs
-        = grep {$_}
+    my @TicketIDs = grep {$_}
         $Self->{ParamObject}->GetArray( Param => 'TicketID' );
 
     # check needed stuff
@@ -111,12 +105,16 @@ sub Run {
             qw(OwnerID Owner ResponsibleID Responsible PriorityID Priority QueueID Queue Subject
             Body ArticleTypeID ArticleType TypeID StateID State MergeToSelection MergeTo LinkTogether
             EmailSubject EmailBody EmailTimeUnits
-            LinkTogetherParent Unlock MergeToChecked MergeToOldestChecked TimeUnits)
+            LinkTogetherParent Unlock MergeToChecked MergeToOldestChecked)
             )
         {
             $GetParam{$Key} = $Self->{ParamObject}->GetParam( Param => $Key ) || '';
         }
 
+        for my $Key (qw(TimeUnits)) {
+            $GetParam{$Key} = $Self->{ParamObject}->GetParam( Param => $Key );
+        }
+
         # get time stamp based on user time zone
         %Time = $Self->{LayoutObject}->TransfromDateSelection(
             Year   => $Self->{ParamObject}->GetParam( Param => 'Year' ),
@@ -391,8 +389,7 @@ sub Run {
                         User => $Ticket{CustomerUserID}
                     );
                     if ( $Customer{UserEmail} ) {
-                        $Customer
-                            = "$Customer{UserFirstname} $Customer{UserLastname} <$Customer{UserEmail}>";
+                        $Customer = $Customer{UserEmail};
                     }
                 }
 
@@ -403,13 +400,16 @@ sub Run {
                         DynamicFields => 0,
                     );
 
+                    # use ReplyTo if set, otherwise use From
+                    $Customer = $Data{ReplyTo} ? $Data{ReplyTo} : $Data{From};
+
                     # check article type and replace To with From (in case)
                     if ( $Data{SenderType} !~ /customer/ ) {
 
                         # replace From/To, To/From because sender is agent
-                        $Data{From} = $Data{To};
+                        $Customer = $Data{To};
                     }
-                    $Customer = $Data{From};
+
                 }
 
                 # generate sender name
@@ -419,12 +419,11 @@ sub Run {
                 );
 
                 # generate subject
-                my $TicketNumber
-                    = $Self->{TicketObject}->TicketNumberLookup( TicketID => $TicketID );
+                my $TicketNumber = $Self->{TicketObject}->TicketNumberLookup( TicketID => $TicketID );
 
                 my $EmailSubject = $Self->{TicketObject}->TicketSubjectBuild(
                     TicketNumber => $TicketNumber,
-                    Subject => $GetParam{EmailSubject} || '',
+                    Subject      => $GetParam{EmailSubject} || '',
                 );
 
                 $EmailArticleID = $Self->{TicketObject}->ArticleSend(
@@ -461,16 +460,16 @@ sub Run {
                     );
                 }
                 $ArticleID = $Self->{TicketObject}->ArticleCreate(
-                    TicketID      => $TicketID,
-                    ArticleTypeID => $GetParam{'ArticleTypeID'},
-                    ArticleType   => $GetParam{'ArticleType'},
-                    SenderType    => 'agent',
-                    From     => "$Self->{UserFirstname} $Self->{UserLastname} <$Self->{UserEmail}>",
-                    Subject  => $GetParam{'Subject'},
-                    Body     => $GetParam{'Body'},
-                    MimeType => $MimeType,
-                    Charset  => $Self->{LayoutObject}->{UserCharset},
-                    UserID   => $Self->{UserID},
+                    TicketID       => $TicketID,
+                    ArticleTypeID  => $GetParam{'ArticleTypeID'},
+                    ArticleType    => $GetParam{'ArticleType'},
+                    SenderType     => 'agent',
+                    From           => "$Self->{UserFirstname} $Self->{UserLastname} <$Self->{UserEmail}>",
+                    Subject        => $GetParam{'Subject'},
+                    Body           => $GetParam{'Body'},
+                    MimeType       => $MimeType,
+                    Charset        => $Self->{LayoutObject}->{UserCharset},
+                    UserID         => $Self->{UserID},
                     HistoryType    => 'AddNote',
                     HistoryComment => '%%Bulk',
                 );
@@ -627,7 +626,7 @@ sub Run {
                 }
             }
 
-            # link togehter
+            # link together
             if ( $GetParam{'LinkTogether'} ) {
                 for my $TicketIDPartner (@TicketIDs) {
                     if ( $TicketID ne $TicketIDPartner ) {
@@ -682,9 +681,8 @@ sub _Mask {
 
     # prepare errors!
     if ( $Param{Errors} ) {
-        for my $KeyError ( keys %{ $Param{Errors} } ) {
-            $Param{$KeyError}
-                = $Self->{LayoutObject}->Ascii2Html( Text => $Param{Errors}->{$KeyError} );
+        for my $KeyError ( sort keys %{ $Param{Errors} } ) {
+            $Param{$KeyError} = $Self->{LayoutObject}->Ascii2Html( Text => $Param{Errors}->{$KeyError} );
         }
     }
 
@@ -708,7 +706,7 @@ sub _Mask {
     # build ArticleTypeID string
     my %DefaultNoteTypes = %{ $Self->{Config}->{ArticleTypes} };
     my %NoteTypes = $Self->{TicketObject}->ArticleTypeList( Result => 'HASH' );
-    for my $KeyNoteType ( keys %NoteTypes ) {
+    for my $KeyNoteType ( sort keys %NoteTypes ) {
         if ( !$DefaultNoteTypes{ $NoteTypes{$KeyNoteType} } ) {
             delete $NoteTypes{$KeyNoteType};
         }
@@ -767,10 +765,10 @@ sub _Mask {
             next STATE_ID if $StateData{TypeName} !~ /pending/i;
             $Param{DateString} = $Self->{LayoutObject}->BuildDateSelection(
                 %Param,
-                Format   => 'DateInputFormatLong',
-                DiffTime => $Self->{ConfigObject}->Get('Ticket::Frontend::PendingDiffTime') || 0,
-                Class    => $Param{Errors}->{DateInvalid} || '',
-                Validate => 1,
+                Format               => 'DateInputFormatLong',
+                DiffTime             => $Self->{ConfigObject}->Get('Ticket::Frontend::PendingDiffTime') || 0,
+                Class                => $Param{Errors}->{DateInvalid} || '',
+                Validate             => 1,
                 ValidateDateInFuture => 1,
             );
             $Self->{LayoutObject}->Block(
@@ -804,7 +802,10 @@ sub _Mask {
 
     # owner list
     if ( $Self->{Config}->{Owner} ) {
-        my %AllGroupsMembers = $Self->{UserObject}->UserList( Type => 'Long', Valid => 1 );
+        my %AllGroupsMembers = $Self->{UserObject}->UserList(
+            Type  => 'Long',
+            Valid => 1
+        );
 
         # only put possible rw agents to possible owner list
         if ( !$Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
@@ -843,7 +844,10 @@ sub _Mask {
 
     # responsible list
     if ( $Self->{ConfigObject}->Get('Ticket::Responsible') && $Self->{Config}->{Responsible} ) {
-        my %AllGroupsMembers = $Self->{UserObject}->UserList( Type => 'Long', Valid => 1 );
+        my %AllGroupsMembers = $Self->{UserObject}->UserList(
+            Type  => 'Long',
+            Valid => 1
+        );
 
         # only put possible rw agents to possible owner list
         if ( !$Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
@@ -868,8 +872,11 @@ sub _Mask {
             }
         }
         $Param{ResponsibleStrg} = $Self->{LayoutObject}->BuildSelection(
-            Data => { '' => '-', %AllGroupsMembers },
-            Name => 'ResponsibleID',
+            Data => {
+                '' => '-',
+                %AllGroupsMembers
+            },
+            Name        => 'ResponsibleID',
             Translation => 0,
             SelectedID  => $Param{ResponsibleID},
         );
@@ -886,7 +893,7 @@ sub _Mask {
         Type   => 'move_into',
     );
     $Param{MoveQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
-        Data => { %MoveQueues, '' => '-' },
+        Data     => { %MoveQueues, '' => '-' },
         Multiple => 0,
         Size     => 0,
         Name     => 'QueueID',
@@ -989,6 +996,11 @@ sub _Mask {
 
     # add rich text editor for note & email
     if ( $Self->{LayoutObject}->{BrowserRichText} ) {
+
+        # use height/width defined for this screen
+        $Param{RichTextHeight} = $Self->{Config}->{RichTextHeight} || 0;
+        $Param{RichTextWidth}  = $Self->{Config}->{RichTextWidth}  || 0;
+
         $Self->{LayoutObject}->Block(
             Name => 'RichText',
             Data => \%Param,
@@ -1010,7 +1022,10 @@ sub _Mask {
     }
 
     # get output back
-    return $Self->{LayoutObject}->Output( TemplateFile => 'AgentTicketBulk', Data => \%Param );
+    return $Self->{LayoutObject}->Output(
+        TemplateFile => 'AgentTicketBulk',
+        Data         => \%Param
+    );
 }
 
 1;
