@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -326,9 +326,12 @@ sub Run {
         }
 
         # store last queue screen
-        my $URL
-            = "Action=AgentTicketSearch;Subaction=Search;Profile=$Self->{Profile};SortBy=$Self->{SortBy}"
-            . ";OrderBy=$Self->{OrderBy};TakeLastSearch=1;StartHit=$Self->{StartHit}";
+        my $URL = "Action=AgentTicketSearch;Subaction=Search"
+            . ";Profile=" . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+            . ";SortBy=" . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
+            . ";OrderBy=" . $Self->{LayoutObject}->LinkEncode( $Self->{OrderBy} )
+            . ";TakeLastSearch=1"
+            . ";StartHit=" . $Self->{LayoutObject}->LinkEncode( $Self->{StartHit} );
         $Self->{SessionObject}->UpdateSessionID(
             SessionID => $Self->{SessionID},
             Key       => 'LastScreenOverview',
@@ -378,10 +381,8 @@ sub Run {
         }
         elsif ( $GetParam{ArticleTimeSearchType} eq 'TimeSlot' ) {
             for my $Key (qw(Month Day)) {
-                $GetParam{"ArticleCreateTimeStart$Key"}
-                    = sprintf( "%02d", $GetParam{"ArticleCreateTimeStart$Key"} );
-                $GetParam{"ArticleCreateTimeStop$Key"}
-                    = sprintf( "%02d", $GetParam{"ArticleCreateTimeStop$Key"} );
+                $GetParam{"ArticleCreateTimeStart$Key"} = sprintf( "%02d", $GetParam{"ArticleCreateTimeStart$Key"} );
+                $GetParam{"ArticleCreateTimeStop$Key"}  = sprintf( "%02d", $GetParam{"ArticleCreateTimeStop$Key"} );
             }
             if (
                 $GetParam{ArticleCreateTimeStartDay}
@@ -389,8 +390,7 @@ sub Run {
                 && $GetParam{ArticleCreateTimeStartYear}
                 )
             {
-                $GetParam{ArticleCreateTimeNewerDate}
-                    = $GetParam{ArticleCreateTimeStartYear} . '-'
+                $GetParam{ArticleCreateTimeNewerDate} = $GetParam{ArticleCreateTimeStartYear} . '-'
                     . $GetParam{ArticleCreateTimeStartMonth} . '-'
                     . $GetParam{ArticleCreateTimeStartDay}
                     . ' 00:00:00';
@@ -401,8 +401,7 @@ sub Run {
                 && $GetParam{ArticleCreateTimeStopYear}
                 )
             {
-                $GetParam{ArticleCreateTimeOlderDate}
-                    = $GetParam{ArticleCreateTimeStopYear} . '-'
+                $GetParam{ArticleCreateTimeOlderDate} = $GetParam{ArticleCreateTimeStopYear} . '-'
                     . $GetParam{ArticleCreateTimeStopMonth} . '-'
                     . $GetParam{ArticleCreateTimeStopDay}
                     . ' 23:59:59';
@@ -450,10 +449,8 @@ sub Run {
         }
         elsif ( $GetParam{TimeSearchType} eq 'TimeSlot' ) {
             for my $Key (qw(Month Day)) {
-                $GetParam{"TicketCreateTimeStart$Key"}
-                    = sprintf( "%02d", $GetParam{"TicketCreateTimeStart$Key"} );
-                $GetParam{"TicketCreateTimeStop$Key"}
-                    = sprintf( "%02d", $GetParam{"TicketCreateTimeStop$Key"} );
+                $GetParam{"TicketCreateTimeStart$Key"} = sprintf( "%02d", $GetParam{"TicketCreateTimeStart$Key"} );
+                $GetParam{"TicketCreateTimeStop$Key"}  = sprintf( "%02d", $GetParam{"TicketCreateTimeStop$Key"} );
             }
             if (
                 $GetParam{TicketCreateTimeStartDay}
@@ -461,8 +458,7 @@ sub Run {
                 && $GetParam{TicketCreateTimeStartYear}
                 )
             {
-                $GetParam{TicketCreateTimeNewerDate}
-                    = $GetParam{TicketCreateTimeStartYear} . '-'
+                $GetParam{TicketCreateTimeNewerDate} = $GetParam{TicketCreateTimeStartYear} . '-'
                     . $GetParam{TicketCreateTimeStartMonth} . '-'
                     . $GetParam{TicketCreateTimeStartDay}
                     . ' 00:00:00';
@@ -473,8 +469,7 @@ sub Run {
                 && $GetParam{TicketCreateTimeStopYear}
                 )
             {
-                $GetParam{TicketCreateTimeOlderDate}
-                    = $GetParam{TicketCreateTimeStopYear} . '-'
+                $GetParam{TicketCreateTimeOlderDate} = $GetParam{TicketCreateTimeStopYear} . '-'
                     . $GetParam{TicketCreateTimeStopMonth} . '-'
                     . $GetParam{TicketCreateTimeStopDay}
                     . ' 23:59:59';
@@ -522,10 +517,8 @@ sub Run {
         }
         elsif ( $GetParam{ChangeTimeSearchType} eq 'TimeSlot' ) {
             for my $Key (qw(Month Day)) {
-                $GetParam{"TicketChangeTimeStart$Key"}
-                    = sprintf( "%02d", $GetParam{"TicketChangeTimeStart$Key"} );
-                $GetParam{"TicketChangeTimeStop$Key"}
-                    = sprintf( "%02d", $GetParam{"TicketChangeTimeStop$Key"} );
+                $GetParam{"TicketChangeTimeStart$Key"} = sprintf( "%02d", $GetParam{"TicketChangeTimeStart$Key"} );
+                $GetParam{"TicketChangeTimeStop$Key"}  = sprintf( "%02d", $GetParam{"TicketChangeTimeStop$Key"} );
             }
             if (
                 $GetParam{TicketChangeTimeStartDay}
@@ -533,8 +526,7 @@ sub Run {
                 && $GetParam{TicketChangeTimeStartYear}
                 )
             {
-                $GetParam{TicketChangeTimeNewerDate}
-                    = $GetParam{TicketChangeTimeStartYear} . '-'
+                $GetParam{TicketChangeTimeNewerDate} = $GetParam{TicketChangeTimeStartYear} . '-'
                     . $GetParam{TicketChangeTimeStartMonth} . '-'
                     . $GetParam{TicketChangeTimeStartDay}
                     . ' 00:00:00';
@@ -545,8 +537,7 @@ sub Run {
                 && $GetParam{TicketChangeTimeStopYear}
                 )
             {
-                $GetParam{TicketChangeTimeOlderDate}
-                    = $GetParam{TicketChangeTimeStopYear} . '-'
+                $GetParam{TicketChangeTimeOlderDate} = $GetParam{TicketChangeTimeStopYear} . '-'
                     . $GetParam{TicketChangeTimeStopMonth} . '-'
                     . $GetParam{TicketChangeTimeStopDay}
                     . ' 23:59:59';
@@ -594,10 +585,8 @@ sub Run {
         }
         elsif ( $GetParam{CloseTimeSearchType} eq 'TimeSlot' ) {
             for my $Key (qw(Month Day)) {
-                $GetParam{"TicketCloseTimeStart$Key"}
-                    = sprintf( "%02d", $GetParam{"TicketCloseTimeStart$Key"} );
-                $GetParam{"TicketCloseTimeStop$Key"}
-                    = sprintf( "%02d", $GetParam{"TicketCloseTimeStop$Key"} );
+                $GetParam{"TicketCloseTimeStart$Key"} = sprintf( "%02d", $GetParam{"TicketCloseTimeStart$Key"} );
+                $GetParam{"TicketCloseTimeStop$Key"}  = sprintf( "%02d", $GetParam{"TicketCloseTimeStop$Key"} );
             }
             if (
                 $GetParam{TicketCloseTimeStartDay}
@@ -605,8 +594,7 @@ sub Run {
                 && $GetParam{TicketCloseTimeStartYear}
                 )
             {
-                $GetParam{TicketCloseTimeNewerDate}
-                    = $GetParam{TicketCloseTimeStartYear} . '-'
+                $GetParam{TicketCloseTimeNewerDate} = $GetParam{TicketCloseTimeStartYear} . '-'
                     . $GetParam{TicketCloseTimeStartMonth} . '-'
                     . $GetParam{TicketCloseTimeStartDay}
                     . ' 00:00:00';
@@ -617,8 +605,7 @@ sub Run {
                 && $GetParam{TicketCloseTimeStopYear}
                 )
             {
-                $GetParam{TicketCloseTimeOlderDate}
-                    = $GetParam{TicketCloseTimeStopYear} . '-'
+                $GetParam{TicketCloseTimeOlderDate} = $GetParam{TicketCloseTimeStopYear} . '-'
                     . $GetParam{TicketCloseTimeStopMonth} . '-'
                     . $GetParam{TicketCloseTimeStopDay}
                     . ' 23:59:59';
@@ -677,8 +664,7 @@ sub Run {
                 && $GetParam{TicketEscalationTimeStartYear}
                 )
             {
-                $GetParam{TicketEscalationTimeNewerDate}
-                    = $GetParam{TicketEscalationTimeStartYear} . '-'
+                $GetParam{TicketEscalationTimeNewerDate} = $GetParam{TicketEscalationTimeStartYear} . '-'
                     . $GetParam{TicketEscalationTimeStartMonth} . '-'
                     . $GetParam{TicketEscalationTimeStartDay}
                     . ' 00:00:00';
@@ -689,8 +675,7 @@ sub Run {
                 && $GetParam{TicketEscalationTimeStopYear}
                 )
             {
-                $GetParam{TicketEscalationTimeOlderDate}
-                    = $GetParam{TicketEscalationTimeStopYear} . '-'
+                $GetParam{TicketEscalationTimeOlderDate} = $GetParam{TicketEscalationTimeStopYear} . '-'
                     . $GetParam{TicketEscalationTimeStopMonth} . '-'
                     . $GetParam{TicketEscalationTimeStopDay}
                     . ' 23:59:59';
@@ -832,7 +817,7 @@ sub Run {
 
             # create head (actual head and head for data fill)
             my @TmpCSVHead = @{ $Self->{Config}->{SearchCSVData} };
-            my @CSVHead = @{ $Self->{Config}->{SearchCSVData} };
+            my @CSVHead    = @{ $Self->{Config}->{SearchCSVData} };
 
             # include the selected dynamic fields in CVS results
             DYNAMICFIELD:
@@ -842,7 +827,7 @@ sub Run {
                 next DYNAMICFIELD if $DynamicFieldConfig->{Name} eq '';
 
                 push @TmpCSVHead, 'DynamicField_' . $DynamicFieldConfig->{Name};
-                push @CSVHead, $DynamicFieldConfig->{Label};
+                push @CSVHead,    $DynamicFieldConfig->{Label};
             }
 
             my @CSVData;
@@ -859,7 +844,10 @@ sub Run {
                     $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{$Key} );
                 }
 
-                $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
+                $Data{Age} = $Self->{LayoutObject}->CustomerAge(
+                    Age   => $Data{Age},
+                    Space => ' '
+                );
 
                 # get whole article (if configured!)
                 if ( $Self->{Config}->{SearchArticleCSVTree} ) {
@@ -895,8 +883,7 @@ sub Run {
                     %Data,
                     %UserInfo,
                     AccountedTime =>
-                        $Self->{TicketObjectSearch}
-                        ->TicketAccountedTimeGet( TicketID => $TicketID ),
+                        $Self->{TicketObjectSearch}->TicketAccountedTimeGet( TicketID => $TicketID ),
                 );
 
                 my @Data;
@@ -943,7 +930,7 @@ sub Run {
 
             if ( $Self->{ConfigObject}->Get('PreferencesGroups')->{CSVSeparator}->{Active} ) {
                 my %UserData = $Self->{UserObject}->GetUserData( UserID => $Self->{UserID} );
-                $UserCSVSeparator = $UserData{UserCSVSeparator};
+                $UserCSVSeparator = $UserData{UserCSVSeparator} if $UserData{UserCSVSeparator};
             }
 
             my %HeaderMap = (
@@ -951,8 +938,7 @@ sub Run {
                 CustomerName => 'customer realname',
             );
 
-            my @CSVHeadTranslated
-                = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
+            my @CSVHeadTranslated = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
                 @CSVHead;
 
             my $CSV = $Self->{CSVObject}->Array2CSV(
@@ -990,6 +976,19 @@ sub Run {
                     DynamicFields => 1,
                 );
 
+                if ( !%Data ) {
+
+                    # get ticket data instead
+                    %Data = $Self->{TicketObjectSearch}->TicketGet(
+                        TicketID      => $TicketID,
+                        DynamicFields => 1,
+                    );
+
+                    # set missing information
+                    $Data{Subject} = $Data{Title};
+                    $Data{From}    = '--';
+                }
+
                 # customer info
                 my %CustomerData;
                 if ( $Data{CustomerUserID} ) {
@@ -1016,7 +1015,10 @@ sub Run {
                 );
 
                 # get age
-                $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
+                $Data{Age} = $Self->{LayoutObject}->CustomerAge(
+                    Age   => $Data{Age},
+                    Space => ' '
+                );
 
                 # customer info string
                 $UserInfo{CustomerName} = '(' . $UserInfo{CustomerName} . ')'
@@ -1068,8 +1070,7 @@ sub Run {
                 my $Time      = $Self->{LayoutObject}->Output( Template => '$Env{"Time"}' );
                 my $Url       = '';
                 if ( $ENV{REQUEST_URI} ) {
-                    $Url
-                        = $Self->{ConfigObject}->Get('HttpType') . '://'
+                    $Url = $Self->{ConfigObject}->Get('HttpType') . '://'
                         . $Self->{ConfigObject}->Get('FQDN')
                         . $ENV{REQUEST_URI};
                 }
@@ -1088,27 +1089,20 @@ sub Run {
                     # create the header
                     $CellData->[0]->[0]->{Content} = $Self->{ConfigObject}->Get('Ticket::Hook');
                     $CellData->[0]->[0]->{Font}    = 'ProportionalBold';
-                    $CellData->[0]->[1]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
-                    $CellData->[0]->[1]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[2]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('From');
-                    $CellData->[0]->[2]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[3]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Subject');
-                    $CellData->[0]->[3]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[4]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('State');
-                    $CellData->[0]->[4]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[5]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Queue');
-                    $CellData->[0]->[5]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[6]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Owner');
-                    $CellData->[0]->[6]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[7]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID');
-                    $CellData->[0]->[7]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[1]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
+                    $CellData->[0]->[1]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[2]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('From');
+                    $CellData->[0]->[2]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[3]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Subject');
+                    $CellData->[0]->[3]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[4]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('State');
+                    $CellData->[0]->[4]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[5]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Queue');
+                    $CellData->[0]->[5]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[6]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Owner');
+                    $CellData->[0]->[6]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[7]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID');
+                    $CellData->[0]->[7]->{Font}    = 'ProportionalBold';
 
                     # create the content array
                     my $CounterRow = 1;
@@ -1163,7 +1157,10 @@ sub Run {
                 );
 
                 # start table output
-                $Self->{PDFObject}->PageNew( %PageParam, FooterRight => $Page . ' 1', );
+                $Self->{PDFObject}->PageNew(
+                    %PageParam,
+                    FooterRight => $Page . ' 1',
+                );
                 PAGE:
                 for my $PageNumber ( 2 .. $MaxPages ) {
 
@@ -1184,10 +1181,9 @@ sub Run {
 
                 # return the pdf document
                 my $Filename = 'ticket_search';
-                my ( $s, $m, $h, $D, $M, $Y )
-                    = $Self->{TimeObject}->SystemTime2Date(
+                my ( $s, $m, $h, $D, $M, $Y ) = $Self->{TimeObject}->SystemTime2Date(
                     SystemTime => $Self->{TimeObject}->SystemTime(),
-                    );
+                );
                 $M = sprintf( "%02d", $M );
                 $D = sprintf( "%02d", $D );
                 $h = sprintf( "%02d", $h );
@@ -1222,7 +1218,7 @@ sub Run {
         else {
 
             # redirect to the ticketzoom if result of the search is only one
-            if ( scalar @ViewableTicketIDs eq 1 ) {
+            if ( scalar @ViewableTicketIDs eq 1 && !$Self->{TakeLastSearch} ) {
                 return $Self->{LayoutObject}->Redirect(
                     OP => "Action=AgentTicketZoom;TicketID=$ViewableTicketIDs[0]",
                 );
@@ -1243,12 +1239,16 @@ sub Run {
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
                 . ';SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
                 . ';OrderBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{OrderBy} )
-                . ';Profile=' . $Self->{Profile} . ';TakeLastSearch=1;Subaction=Search'
+                . ';Profile='
+                . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ';TakeLastSearch=1;Subaction=Search'
                 . ';';
             my $LinkSort = 'Filter='
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Filter} )
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
-                . ';Profile=' . $Self->{Profile} . ';TakeLastSearch=1;Subaction=Search'
+                . ';Profile='
+                . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ';TakeLastSearch=1;Subaction=Search'
                 . ';';
             my $LinkFilter = 'TakeLastSearch=1;Subaction=Search;Profile='
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
@@ -1257,11 +1257,12 @@ sub Run {
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
                 . ';TakeLastSearch=1&';
 
-            my $FilterLink
-                = 'SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
+            my $FilterLink = 'SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
                 . ';OrderBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{OrderBy} )
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
-                . ';Profile=' . $Self->{Profile} . ';TakeLastSearch=1;Subaction=Search'
+                . ';Profile='
+                . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ';TakeLastSearch=1;Subaction=Search'
                 . ';';
             $Output .= $Self->{LayoutObject}->TicketListShow(
                 TicketIDs => \@ViewableTicketIDs,
@@ -1324,8 +1325,9 @@ sub Run {
         );
 
         # convert attributes
-        if ( $GetParam{ShownAttributes} && ref $GetParam{ShownAttributes} eq 'ARRAY' ) {
-            $GetParam{ShownAttributes} = join ';', @{ $GetParam{ShownAttributes} };
+        if ( IsArrayRefWithData( $GetParam{ShownAttributes} ) ) {
+            my @ShowAttributes = grep {defined} @{ $GetParam{ShownAttributes} };
+            $GetParam{ShownAttributes} = join ';', @ShowAttributes;
         }
 
         # if no profile is used, set default params of default attributes
@@ -1688,7 +1690,9 @@ sub Run {
             if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ListType') eq 'tree' ) {
                 $TreeView = 1;
             }
-            my %Service = $Self->{ServiceObject}->ServiceList( UserID => $Self->{UserID}, );
+            my %Service = $Self->{ServiceObject}->ServiceList(
+                UserID => $Self->{UserID},
+            );
             $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Service,
                 Name        => 'ServiceIDs',
@@ -1700,7 +1704,9 @@ sub Run {
                 Translation => 0,
                 Max         => 200,
             );
-            my %SLA = $Self->{SLAObject}->SLAList( UserID => $Self->{UserID}, );
+            my %SLA = $Self->{SLAObject}->SLAList(
+                UserID => $Self->{UserID},
+            );
             $Param{SLAsStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%SLA,
                 Name        => 'SLAIDs',
@@ -1719,7 +1725,7 @@ sub Run {
                 Print  => 'Print',
                 CSV    => 'CSV',
             },
-            Name => 'ResultForm',
+            Name       => 'ResultForm',
             SelectedID => $GetParam{ResultForm} || 'Normal',
         );
 
@@ -1731,7 +1737,7 @@ sub Run {
                     NotArchivedTickets => 'Unarchived tickets',
                     AllTickets         => 'All tickets',
                 },
-                Name => 'SearchInArchive',
+                Name       => 'SearchInArchive',
                 SelectedID => $GetParam{SearchInArchive} || 'NotArchivedTickets',
             );
         }
@@ -1822,7 +1828,7 @@ sub Run {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name => 'ArticleCreateTimePointStart',
+            Name       => 'ArticleCreateTimePointStart',
             SelectedID => $GetParam{ArticleCreateTimePointStart} || 'Last',
         );
         $Param{ArticleCreateTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1858,7 +1864,7 @@ sub Run {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name => 'TicketCreateTimePointStart',
+            Name       => 'TicketCreateTimePointStart',
             SelectedID => $GetParam{TicketCreateTimePointStart} || 'Last',
         );
         $Param{TicketCreateTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1895,7 +1901,7 @@ sub Run {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name => 'TicketChangeTimePointStart',
+            Name       => 'TicketChangeTimePointStart',
             SelectedID => $GetParam{TicketChangeTimePointStart} || 'Last',
         );
         $Param{TicketChangeTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1932,7 +1938,7 @@ sub Run {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name => 'TicketCloseTimePointStart',
+            Name       => 'TicketCloseTimePointStart',
             SelectedID => $GetParam{TicketCloseTimePointStart} || 'Last',
         );
         $Param{TicketCloseTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1969,7 +1975,7 @@ sub Run {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name => 'TicketEscalationTimePointStart',
+            Name       => 'TicketEscalationTimePointStart',
             SelectedID => $GetParam{TicketEscalationTimePointStart} || 'Last',
         );
         $Param{TicketEscalationTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -2006,7 +2012,9 @@ sub Run {
 
         # build type string
         if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
-            my %Type = $Self->{TypeObject}->TypeList( UserID => $Self->{UserID}, );
+            my %Type = $Self->{TypeObject}->TypeList(
+                UserID => $Self->{UserID},
+            );
             $Param{TypesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Type,
                 Name        => 'TypeIDs',
