@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketStatusView.pm - status for all open tickets
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketStatusView.pm,v 1.28 2010-11-04 17:57:08 mb Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +12,6 @@ package Kernel::Modules::AgentTicketStatusView;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.28 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -68,7 +63,9 @@ sub Run {
     if ( $Self->{UserRefreshTime} ) {
         $Refresh = 60 * $Self->{UserRefreshTime};
     }
-    my $Output = $Self->{LayoutObject}->Header( Refresh => $Refresh, );
+    my $Output = $Self->{LayoutObject}->Header(
+        Refresh => $Refresh,
+    );
     $Output .= $Self->{LayoutObject}->NavigationBar();
     $Self->{LayoutObject}->Print( Output => \$Output );
     $Output = '';
@@ -76,7 +73,7 @@ sub Run {
     # define filter
     my %Filters = (
         Open => {
-            Name   => 'open',
+            Name   => 'Open tickets',
             Prio   => 1000,
             Search => {
                 StateType  => 'Open',
@@ -87,7 +84,7 @@ sub Run {
             },
         },
         Closed => {
-            Name   => 'closed',
+            Name   => 'Closed tickets',
             Prio   => 1001,
             Search => {
                 StateType  => 'Closed',
@@ -121,7 +118,7 @@ sub Run {
 
     # do nav bar lookup
     my %NavBarFilter;
-    for my $Filter ( keys %Filters ) {
+    for my $Filter ( sort keys %Filters ) {
         my $Count = $Self->{TicketObject}->TicketSearch(
             %{ $Filters{$Filter}->{Search} },
             Result => 'COUNT',
@@ -168,6 +165,8 @@ sub Run {
         Filters    => \%NavBarFilter,
         FilterLink => $FilterLink,
 
+        RequestedURL => $Self->{RequestedURL},
+
         OrderBy => $OrderBy,
         SortBy  => $SortBy,
     );
