@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketZoom.pm - to get a closer view
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketZoom.pm,v 1.198 2013/01/15 18:36:41 cr Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -28,9 +26,6 @@ use Kernel::System::SystemAddress;
 
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.198 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -61,19 +56,17 @@ sub new {
     if ( !defined $Self->{ZoomExpandSort} ) {
         $Self->{ZoomExpandSort} = $Self->{ConfigObject}->Get('Ticket::Frontend::ZoomExpandSort');
     }
-    $Self->{ArticleFilterActive}
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::TicketArticleFilter');
+    $Self->{ArticleFilterActive} = $Self->{ConfigObject}->Get('Ticket::Frontend::TicketArticleFilter');
 
     # define if rich text should be used
-    $Self->{RichText}
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::ZoomRichTextForce')
+    $Self->{RichText} = $Self->{ConfigObject}->Get('Ticket::Frontend::ZoomRichTextForce')
         || $Self->{LayoutObject}->{BrowserRichText}
         || 0;
 
     # strip html and ascii attachments of content
     $Self->{StripPlainBodyAsAttachment} = 1;
 
-    # check if rich text is enabled, if not only stip ascii attachments
+    # check if rich text is enabled, if not only strip ascii attachments
     if ( !$Self->{RichText} ) {
         $Self->{StripPlainBodyAsAttachment} = 2;
     }
@@ -82,7 +75,7 @@ sub new {
     if ( !$Self->{TicketID} && $Self->{ParamObject}->GetParam( Param => 'TicketNumber' ) ) {
         $Self->{TicketID} = $Self->{TicketObject}->TicketIDLookup(
             TicketNumber => $Self->{ParamObject}->GetParam( Param => 'TicketNumber' ),
-            UserID => $Self->{UserID},
+            UserID       => $Self->{UserID},
         );
     }
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
@@ -102,13 +95,11 @@ sub new {
     };
 
     # create additional objects for process management
-    $Self->{ActivityObject} = Kernel::System::ProcessManagement::Activity->new(%Param);
-    $Self->{ActivityDialogObject}
-        = Kernel::System::ProcessManagement::ActivityDialog->new(%Param);
+    $Self->{ActivityObject}       = Kernel::System::ProcessManagement::Activity->new(%Param);
+    $Self->{ActivityDialogObject} = Kernel::System::ProcessManagement::ActivityDialog->new(%Param);
 
-    $Self->{TransitionObject} = Kernel::System::ProcessManagement::Transition->new(%Param);
-    $Self->{TransitionActionObject}
-        = Kernel::System::ProcessManagement::TransitionAction->new(%Param);
+    $Self->{TransitionObject}       = Kernel::System::ProcessManagement::Transition->new(%Param);
+    $Self->{TransitionActionObject} = Kernel::System::ProcessManagement::TransitionAction->new(%Param);
 
     $Self->{ProcessObject} = Kernel::System::ProcessManagement::Process->new(
         %Param,
@@ -164,7 +155,7 @@ sub Run {
     );
     my %AclAction = $Self->{TicketObject}->TicketAclActionData();
 
-    # check if ACL resctictions if exist
+    # check if ACL restrictions exist
     if ( IsHashRefWithData( \%AclAction ) ) {
 
         # show error screen if ACL prohibits this action
@@ -257,9 +248,8 @@ sub Run {
         # get params
         my $TicketID     = $Self->{ParamObject}->GetParam( Param => 'TicketID' );
         my $SaveDefaults = $Self->{ParamObject}->GetParam( Param => 'SaveDefaults' );
-        my @ArticleTypeFilterIDs = $Self->{ParamObject}->GetArray( Param => 'ArticleTypeFilter' );
-        my @ArticleSenderTypeFilterIDs
-            = $Self->{ParamObject}->GetArray( Param => 'ArticleSenderTypeFilter' );
+        my @ArticleTypeFilterIDs       = $Self->{ParamObject}->GetArray( Param => 'ArticleTypeFilter' );
+        my @ArticleSenderTypeFilterIDs = $Self->{ParamObject}->GetArray( Param => 'ArticleSenderTypeFilter' );
 
         # build session string
         my $SessionString = '';
@@ -399,7 +389,10 @@ sub Run {
     # generate output
     my $Output = $Self->{LayoutObject}->Header( Value => $Ticket{TicketNumber} );
     $Output .= $Self->{LayoutObject}->NavigationBar();
-    $Output .= $Self->MaskAgentZoom( Ticket => \%Ticket, AclAction => \%AclAction );
+    $Output .= $Self->MaskAgentZoom(
+        Ticket    => \%Ticket,
+        AclAction => \%AclAction
+    );
     $Output .= $Self->{LayoutObject}->Footer();
     return $Output;
 }
@@ -420,8 +413,7 @@ sub MaskAgentZoom {
     );
 
     # fetch all std. responses
-    my %StandardResponses
-        = $Self->{QueueObject}->GetStandardResponses( QueueID => $Ticket{QueueID} );
+    my %StandardResponses = $Self->{QueueObject}->GetStandardResponses( QueueID => $Ticket{QueueID} );
 
     # owner info
     my %OwnerInfo = $Self->{UserObject}->GetUserData(
@@ -643,7 +635,10 @@ sub MaskAgentZoom {
     }
 
     # age design
-    $Ticket{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Ticket{Age}, Space => ' ' );
+    $Ticket{Age} = $Self->{LayoutObject}->CustomerAge(
+        Age   => $Ticket{Age},
+        Space => ' '
+    );
 
     # number of articles
     $Param{ArticleCount} = scalar @ArticleBox;
@@ -690,8 +685,7 @@ sub MaskAgentZoom {
 
     # get MoveQueuesStrg
     if ( $Self->{ConfigObject}->Get('Ticket::Frontend::MoveType') =~ /^form$/i ) {
-        $MoveQueues{0}
-            = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Move') . ' -';
+        $MoveQueues{0} = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Move') . ' -';
         $Param{MoveQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
             Name           => 'DestQueueID',
             Data           => \%MoveQueues,
@@ -971,8 +965,8 @@ sub MaskAgentZoom {
             # to a regular array in correct order:
             # ('AD1', 'AD3', 'AD2')
 
-            my @TmpActivityDialogList
-                = map { $NextActivityDialogs->{$_} } sort keys %{$NextActivityDialogs};
+            my @TmpActivityDialogList = map { $NextActivityDialogs->{$_} }
+                sort { $a <=> $b } keys %{$NextActivityDialogs};
 
             # we have to check if the current user has the needed permissions to view the
             # different activity dialogs, so we loop over every activity dialog and check if there
@@ -982,11 +976,10 @@ sub MaskAgentZoom {
             my @PermissionActivityDialogList;
             ACTIVITYDIALOGPERMISSION:
             for my $CurrentActivityDialogEntityID (@TmpActivityDialogList) {
-                my $CurrentActivityDialog
-                    = $Self->{ActivityDialogObject}->ActivityDialogGet(
+                my $CurrentActivityDialog = $Self->{ActivityDialogObject}->ActivityDialogGet(
                     Interface              => 'AgentInterface',
                     ActivityDialogEntityID => $CurrentActivityDialogEntityID
-                    );
+                );
 
                 # create an interface lookuplist
                 my %InterfaceLookup = map { $_ => 1 } @{ $CurrentActivityDialog->{Interface} };
@@ -1014,10 +1007,9 @@ sub MaskAgentZoom {
 
             my @PossibleActivityDialogs;
             if (@PermissionActivityDialogList) {
-                @PossibleActivityDialogs
-                    = $Self->{TicketObject}->TicketAclActivityDialogData(
+                @PossibleActivityDialogs = $Self->{TicketObject}->TicketAclActivityDialogData(
                     ActivityDialogs => \@PermissionActivityDialogList
-                    );
+                );
             }
 
             # reformat the @PossibleActivityDialogs that is of the structure:
@@ -1026,8 +1018,7 @@ sub MaskAgentZoom {
             # e.g.:
             # 1 => 'AD1',
             # 2 => 'AD3',
-            %{$NextActivityDialogs}
-                = map { $_ => $PossibleActivityDialogs[ $_ - 1 ] }
+            %{$NextActivityDialogs} = map { $_ => $PossibleActivityDialogs[ $_ - 1 ] }
                 1 .. scalar @PossibleActivityDialogs;
 
             $Self->{LayoutObject}->Block(
@@ -1035,7 +1026,7 @@ sub MaskAgentZoom {
             );
 
             if ( IsHashRefWithData($NextActivityDialogs) ) {
-                for my $NextActivityDialogKey ( sort keys %{$NextActivityDialogs} ) {
+                for my $NextActivityDialogKey ( sort { $a <=> $b } keys %{$NextActivityDialogs} ) {
                     my $ActivityDialogData = $Self->{ActivityDialogObject}->ActivityDialogGet(
                         Interface              => 'AgentInterface',
                         ActivityDialogEntityID => $NextActivityDialogs->{$NextActivityDialogKey},
@@ -1078,14 +1069,6 @@ sub MaskAgentZoom {
         next DYNAMICFIELD if !defined $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} };
         next DYNAMICFIELD if $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} } eq '';
 
-        # get print string for this dynamic field
-        # do not use ValueMaxChars here otherwise values will be trimmed also in Process Widget
-        my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
-            DynamicFieldConfig => $DynamicFieldConfig,
-            Value              => $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
-            LayoutObject       => $Self->{LayoutObject},
-        );
-
         # use translation here to be able to reduce the character length in the template
         my $Label = $Self->{LayoutObject}->{LanguageObject}->Get( $DynamicFieldConfig->{Label} );
 
@@ -1094,6 +1077,14 @@ sub MaskAgentZoom {
             $Self->{DisplaySettings}->{ProcessWidgetDynamicField}->{ $DynamicFieldConfig->{Name} }
             )
         {
+            my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+                DynamicFieldConfig => $DynamicFieldConfig,
+                Value              => $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+                LayoutObject       => $Self->{LayoutObject},
+
+                # no ValueMaxChars here, enough space available
+            );
+
             push @FieldsWidget, {
                 Name  => $DynamicFieldConfig->{Name},
                 Title => $ValueStrg->{Title},
@@ -1106,21 +1097,21 @@ sub MaskAgentZoom {
             };
         }
 
+        my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+            LayoutObject       => $Self->{LayoutObject},
+            ValueMaxChars      => 18,                                                        # limit for sidebar display
+        );
+
         if (
             $Self->{DisplaySettings}->{DynamicField}->{ $DynamicFieldConfig->{Name} }
             )
         {
-            my $TrimmedValue = $ValueStrg->{Value};
-
-            # trim the value so it can fit better in the sidebar
-            if ( length $ValueStrg->{Value} > 18 ) {
-                $TrimmedValue = substr( $ValueStrg->{Value}, 0, 18 ) . '...';
-            }
-
             push @FieldsSidebar, {
                 Name                        => $DynamicFieldConfig->{Name},
                 Title                       => $ValueStrg->{Title},
-                Value                       => $TrimmedValue,
+                Value                       => $ValueStrg->{Value},
                 Label                       => $Label,
                 Link                        => $ValueStrg->{Link},
                 $DynamicFieldConfig->{Name} => $ValueStrg->{Title},
@@ -1157,8 +1148,7 @@ sub MaskAgentZoom {
                 Name => 'ProcessWidgetDynamicFieldGroups',
             );
 
-            my $GroupFieldsString
-                = $Self->{DisplaySettings}->{ProcessWidgetDynamicFieldGroups}->{$GroupName};
+            my $GroupFieldsString = $Self->{DisplaySettings}->{ProcessWidgetDynamicFieldGroups}->{$GroupName};
 
             $GroupFieldsString =~ s{\s}{}xmsg;
             my @GroupFields = split( ',', $GroupFieldsString );
@@ -1187,6 +1177,10 @@ sub MaskAgentZoom {
                             $Self->{LayoutObject}->Block(
                                 Name => 'ProcessWidgetDynamicFieldLink',
                                 Data => {
+                                    %Ticket,
+
+                                    # alias for ticket title, Title will be overwritten
+                                    TicketTitle    => $Ticket{Title},
                                     Value          => $Field->{Value},
                                     Title          => $Field->{Title},
                                     Link           => $Field->{Link},
@@ -1258,6 +1252,10 @@ sub MaskAgentZoom {
                 $Self->{LayoutObject}->Block(
                     Name => 'ProcessWidgetDynamicFieldLink',
                     Data => {
+                        %Ticket,
+
+                        # alias for ticket title, Title will be overwritten
+                        TicketTitle    => $Ticket{Title},
                         Value          => $Field->{Value},
                         Title          => $Field->{Title},
                         Link           => $Field->{Link},
@@ -1291,6 +1289,10 @@ sub MaskAgentZoom {
             $Self->{LayoutObject}->Block(
                 Name => 'TicketDynamicFieldLink',
                 Data => {
+                    %Ticket,
+
+                    # alias for ticket title, Title will be overwritten
+                    TicketTitle    => $Ticket{Title},
                     Value          => $Field->{Value},
                     Title          => $Field->{Title},
                     Link           => $Field->{Link},
@@ -1445,7 +1447,7 @@ sub MaskAgentZoom {
     # return output
     return $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentTicketZoom',
-        Data => { %Param, %Ticket, %AclAction },
+        Data         => { %Param, %Ticket, %AclAction },
     );
 }
 
@@ -1601,7 +1603,7 @@ sub _ArticleTree {
 
         my $TmpSubject = $Self->{TicketObject}->TicketSubjectClean(
             TicketNumber => $Article{TicketNumber},
-            Subject => $Article{Subject} || '',
+            Subject      => $Article{Subject} || '',
         );
 
         # check if we need to show also expand/collapse icon
@@ -1672,9 +1674,8 @@ sub _ArticleTree {
         if ( $Type =~ /inline/i ) {
             $Target = 'target="attachment" ';
         }
-        my $ZoomAttachmentDisplayCount
-            = $Self->{ConfigObject}->Get('Ticket::ZoomAttachmentDisplayCount');
-        my $CountShown = 0;
+        my $ZoomAttachmentDisplayCount = $Self->{ConfigObject}->Get('Ticket::ZoomAttachmentDisplayCount');
+        my $CountShown                 = 0;
         ATTACHMENT:
         for my $Count ( 1 .. ( $ZoomAttachmentDisplayCount + 2 ) ) {
             next ATTACHMENT if !$Article{Atms}->{$Count};
@@ -1726,7 +1727,7 @@ sub _ArticleTree {
     # return output
     return $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentTicketZoom',
-        Data => { %Param, %Ticket },
+        Data         => { %Param, %Ticket },
     );
 }
 
@@ -1770,7 +1771,7 @@ sub _ArticleItem {
     # cleanup subject
     $Article{Subject} = $Self->{TicketObject}->TicketSubjectClean(
         TicketNumber => $Article{TicketNumber},
-        Subject => $Article{Subject} || '',
+        Subject      => $Article{Subject} || '',
     );
 
     $Self->{LayoutObject}->Block(
@@ -1853,8 +1854,7 @@ sub _ArticleItem {
             if ($Access) {
 
                 # get StandardResponsesStrg
-                $Param{StandardResponses}->{0}
-                    = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Reply') . ' -';
+                $Param{StandardResponses}->{0} = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Reply') . ' -';
 
                 # build html string
                 my $StandardResponsesStrg = $Self->{LayoutObject}->BuildSelection(
@@ -2106,8 +2106,7 @@ sub _ArticleItem {
             LogNo    => 1,
         );
         if ($OK) {
-            my $Link
-                = 'Action=AgentTicketPlain;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"}';
+            my $Link = 'Action=AgentTicketPlain;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"}';
             $Self->{LayoutObject}->Block(
                 Name => 'ArticleMenu',
                 Data => {
@@ -2196,6 +2195,10 @@ sub _ArticleItem {
             $Self->{LayoutObject}->Block(
                 Name => 'ArticleDynamicFieldLink',
                 Data => {
+                    %Ticket,
+
+                    # alias for ticket title, Title will be overwritten
+                    TicketTitle                 => $Ticket{Title},
                     Value                       => $ValueStrg->{Value},
                     Title                       => $ValueStrg->{Title},
                     Link                        => $ValueStrg->{Link},
@@ -2231,6 +2234,10 @@ sub _ArticleItem {
             $Self->{LayoutObject}->Block(
                 Name => 'ArticleDynamicField' . $DynamicFieldConfig->{Name} . 'Link',
                 Data => {
+                    %Ticket,
+
+                    # alias for ticket title, Title will be overwritten
+                    TicketTitle                 => $Ticket{Title},
                     Value                       => $ValueStrg->{Value},
                     Title                       => $ValueStrg->{Title},
                     Link                        => $ValueStrg->{Link},
@@ -2268,7 +2275,10 @@ sub _ArticleItem {
             );
 
             # run module
-            my @Data = $Object->Check( Article => \%Article, %Ticket, Config => $Jobs{$Job} );
+            my @Data = $Object->Check(
+                Article => \%Article,
+                %Ticket, Config => $Jobs{$Job}
+            );
             for my $DataRef (@Data) {
                 if ( !$DataRef->{Successful} ) {
                     $DataRef->{Result} = 'Error';
@@ -2290,7 +2300,10 @@ sub _ArticleItem {
             }
 
             # filter option
-            $Object->Filter( Article => \%Article, %Ticket, Config => $Jobs{$Job} );
+            $Object->Filter(
+                Article => \%Article,
+                %Ticket, Config => $Jobs{$Job}
+            );
         }
     }
 
@@ -2407,7 +2420,7 @@ sub _ArticleItem {
     # return output
     return $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentTicketZoom',
-        Data => { %Param, %Ticket, %AclAction },
+        Data         => { %Param, %Ticket, %AclAction },
     );
 }
 1;
