@@ -46,19 +46,16 @@ sub new {
     $Self->{SmallViewColumnHeader}
         = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverview')->{ColumnHeader};
 
-    $Self->{Owner}
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverview')->{Owner};
+    $Self->{Owner} = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverview')->{Owner};
 
-    $Self->{Queue}
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverview')->{Queue};
+    $Self->{Queue} = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverview')->{Queue};
 
     # get dynamic field config for frontend module
     $Self->{DynamicFieldFilter}
         = $Self->{ConfigObject}->Get("Ticket::Frontend::CustomerTicketOverview")->{DynamicField};
 
     # disable output of customer company tickets
-    $Self->{DisableCompanyTickets}
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerDisableCompanyTicketAccess');
+    $Self->{DisableCompanyTickets} = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerDisableCompanyTicketAccess');
 
     # get the dynamic fields for this screen
     $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
@@ -117,32 +114,35 @@ sub Run {
                 Name   => 'All',
                 Prio   => 1000,
                 Search => {
-                    OrderBy        => $Self->{OrderBy},
-                    SortBy         => $Self->{SortBy},
-                    CustomerUserID => $Self->{UserID},
-                    Permission     => 'ro',
+                    CustomerUserLogin => $Self->{UserID},
+                    OrderBy           => $Self->{OrderBy},
+                    SortBy            => $Self->{SortBy},
+                    CustomerUserID    => $Self->{UserID},
+                    Permission        => 'ro',
                 },
             },
             Open => {
                 Name   => 'Open',
                 Prio   => 1100,
                 Search => {
-                    StateType      => 'Open',
-                    OrderBy        => $Self->{OrderBy},
-                    SortBy         => $Self->{SortBy},
-                    CustomerUserID => $Self->{UserID},
-                    Permission     => 'ro',
+                    CustomerUserLogin => $Self->{UserID},
+                    StateType         => 'Open',
+                    OrderBy           => $Self->{OrderBy},
+                    SortBy            => $Self->{SortBy},
+                    CustomerUserID    => $Self->{UserID},
+                    Permission        => 'ro',
                 },
             },
             Closed => {
                 Name   => 'Closed',
                 Prio   => 1200,
                 Search => {
-                    StateType      => 'Closed',
-                    OrderBy        => $Self->{OrderBy},
-                    SortBy         => $Self->{SortBy},
-                    CustomerUserID => $Self->{UserID},
-                    Permission     => 'ro',
+                    CustomerUserLogin => $Self->{UserID},
+                    StateType         => 'Closed',
+                    OrderBy           => $Self->{OrderBy},
+                    SortBy            => $Self->{SortBy},
+                    CustomerUserID    => $Self->{UserID},
+                    Permission        => 'ro',
                 },
             },
         },
@@ -262,8 +262,7 @@ sub Run {
             Name => 'Empty',
         );
 
-        my $CustomTexts
-            = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverviewCustomEmptyText');
+        my $CustomTexts = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverviewCustomEmptyText');
 
         if ( ref $CustomTexts eq 'HASH' ) {
             $Self->{LayoutObject}->Block(
@@ -276,8 +275,8 @@ sub Run {
             if (
                 ref $Self->{ConfigObject}->Get('CustomerFrontend::Module')->{CustomerTicketMessage}
                 eq 'HASH'
-                && defined $Self->{ConfigObject}
-                ->Get('Ticket::Frontend::CustomerTicketOverviewCustomEmptyText')->{Button}
+                && defined $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerTicketOverviewCustomEmptyText')
+                ->{Button}
                 )
             {
                 $Self->{LayoutObject}->Block(
@@ -635,22 +634,26 @@ sub ShowTicketStatus {
     if ($NoArticle) {
         $Article{State}        = $Ticket{State};
         $Article{TicketNumber} = $Ticket{TicketNumber};
-        $Article{CustomerAge}
-            = $Self->{LayoutObject}->CustomerAge( Age => $Ticket{Age}, Space => ' ' ) || 0;
-        $Article{Body}
-            = $Self->{LayoutObject}->{LanguageObject}->Get('This item has no articles yet.');
+        $Article{CustomerAge}  = $Self->{LayoutObject}->CustomerAge(
+            Age   => $Ticket{Age},
+            Space => ' '
+        ) || 0;
+        $Article{Body} = $Self->{LayoutObject}->{LanguageObject}->Get('This item has no articles yet.');
     }
 
     # otherwise return article information
     else {
-        $Article{CustomerAge}
-            = $Self->{LayoutObject}->CustomerAge( Age => $Article{Age}, Space => ' ' ) || 0;
+        $Article{CustomerAge} = $Self->{LayoutObject}->CustomerAge(
+            Age   => $Article{Age},
+            Space => ' '
+        ) || 0;
     }
 
     # customer info (customer name)
     if ( $Article{CustomerUserID} ) {
-        $Param{CustomerName}
-            = $Self->{UserObject}->CustomerName( UserLogin => $Article{CustomerUserID}, );
+        $Param{CustomerName} = $Self->{UserObject}->CustomerName(
+            UserLogin => $Article{CustomerUserID},
+        );
         $Param{CustomerName} = '(' . $Param{CustomerName} . ')' if ( $Param{CustomerName} );
     }
 
