@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/CustomerTicketProcess.pm - to create process tickets
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -43,16 +43,15 @@ sub new {
         }
     }
 
-    $Self->{UploadCacheObject}    = Kernel::System::Web::UploadCache->new(%Param);
-    $Self->{UserObject}           = Kernel::System::User->new(%Param);
-    $Self->{ActivityObject}       = Kernel::System::ProcessManagement::Activity->new(%Param);
-    $Self->{ActivityDialogObject} = Kernel::System::ProcessManagement::ActivityDialog->new(%Param);
-    $Self->{TransitionActionObject}
-        = Kernel::System::ProcessManagement::TransitionAction->new(%Param);
-    $Self->{TransitionObject}   = Kernel::System::ProcessManagement::Transition->new(%Param);
-    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
-    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
-    $Self->{ProcessObject}      = Kernel::System::ProcessManagement::Process->new(
+    $Self->{UploadCacheObject}      = Kernel::System::Web::UploadCache->new(%Param);
+    $Self->{UserObject}             = Kernel::System::User->new(%Param);
+    $Self->{ActivityObject}         = Kernel::System::ProcessManagement::Activity->new(%Param);
+    $Self->{ActivityDialogObject}   = Kernel::System::ProcessManagement::ActivityDialog->new(%Param);
+    $Self->{TransitionActionObject} = Kernel::System::ProcessManagement::TransitionAction->new(%Param);
+    $Self->{TransitionObject}       = Kernel::System::ProcessManagement::Transition->new(%Param);
+    $Self->{DynamicFieldObject}     = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}          = Kernel::System::DynamicField::Backend->new(%Param);
+    $Self->{ProcessObject}          = Kernel::System::ProcessManagement::Process->new(
         ActivityObject         => $Self->{ActivityObject},
         ActivityDialogObject   => $Self->{ActivityDialogObject},
         TransitionObject       => $Self->{TransitionObject},
@@ -76,9 +75,8 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $TicketID = $Self->{ParamObject}->GetParam( Param => 'TicketID' );
-    my $ActivityDialogEntityID
-        = $Self->{ParamObject}->GetParam( Param => 'ActivityDialogEntityID' );
+    my $TicketID               = $Self->{ParamObject}->GetParam( Param => 'TicketID' );
+    my $ActivityDialogEntityID = $Self->{ParamObject}->GetParam( Param => 'ActivityDialogEntityID' );
     my $ActivityDialogHashRef;
 
     # get all processes even those that can not be started in the Customer Interface
@@ -87,7 +85,7 @@ sub Run {
     # possible to access valid customer activity dialogs)
     my $ProcessList = $Self->{ProcessObject}->ProcessList(
         ProcessState => [ 'Active', 'FadeAway' ],
-        Interface => 'all',
+        Interface    => 'all',
     );
     my $ProcessEntityID = $Self->{ParamObject}->GetParam( Param => 'ProcessEntityID' );
 
@@ -109,11 +107,10 @@ sub Run {
     # for the ActivityDialog (if there is one)
     my $ActivityDialogPermission = 'rw';
     if ($ActivityDialogEntityID) {
-        $ActivityDialogHashRef
-            = $Self->{ActivityDialogObject}->ActivityDialogGet(
+        $ActivityDialogHashRef = $Self->{ActivityDialogObject}->ActivityDialogGet(
             ActivityDialogEntityID => $ActivityDialogEntityID,
             Interface              => 'CustomerInterface',
-            );
+        );
 
         if ( !IsHashRefWithData($ActivityDialogHashRef) ) {
             $Self->{LayoutObject}->CustomerFatalError(
@@ -175,10 +172,9 @@ sub Run {
             CustomerUserID         => $Self->{UserID},
         );
 
-        my @PossibleActivityDialogs
-            = $Self->{TicketObject}->TicketAclActivityDialogData(
+        my @PossibleActivityDialogs = $Self->{TicketObject}->TicketAclActivityDialogData(
             ActivityDialogs => [ $ActivityDialogEntityID, ]
-            );
+        );
 
         # check if ACL resctictions exist
         if (
@@ -227,7 +223,7 @@ sub Run {
     }
 
     if ( $Self->{Subaction} eq 'StoreActivityDialog' && $ProcessEntityID ) {
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck( Type => 'Customer' );
 
         return $Self->_StoreActivityDialog(
             %Param,
@@ -293,11 +289,10 @@ sub _RenderAjax {
             Message => "Got no ActivityDialogEntityID in _RenderAjax!"
         );
     }
-    my $ActivityDialog
-        = $Self->{ActivityDialogObject}->ActivityDialogGet(
+    my $ActivityDialog = $Self->{ActivityDialogObject}->ActivityDialogGet(
         ActivityDialogEntityID => $ActivityDialogEntityID,
         Interface              => 'CustomerInterface',
-        );
+    );
     if ( !IsHashRefWithData($ActivityDialog) ) {
         $Self->{LayoutObject}->CustomerFatalError(
             Message => "No ActivityDialog configured for $ActivityDialogEntityID in _RenderAjax!"
@@ -317,6 +312,7 @@ sub _RenderAjax {
     # used for ACL checking
     my %DynamicFieldCheckParam = map { $_ => $Param{GetParam}{$_} }
         grep {m{^DynamicField_}xms} ( keys %{ $Param{GetParam} } );
+    $Param{GetParam}->{DynamicField} = \%DynamicFieldCheckParam;
 
     # Get the activity dialog's Submit Param's or Config Params
     DIALOGFIELD:
@@ -334,8 +330,7 @@ sub _RenderAjax {
         if ( $CurrentField =~ m{^DynamicField_(.*)}xms ) {
             my $DynamicFieldName = $1;
 
-            my $DynamicFieldConfig
-                = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
+            my $DynamicFieldConfig = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
 
             next DIALOGFIELD if !IsHashRefWithData($DynamicFieldConfig);
             next DIALOGFIELD if !$Self->{BackendObject}->IsAJAXUpdateable(
@@ -345,8 +340,6 @@ sub _RenderAjax {
             my $PossibleValues = $Self->{BackendObject}->AJAXPossibleValuesGet(
                 DynamicFieldConfig => $DynamicFieldConfig,
             );
-            my %DynamicFieldCheckParam = map { $_ => $Param{GetParam}{$_} }
-                grep {m{^DynamicField_}xms} ( keys %{ $Param{GetParam} } );
 
             # convert possible values key => value to key => key for ACLs usign a Hash slice
             my %AclData = %{$PossibleValues};
@@ -355,7 +348,6 @@ sub _RenderAjax {
             # set possible values filter from ACLs
             my $ACL = $Self->{TicketObject}->TicketAcl(
                 %{ $Param{GetParam} },
-                DynamicField   => \%DynamicFieldCheckParam,
                 ReturnType     => 'Ticket',
                 ReturnSubType  => 'DynamicField_' . $DynamicFieldConfig->{Name},
                 Data           => \%AclData,
@@ -373,24 +365,23 @@ sub _RenderAjax {
             push(
                 @JSONCollector,
                 {
-                    Name       => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data       => $PossibleValues,
-                    SelectedID => $Param{GetParam}{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+                    Name        => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                    Data        => $PossibleValues,
+                    SelectedID  => $Param{GetParam}{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
                     Translation => $DynamicFieldConfig->{Config}->{TranslatableValues} || 0,
                     Max         => 100,
                 }
             );
         }
-
-        my $JSON = $Self->{LayoutObject}->BuildSelectionJSON( [@JSONCollector] );
-
-        return $Self->{LayoutObject}->Attachment(
-            ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
-            Content     => $JSON,
-            Type        => 'inline',
-            NoCache     => 1,
-        );
     }
+    my $JSON = $Self->{LayoutObject}->BuildSelectionJSON( [@JSONCollector] );
+
+    return $Self->{LayoutObject}->Attachment(
+        ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
+        Content     => $JSON,
+        Type        => 'inline',
+        NoCache     => 1,
+    );
 }
 
 =item _GetParam()
@@ -442,10 +433,9 @@ sub _GetParam {
     }
     my %GetParam;
     my %Ticket;
-    my $ProcessEntityID = $Param{ProcessEntityID};
-    my $TicketID = $Self->{ParamObject}->GetParam( Param => 'TicketID' );
-    my $ActivityDialogEntityID
-        = $Self->{ParamObject}->GetParam( Param => 'ActivityDialogEntityID' );
+    my $ProcessEntityID        = $Param{ProcessEntityID};
+    my $TicketID               = $Self->{ParamObject}->GetParam( Param => 'TicketID' );
+    my $ActivityDialogEntityID = $Self->{ParamObject}->GetParam( Param => 'ActivityDialogEntityID' );
     my $ActivityEntityID;
     my %ValuesGotten;
     my $Value;
@@ -479,11 +469,10 @@ sub _GetParam {
         $ActivityEntityID       = $ActivityActivityDialog->{Activity};
     }
 
-    my $ActivityDialog
-        = $Self->{ActivityDialogObject}->ActivityDialogGet(
+    my $ActivityDialog = $Self->{ActivityDialogObject}->ActivityDialogGet(
         ActivityDialogEntityID => $ActivityDialogEntityID,
         Interface              => 'CustomerInterface',
-        );
+    );
 
     if ( !IsHashRefWithData($ActivityDialog) ) {
         $Self->{LayoutObject}->CustomerFatalError(
@@ -534,9 +523,8 @@ sub _GetParam {
         if ( $CurrentField =~ m{^DynamicField_(.*)}xms ) {
             my $DynamicFieldName = $1;
 
-           # Get the Config of the current DynamicField (the first element of the grep result array)
-            my $DynamicFieldConfig
-                = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
+            # Get the Config of the current DynamicField (the first element of the grep result array)
+            my $DynamicFieldConfig = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
 
             if ( !IsHashRefWithData($DynamicFieldConfig) ) {
                 my $Message = "DynamicFieldConfig missing for field: $DynamicFieldName!";
@@ -653,8 +641,7 @@ sub _OutputActivityDialog {
 
     my $DynamicFieldProcessID = 'DynamicField_'
         . $Self->{ConfigObject}->Get('Process::DynamicFieldProcessManagementProcessID');
-    my $DynamicFieldActivityID
-        = 'DynamicField_'
+    my $DynamicFieldActivityID = 'DynamicField_'
         . $Self->{ConfigObject}->Get(
         'Process::DynamicFieldProcessManagementActivityID'
         );
@@ -804,10 +791,10 @@ sub _OutputActivityDialog {
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'ProcessManagement/CustomerActivityDialogHeader',
         Data         => {
-            FormName  => 'ActivityDialogDialog' . $ActivityActivityDialog->{ActivityDialog},
-            FormID    => $Self->{FormID},
-            Subaction => 'StoreActivityDialog',
-            TicketID  => $Ticket{TicketID},
+            FormName               => 'ActivityDialogDialog' . $ActivityActivityDialog->{ActivityDialog},
+            FormID                 => $Self->{FormID},
+            Subaction              => 'StoreActivityDialog',
+            TicketID               => $Ticket{TicketID},
             ActivityDialogEntityID => $ActivityActivityDialog->{ActivityDialog},
             ProcessEntityID        => $Param{ProcessEntityID}
                 || $Ticket{
@@ -1007,8 +994,7 @@ sub _RenderDynamicField {
             };
         }
     }
-    my $DynamicFieldConfig
-        = ( grep { $_->{Name} eq $Param{FieldName} } @{ $Self->{DynamicField} } )[0];
+    my $DynamicFieldConfig = ( grep { $_->{Name} eq $Param{FieldName} } @{ $Self->{DynamicField} } )[0];
 
     my $PossibleValuesFilter;
 
@@ -1038,8 +1024,7 @@ sub _RenderDynamicField {
             my %Filter = $Self->{TicketObject}->TicketAclData();
 
             # convert Filer key => key back to key => value using map
-            %{$PossibleValuesFilter}
-                = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} } keys %Filter;
+            %{$PossibleValuesFilter} = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} } keys %Filter;
         }
     }
 
@@ -1076,7 +1061,7 @@ sub _RenderDynamicField {
 
     return {
         Success => 1,
-        HTML => $Self->{LayoutObject}->Output( TemplateFile => 'ProcessManagement/DynamicField' ),
+        HTML    => $Self->{LayoutObject}->Output( TemplateFile => 'ProcessManagement/DynamicField' ),
     };
 
     return '';
@@ -1101,8 +1086,7 @@ sub _RenderArticle {
         };
     }
 
-    my $ArticleInvalid
-        = ( IsHashRefWithData( $Param{Error} ) && $Param{Error}->{'Article'} )
+    my $ArticleInvalid = ( IsHashRefWithData( $Param{Error} ) && $Param{Error}->{'Article'} )
         ? $Param{Error}->{'Article'}
         : '';
 
@@ -1186,7 +1170,7 @@ sub _RenderArticle {
 
     return {
         Success => 1,
-        HTML => $Self->{LayoutObject}->Output( TemplateFile => 'ProcessManagement/Article' ),
+        HTML    => $Self->{LayoutObject}->Output( TemplateFile => 'ProcessManagement/Article' ),
     };
 }
 
@@ -1209,11 +1193,10 @@ sub _StoreActivityDialog {
         );
     }
 
-    my $ActivityDialog
-        = $Self->{ActivityDialogObject}->ActivityDialogGet(
+    my $ActivityDialog = $Self->{ActivityDialogObject}->ActivityDialogGet(
         ActivityDialogEntityID => $ActivityDialogEntityID,
         Interface              => 'CustomerInterface',
-        );
+    );
     if ( !IsHashRefWithData($ActivityDialog) ) {
         $Self->{LayoutObject}->CustomerFatalError(
             Message => "Couldn't get Config for ActivityDialogEntityID $ActivityDialogEntityID!",
@@ -1252,16 +1235,15 @@ sub _StoreActivityDialog {
         );
     }
 
-   # check each Field of an Activity Dialog and fill the error hash if something goes horribly wrong
+    # check each Field of an Activity Dialog and fill the error hash if something goes horribly wrong
     my %CheckedFields;
     DIALOGFIELD:
     for my $CurrentField ( @{ $ActivityDialog->{FieldOrder} } ) {
         if ( $CurrentField =~ m{^DynamicField_(.*)}xms ) {
             my $DynamicFieldName = $1;
 
-           # Get the Config of the current DynamicField (the first element of the grep result array)
-            my $DynamicFieldConfig
-                = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
+            # Get the Config of the current DynamicField (the first element of the grep result array)
+            my $DynamicFieldConfig = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
 
             if ( !IsHashRefWithData($DynamicFieldConfig) ) {
                 $Self->{LayoutObject}->CustomerFatalError(
@@ -1398,8 +1380,7 @@ sub _StoreActivityDialog {
 
         if ( $CurrentField =~ m{^DynamicField_(.*)}xms ) {
             my $DynamicFieldName = $1;
-            my $DynamicFieldConfig
-                = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
+            my $DynamicFieldConfig = ( grep { $_->{Name} eq $DynamicFieldName } @{ $Self->{DynamicField} } )[0];
 
             my $Success = $Self->{BackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldConfig,
