@@ -1,8 +1,6 @@
 # --
 # Kernel/Output/HTML/LayoutAJAX.pm - provides generic HTML output
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: LayoutAJAX.pm,v 1.29 2011-12-09 02:50:26 cr Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,8 +12,7 @@ package Kernel::Output::HTML::LayoutAJAX;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.29 $) [1];
+use vars qw(@ISA);
 
 =item BuildSelectionJSON()
 
@@ -50,7 +47,10 @@ sub BuildSelectionJSON {
         # check needed stuff
         for (qw(Name Data)) {
             if ( !defined $Param{$_} ) {
-                $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => "Need $_!"
+                );
                 return;
             }
         }
