@@ -1,8 +1,6 @@
 # --
 # Kernel/Output/HTML/LayoutLinkObject.pm - provides generic HTML output for LinkObject
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: LayoutLinkObject.pm,v 1.29 2012/11/20 14:59:14 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +14,6 @@ use warnings;
 
 use Kernel::System::LinkObject;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.29 $) [1];
-
 =item LinkObjectTableCreate()
 
 create a output table
@@ -274,7 +269,7 @@ sub LinkObjectTableCreateComplex {
             Name => 'TableComplexBlock',
             Data => {
                 BlockDescription => $BlockDescription,
-                Blockname => $Block->{Blockname} || '',
+                Blockname        => $Block->{Blockname} || '',
             },
         );
 
@@ -393,7 +388,10 @@ sub LinkObjectTableCreateSimple {
 
     # check needed stuff
     if ( !$Param{LinkListWithData} || ref $Param{LinkListWithData} ne 'HASH' ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need LinkListWithData!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need LinkListWithData!'
+        );
         return;
     }
 
@@ -517,7 +515,10 @@ sub LinkObjectSelectableObjectList {
 
     # check needed stuff
     if ( !$Param{Object} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Object!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Object!'
+        );
         return;
     }
 
@@ -623,7 +624,10 @@ sub LinkObjectSearchOptionList {
 
     # check needed stuff
     if ( !$Param{Object} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Object!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Object!'
+        );
         return;
     }
 
