@@ -1,8 +1,6 @@
 # --
 # Kernel/Output/HTML/LayoutPopup.pm - provides generic HTML output
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: LayoutPopup.pm,v 1.8 2012/11/20 14:59:28 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,8 +12,7 @@ package Kernel::Output::HTML::LayoutPopup;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.8 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -54,7 +51,10 @@ sub PopupClose {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{URL} && !$Param{Reload} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need URL or Reload!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need URL or Reload!'
+        );
         return;
     }
 
@@ -99,9 +99,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.8 $ $Date: 2012/11/20 14:59:28 $
-
-=cut
