@@ -2,8 +2,6 @@
 # Kernel/System/CheckItem.pm - the global spelling module
 # Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: CheckItem.pm,v 1.41 2011-09-07 20:52:38 en Exp $
-# --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
@@ -14,8 +12,7 @@ package Kernel::System::CheckItem;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.41 $) [1];
+use Email::Valid;
 
 =head1 NAME
 
@@ -121,7 +118,10 @@ sub CheckEmail {
 
     # check needed stuff
     if ( !$Param{Address} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Address!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Address!'
+        );
         return;
     }
 
@@ -136,32 +136,7 @@ sub CheckEmail {
     my $Error = '';
 
     # email address syntax check
-    if (
-        $Param{Address}
-        !~ m{
-            ^
-            [a-zA-Z0-9_#]+
-            (?:
-                [a-zA-Z0-9_+\.&%-/=]*
-                [a-zA-Z0-9_'\.-]+
-            )?
-            @
-            (?:
-                (?:
-                    [a-zA-Z0-9]+
-                    ([a-zA-Z0-9\.-]*[a-zA-Z0-9]+)?
-                    \.+
-                    [a-zA-Z]{2,8}
-                )
-                |
-                (?:
-                    \d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}
-                )
-            )
-            $
-        }x
-        )
-    {
+    if ( !Email::Valid->address( $Param{Address} ) ) {
         $Error = "Invalid syntax";
         $Self->{ErrorType} = 'InvalidSyntax';
     }
@@ -177,7 +152,7 @@ sub CheckEmail {
     # mx check
     elsif (
         $Self->{ConfigObject}->Get('CheckMXRecord')
-        && eval { require Net::DNS }
+        && eval { require Net::DNS }    ## no critic
         )
     {
 
@@ -198,8 +173,8 @@ sub CheckEmail {
             }
 
             # A recorde lookup
-            my $packet = $Resolver->send( $Host, 'A' );
-            if ( !$packet ) {
+            my $Packet = $Resolver->send( $Host, 'A' );
+            if ( !$Packet ) {
                 $Self->{ErrorType} = 'InvalidDNS';
                 $Error = "DNS problem: " . $Resolver->errorstring();
                 $Self->{LogObject}->Log(
@@ -207,16 +182,16 @@ sub CheckEmail {
                     Message  => "DNS problem: " . $Resolver->errorstring(),
                 );
             }
-            elsif ( $packet->header->ancount() ) {
+            elsif ( $Packet->header()->ancount() ) {
 
                 # OK
-                # print STDERR "OK A $Host ".$packet->header->ancount()."\n";
+                # print STDERR "OK A $Host ".$Packet->header->ancount()."\n";
             }
 
             # mx recorde lookup
             else {
-                my $packet = $Resolver->send( $Host, 'MX' );
-                if ( !$packet ) {
+                my $Packet = $Resolver->send( $Host, 'MX' );
+                if ( !$Packet ) {
                     $Self->{ErrorType} = 'InvalidDNS';
                     $Error = "DNS problem: " . $Resolver->errorstring();
                     $Self->{LogObject}->Log(
@@ -224,10 +199,10 @@ sub CheckEmail {
                         Message  => "DNS problem: " . $Resolver->errorstring(),
                     );
                 }
-                elsif ( $packet->header->ancount() ) {
+                elsif ( $Packet->header()->ancount() ) {
 
                     # OK
-                    # print STDERR "OK MX $Host ".$packet->header->ancount()."\n";
+                    # print STDERR "OK MX $Host ".$Packet->header->ancount()."\n";
                 }
                 else {
                     $Error = "no mail exchanger (mx) found!";
@@ -364,9 +339,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.41 $ $Date: 2011-09-07 20:52:38 $
-
-=cut
