@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Crypt/SMIME.pm - the main crypt module
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,9 +12,6 @@ package Kernel::System::Crypt::SMIME;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.73 $) [1];
-
 =head1 NAME
 
 Kernel::System::Crypt::SMIME - smime crypt backend lib
@@ -122,7 +119,10 @@ sub Crypt {
     # check needed stuff
     for (qw(Message)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -145,11 +145,13 @@ sub Crypt {
     my ( $FHCrypted, $CryptedFile ) = $Self->{FileTempObject}->TempFile();
     close $FHCrypted;
 
-    my $Options
-        = "smime -encrypt -binary -des3 -in $PlainFile -out $CryptedFile $CertFile";
+    my $Options    = "smime -encrypt -binary -des3 -in $PlainFile -out $CryptedFile $CertFile";
     my $LogMessage = $Self->_CleanOutput(qx{$Self->{Cmd} $Options 2>&1});
     if ($LogMessage) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Can't crypt: $LogMessage!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Can't crypt: $LogMessage!"
+        );
         return;
     }
 
@@ -181,7 +183,10 @@ sub Decrypt {
     # check needed stuff
     for (qw(Message)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -213,8 +218,7 @@ sub Decrypt {
     print $FHSecret $Secret;
     close $FHSecret;
 
-    my $Options
-        = "smime -decrypt -in $CryptedFile -out $PlainFile -recip $CertFile -inkey $PrivateKeyFile"
+    my $Options = "smime -decrypt -in $CryptedFile -out $PlainFile -recip $CertFile -inkey $PrivateKeyFile"
         . " -passin file:$SecretFile";
     my $LogMessage = qx{$Self->{Cmd} $Options 2>&1};
     unlink $SecretFile;
@@ -232,7 +236,10 @@ sub Decrypt {
     }
 
     if ($LogMessage) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Can't decrypt: $LogMessage!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Can't decrypt: $LogMessage!"
+        );
         return (
             Successful => 0,
             Message    => $LogMessage,
@@ -277,7 +284,10 @@ sub Sign {
     # check needed stuff
     for (qw(Message)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -295,8 +305,7 @@ sub Sign {
     my ( $Private, $Secret ) = $Self->PrivateGet(%Attributes);
 
     # get the related certificates
-    my @RelatedCertificates
-        = $Self->SignerCertRelationGet( CertFingerprint => $Attributes{Fingerprint} );
+    my @RelatedCertificates = $Self->SignerCertRelationGet( CertFingerprint => $Attributes{Fingerprint} );
 
     my $FHCACertFileActive;
     my ( $FHCACertFile, $CAFileName ) = $Self->{FileTempObject}->TempFile();
@@ -333,8 +342,7 @@ sub Sign {
     print $FHSecret $Secret;
     close $FHSecret;
 
-    my $Options
-        = "smime -sign -in $PlainFile -out $SignFile -signer $CertFile -inkey $PrivateKeyFile"
+    my $Options = "smime -sign -in $PlainFile -out $SignFile -signer $CertFile -inkey $PrivateKeyFile"
         . " -text -binary -passin file:$SecretFile";
 
     # add the certfile parameter
@@ -391,7 +399,10 @@ sub Verify {
 
     # check needed stuff
     if ( !$Param{Message} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need Message!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need Message!"
+        );
         return;
     }
 
@@ -410,8 +421,7 @@ sub Verify {
         $CertificateOption = "-CAfile $Param{CACert}";
     }
 
-    my $Options
-        = "smime -verify -in $SignedFile -out $VerifiedFile -signer $SignerFile "
+    my $Options = "smime -verify -in $SignedFile -out $VerifiedFile -signer $SignerFile "
         . "-CApath $Self->{CertPath} $CertificateOption $SignedFile";
 
     my @LogLines = qx{$Self->{Cmd} $Options 2>&1};
@@ -526,11 +536,13 @@ sub CertificateSearch {
 
     for my $Filename (@CertList) {
         my $Certificate = $Self->CertificateGet( Filename => $Filename );
-        my %Attributes = $Self->CertificateAttributes( Certificate => $Certificate, );
+        my %Attributes = $Self->CertificateAttributes(
+            Certificate => $Certificate,
+        );
         my $Hit = 0;
         if ($Search) {
             for my $Attribute ( sort keys %Attributes ) {
-                if ( $Attributes{$Attribute} =~ m{\Q$Search\E}xms ) {
+                if ( $Attributes{$Attribute} =~ m{\Q$Search\E}ixms ) {
                     $Hit = 1;
                 }
             }
@@ -564,10 +576,15 @@ sub CertificateAdd {
 
     # check needed stuff
     if ( !$Param{Certificate} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Certificate!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Certificate!'
+        );
         return;
     }
-    my %Attributes = $Self->CertificateAttributes( Certificate => $Param{Certificate}, );
+    my %Attributes = $Self->CertificateAttributes(
+        Certificate => $Param{Certificate},
+    );
     my %Result;
 
     if ( !$Attributes{Hash} ) {
@@ -619,7 +636,10 @@ sub CertificateAdd {
             return %Result;
         }
 
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Can't write $File: $!!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Can't write $File: $!!"
+        );
         %Result = (
             Successful => 0,
             Message    => "Can't write $File: $!!",
@@ -735,7 +755,7 @@ sub CertificateRemove {
     # remove certificate
     my $Cert = unlink "$Self->{CertPath}/$Param{Filename}";
     if ( !$Cert ) {
-        $Message = "Impossible to remove certificate: $Self->{CertPath}/$Param{Filename}: $!!",
+        $Message       = "Impossible to remove certificate: $Self->{CertPath}/$Param{Filename}: $!!",
             $Succesful = 0;
     }
 
@@ -792,7 +812,10 @@ sub CertificateAttributes {
 
     my %Attributes;
     if ( !$Param{Certificate} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Certificate!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Certificate!'
+        );
         return;
     }
     my ( $FH, $Filename ) = $Self->{FileTempObject}->TempFile();
@@ -895,7 +918,7 @@ sub PrivateSearch {
         my $Hit = 0;
         if ($Search) {
             for my $Attribute ( sort keys %Attributes ) {
-                if ( $Attributes{$Attribute} =~ m{\Q$Search\E}xms ) {
+                if ( $Attributes{$Attribute} =~ m{\Q$Search\E}ixms ) {
                     $Hit = 1;
                 }
             }
@@ -929,7 +952,10 @@ sub PrivateAdd {
     # check needed stuff
     for my $Needed (qw(Private Secret)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -939,7 +965,10 @@ sub PrivateAdd {
     # get private attributes
     my %Attributes = $Self->PrivateAttributes(%Param);
     if ( !$Attributes{Modulus} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'No Private Key!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'No Private Key!'
+        );
         %Result = (
             Successful => 0,
             Message    => 'No private key',
@@ -992,7 +1021,10 @@ sub PrivateAdd {
             return %Result;
         }
         else {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Can't write $File: $!!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Can't write $File: $!!"
+            );
             %Result = (
                 Successful => 0,
                 Message    => "Can't write $File: $!!",
@@ -1000,7 +1032,10 @@ sub PrivateAdd {
             return %Result;
         }
     }
-    $Self->{LogObject}->Log( Priority => 'error', Message => 'Can\'t add invalid private key!' );
+    $Self->{LogObject}->Log(
+        Priority => 'error',
+        Message  => 'Can\'t add invalid private key!'
+    );
     %Result = (
         Successful => 0,
         Message    => 'Can\'t add invalid private key!',
@@ -1187,13 +1222,18 @@ sub PrivateAttributes {
 
     for my $Needed (qw(Private Secret)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
 
     my %Attributes;
-    my %Option = ( Modulus => '-modulus', );
+    my %Option = (
+        Modulus => '-modulus',
+    );
     my ( $FH, $Filename ) = $Self->{FileTempObject}->TempFile();
     print $FH $Param{Private};
     close $FH;
@@ -1229,7 +1269,10 @@ sub SignerCertRelationAdd {
     # check needed stuff
     for my $Needed (qw( CertFingerprint CAFingerprint UserID )) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -1304,7 +1347,10 @@ sub SignerCertRelationGet {
 
     # check needed stuff
     if ( !$Param{ID} && !$Param{CertFingerprint} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Needed ID or CertFingerprint!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Needed ID or CertFingerprint!'
+        );
         return;
     }
 
@@ -1416,7 +1462,7 @@ sub SignerCertRelationExists {
         my $Success = $Self->{DBObject}->Prepare(
             SQL => 'SELECT id FROM smime_signer_cert_relations '
                 . 'WHERE cert_fingerprint = ? AND ca_fingerprint = ?',
-            Bind => [ \$Param{CertFingerprint}, \$Param{CAFingerprint} ],
+            Bind  => [ \$Param{CertFingerprint}, \$Param{CAFingerprint} ],
             Limit => 1,
         );
 
@@ -1489,7 +1535,10 @@ sub SignerCertRelationDelete {
 
     # check needed stuff
     if ( !$Param{CertFingerprint} && !$Param{ID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need ID or CertFingerprint!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need ID or CertFingerprint!'
+        );
         return;
     }
 
@@ -1640,8 +1689,7 @@ sub _Init {
     $ENV{RANDFILE} = $Self->{ConfigObject}->Get('TempDir') . '/.rnd';
 
     # prepend RANDFILE declaration to openssl cmd
-    $Self->{Cmd}
-        = "HOME=" . $Self->{ConfigObject}->Get('Home') . " RANDFILE=$ENV{RANDFILE} $Self->{Cmd}";
+    $Self->{Cmd} = "HOME=" . $Self->{ConfigObject}->Get('Home') . " RANDFILE=$ENV{RANDFILE} $Self->{Cmd}";
 
     # get the openssl version string, e.g. OpenSSL 0.9.8e 23 Feb 2007
     $Self->{OpenSSLVersionString} = qx{$Self->{Cmd} version};
@@ -1712,7 +1760,7 @@ sub _FetchAttributesFromCert {
             if ( $Line =~ m{\A $Filters{$Filter} \z}xms ) {
                 $AttributesRef->{$Filter} = $1 || '';
 
-          # delete the match key from filter  to don't search again this value and improve the speed
+                # delete the match key from filter  to don't search again this value and improve the speed
                 delete $Filters{$Filter};
                 last;
             }
@@ -1731,7 +1779,12 @@ sub _FetchAttributesFromCert {
         Apr => '04',
         May => '05',
         Jun => '06',
-        Jul => '07', Aug => '08', Sep => '09', Oct => '10', Nov => '11', Dec => '12',
+        Jul => '07',
+        Aug => '08',
+        Sep => '09',
+        Oct => '10',
+        Nov => '11',
+        Dec => '12',
     );
 
     for my $DateType ( 'StartDate', 'EndDate' ) {
@@ -1778,7 +1831,10 @@ sub _CertificateFilename {
     # check needed stuff
     for my $Needed (qw(Fingerprint Hash)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -1810,7 +1866,10 @@ sub _PrivateFilename {
     # check needed stuff
     for my $Needed (qw(Hash Modulus)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -2136,8 +2195,7 @@ sub _ReHashCertificates {
     for my $WrongCertificate (@WrongCertificatesList) {
 
         # recreate the certificate file name
-        my $WrongCertificateFile
-            = "$Self->{CertPath}/$WrongCertificate->{Hash}.$WrongCertificate->{Index}";
+        my $WrongCertificateFile = "$Self->{CertPath}/$WrongCertificate->{Hash}.$WrongCertificate->{Index}";
 
         # check if certificate exists
         if ( !-e $WrongCertificateFile ) {
@@ -2185,8 +2243,7 @@ sub _ReHashCertificates {
         }
 
         # set wrong private key
-        my $WrongPrivateKeyFile
-            = "$Self->{PrivatePath}/$WrongCertificate->{Hash}.$WrongCertificate->{Index}";
+        my $WrongPrivateKeyFile = "$Self->{PrivatePath}/$WrongCertificate->{Hash}.$WrongCertificate->{Index}";
 
         # check if certificate has a private key and secret
         # if has a private key it must have a private secret
@@ -2512,9 +2569,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.73 $ $Date: 2013-02-08 23:01:42 $
-
-=cut
