@@ -1,6 +1,6 @@
 # --
 # Kernel/System/DB.pm - the global database wrapper to support different databases
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -8,6 +8,7 @@
 # --
 
 package Kernel::System::DB;
+## nofilter(TidyAll::Plugin::OTRS::Perl::PODSpelling)
 
 use strict;
 use warnings;
@@ -411,7 +412,10 @@ sub Do {
 
     # check needed stuff
     if ( !$Param{SQL} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need SQL!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need SQL!'
+        );
         return;
     }
 
@@ -468,7 +472,10 @@ sub Do {
     }
 
     for my $DBListener ( @{ $Self->{DBListeners} } ) {
-        $DBListener->PreDo( SQL => $Param{SQL}, Bind => \@Array );
+        $DBListener->PreDo(
+            SQL  => $Param{SQL},
+            Bind => \@Array
+        );
     }
 
     # send sql to database
@@ -482,7 +489,10 @@ sub Do {
     }
 
     for my $DBListener ( @{ $Self->{DBListeners} } ) {
-        $DBListener->PostDo( SQL => $Param{SQL}, Bind => \@Array );
+        $DBListener->PostDo(
+            SQL  => $Param{SQL},
+            Bind => \@Array
+        );
     }
 
     return 1;
@@ -534,7 +544,10 @@ sub Prepare {
 
     # check needed stuff
     if ( !$Param{SQL} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need SQL!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need SQL!'
+        );
         return;
     }
     if ( defined $Param{Encode} ) {
@@ -599,7 +612,10 @@ sub Prepare {
     }
 
     for my $DBListener ( @{ $Self->{DBListeners} } ) {
-        $DBListener->PrePrepare( SQL => $SQL, Bind => \@Array );
+        $DBListener->PrePrepare(
+            SQL  => $SQL,
+            Bind => \@Array
+        );
     }
 
     # do
@@ -622,7 +638,10 @@ sub Prepare {
     }
 
     for my $DBListener ( @{ $Self->{DBListeners} } ) {
-        $DBListener->PostPrepare( SQL => $SQL, Bind => \@Array );
+        $DBListener->PostPrepare(
+            SQL  => $SQL,
+            Bind => \@Array
+        );
     }
 
     # slow log feature
@@ -1029,6 +1048,8 @@ generate SQL condition query based on a search expression
         Value => '((ABC&&DEF)&&!GHI)',
     );
 
+    Returns the SQL string or "1=0" if the query could not be parsed correctly.
+
 Note that the comparisons are usually performed case insensitively.
 Only VARCHAR colums with a size less or equal 3998 are supported,
 as for locator objects the functioning of SQL function LOWER() can't
@@ -1042,7 +1063,10 @@ sub QueryCondition {
     # check needed stuff
     for (qw(Key Value)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -1051,8 +1075,9 @@ sub QueryCondition {
     my $LikeEscapeString = $Self->GetDatabaseFunction('LikeEscapeString');
 
     # search prefix/suffix check
-    my $SearchPrefix = $Param{SearchPrefix} || '';
-    my $SearchSuffix = $Param{SearchSuffix} || '';
+    my $SearchPrefix  = $Param{SearchPrefix}  || '';
+    my $SearchSuffix  = $Param{SearchSuffix}  || '';
+    my $CaseSensitive = $Param{CaseSensitive} || 0;
 
     # remove leading/trailing spaces
     $Param{Value} =~ s/^\s+//g;
@@ -1077,6 +1102,9 @@ sub QueryCondition {
         "###$Count###";
     }egx;
 
+    # remove empty parentheses
+    $Param{Value} =~ s/(?<!\\)\(\s*(?<!\\)\)//g;
+
     # remove double spaces
     $Param{Value} =~ s/\s+/ /g;
 
@@ -1106,8 +1134,33 @@ sub QueryCondition {
     $Param{Value} =~ s/^(?<!\\)\((&&|\|\|)/(/g;
 
     # clean up not needed spaces in condistions
-    $Param{Value} =~ s/(\s((?<!\\)\(|(?<!\\)\)|\||&))/$2/g;
-    $Param{Value} =~ s/(((?<!\\)\(|(?<!\\)\)|\||&)\s)/$2/g;
+    # removed spaces examples
+    # [SPACE](, [SPACE]), [SPACE]|, [SPACE]&
+    # example not removed spaces
+    # [SPACE]\\(, [SPACE]\\), [SPACE]\\&
+    $Param{Value} =~ s{(
+        \s
+        (
+              (?<!\\) \(
+            | (?<!\\) \)
+            |         \|
+            | (?<!\\) &
+        )
+    )}{$2}xg;
+
+    # removed spaces examples
+    # )[SPACE], )[SPACE], |[SPACE], &[SPACE]
+    # example not removed spaces
+    # \\([SPACE], \\)[SPACE], \\&[SPACE]
+    $Param{Value} =~ s{(
+        (
+              (?<!\\) \(
+            | (?<!\\) \)
+            |         \|
+            | (?<!\\) &
+        )
+        \s
+    )}{$2}xg;
 
     # use extended condition mode
     # 1. replace " " by "&&"
@@ -1129,10 +1182,11 @@ sub QueryCondition {
     my $Close = 0;
 
     # for processing
-    my @Array = split( //, $Param{Value} );
-    my $SQL   = '';
-    my $Word  = '';
-    my $Not   = 0;
+    my @Array     = split( //, $Param{Value} );
+    my $SQL       = '';
+    my $Word      = '';
+    my $Not       = 0;
+    my $Backslash = 0;
 
     my $SpecialCharacters = $Self->_SpecialCharactersGet();
 
@@ -1140,44 +1194,53 @@ sub QueryCondition {
     for my $Position ( 0 .. $#Array ) {
 
         # find word
-        if (
+        if ($Backslash) {
+            $Word .= $Array[$Position];
+            $Backslash = 0;
+            next POSITION;
+        }
 
-            # if the previous element was '\\', the current element has to be added as word
-            # so that search queries like '\(Test\)' (searching for round brackets) work
-            (
-                $Position > 0
-                && $Array[ $Position - 1 ] eq '\\'
-                && $SpecialCharacters->{ $Array[$Position] }
+        # remember if next token is a part of word
+        elsif (
+            $Array[$Position] eq '\\'
+            && $Position < $#Array
+            && (
+                $SpecialCharacters->{ $Array[ $Position + 1 ] }
+                || $Array[ $Position + 1 ] eq '\\'
             )
-
-            # "default" case: don't add brackets, etc. to a word being searched for
-            || $Array[$Position] !~ /(\(|\)|\!|\|)/
             )
         {
-            if ( $Array[$Position] =~ m{&} ) {
-                if (
-                    !(
-                        (
-                            $Array[ $Position - 1 ]
-                            && $Array[ $Position - 1 ] =~ m{&}
-                        )
-                        ||
-                        (
-                            $Array[ $Position + 1 ]
-                            && $Array[ $Position + 1 ] =~ m{&}
-                        )
-                    )
-                    )
-                {
-                    $Word .= $Array[$Position];
-                    next POSITION;
-                }
+            $Backslash = 1;
+            next POSITION;
+        }
+
+        # remember if it's a NOT condition
+        elsif ( $Word eq '' && $Array[$Position] eq '!' ) {
+            $Not = 1;
+            next POSITION;
+        }
+        elsif ( $Array[$Position] eq '&' ) {
+            if ( $Position >= 1 && $Array[ $Position - 1 ] eq '&' ) {
+                next POSITION;
             }
-            else {
+            if ( $Position == $#Array || $Array[ $Position + 1 ] ne '&' ) {
                 $Word .= $Array[$Position];
                 next POSITION;
             }
         }
+        elsif ( $Array[$Position] eq '|' ) {
+            if ( $Position >= 1 && $Array[ $Position - 1 ] eq '|' ) {
+                next POSITION;
+            }
+            if ( $Position == $#Array || $Array[ $Position + 1 ] ne '|' ) {
+                $Word .= $Array[$Position];
+                next POSITION;
+            }
+        }
+        elsif ( !$SpecialCharacters->{ $Array[$Position] } ) {
+            $Word .= $Array[$Position];
+            next POSITION;
+        }
 
         # if word exists, do something with it
         if ($Word) {
@@ -1205,7 +1268,7 @@ sub QueryCondition {
             }
 
             # if it's a NOT LIKE condition
-            if ( $Array[$Position] eq '!' || $Not ) {
+            if ($Not) {
                 $Not = 0;
 
                 my $SQLA;
@@ -1220,8 +1283,13 @@ sub QueryCondition {
                         $Type = '!=';
                     }
 
-                    # check if database supports LIKE in large text types
-                    if ( $Self->GetDatabaseFunction('CaseInsensitive') ) {
+        # check if database supports LIKE in large text types
+        # the first condition is a little bit opaque
+        # CaseInsensitive of the database defines, if the database handles case sensitivity or not
+        # and the parameter $CaseSensitive defines, if the customer database should do case sensitive statements or not.
+        # so if the database dont support case sensitivity or the configuration of the customer database want to do this
+        # then we prevent the LOWER() statements.
+                    if ( $Self->GetDatabaseFunction('CaseInsensitive') || $CaseSensitive ) {
                         $SQLA .= "$Key $Type '$Word'";
                     }
                     elsif ( $Self->GetDatabaseFunction('LcaseLikeInLargeText') ) {
@@ -1252,8 +1320,13 @@ sub QueryCondition {
                         $Type = '=';
                     }
 
-                    # check if database supports LIKE in large text types
-                    if ( $Self->GetDatabaseFunction('CaseInsensitive') ) {
+        # check if database supports LIKE in large text types
+        # the first condition is a little bit opaque
+        # CaseInsensitive of the database defines, if the database handles case sensitivity or not
+        # and the parameter $CaseSensitive defines, if the customer database should do case sensitive statements or not.
+        # so if the database dont support case sensitivity or the configuration of the customer database want to do this
+        # then we prevent the LOWER() statements.
+                    if ( $Self->GetDatabaseFunction('CaseInsensitive') || $CaseSensitive ) {
                         $SQLA .= "$Key $Type '$Word'";
                     }
                     elsif ( $Self->GetDatabaseFunction('LcaseLikeInLargeText') ) {
@@ -1279,48 +1352,77 @@ sub QueryCondition {
 
             # if it's an AND condition
             if ( $Array[$Position] eq '&' && $Array[ $Position + 1 ] eq '&' ) {
-                $SQL .= ' AND ';
+                if ( $SQL =~ m/ OR $/ ) {
+                    $Self->{LogObject}->Log(
+                        Priority => 'notice',
+                        Message =>
+                            "Invalid condition '$Param{Value}', simultaneous usage both AND and OR conditions!",
+                    );
+                    return "1=0";
+                }
+                elsif ( $SQL !~ m/ AND $/ ) {
+                    $SQL .= ' AND ';
+                }
             }
 
             # if it's an OR condition
             elsif ( $Array[$Position] eq '|' && $Array[ $Position + 1 ] eq '|' ) {
-                $SQL .= ' OR ';
+                if ( $SQL =~ m/ AND $/ ) {
+                    $Self->{LogObject}->Log(
+                        Priority => 'notice',
+                        Message =>
+                            "Invalid condition '$Param{Value}', simultaneous usage both AND and OR conditions!",
+                    );
+                    return "1=0";
+                }
+                elsif ( $SQL !~ m/ OR $/ ) {
+                    $SQL .= ' OR ';
+                }
             }
         }
 
         # add ( or ) for query
-        if (
-
-            # if the previous element was '\\', don't handle the current one as an SQL bracket
-            # (it was a bracket to search for)
-            ( $Position == 0 || $Array[ $Position - 1 ] ne '\\' )
-            && $Array[$Position] =~ /(\(|\))/
-            )
-        {
+        if ( $Array[$Position] eq '(' ) {
+            if ( $SQL ne '' && $SQL !~ /(?: (?:AND|OR) |\(\s*)$/ ) {
+                $SQL .= ' AND ';
+            }
             $SQL .= $Array[$Position];
 
             # remember for syntax check
-            if ( $1 eq '(' ) {
-                $Open++;
-            }
-            elsif ( $1 eq ')' ) {
-                $Close++;
-            }
+            $Open++;
         }
+        if ( $Array[$Position] eq ')' ) {
+            $SQL .= $Array[$Position];
+            if (
+                $Position < $#Array
+                && ( $Position > $#Array - 1 || $Array[ $Position + 1 ] ne ')' )
+                && (
+                    $Position > $#Array - 2
+                    || $Array[ $Position + 1 ] ne '&'
+                    || $Array[ $Position + 2 ] ne '&'
+                )
+                && (
+                    $Position > $#Array - 2
+                    || $Array[ $Position + 1 ] ne '|'
+                    || $Array[ $Position + 2 ] ne '|'
+                )
+                )
+            {
+                $SQL .= ' AND ';
+            }
 
-        # remember if it's a NOT condition
-        elsif ( $Array[$Position] eq '!' ) {
-            $Not = 1;
+            # remember for syntax check
+            $Close++;
         }
     }
 
     # check syntax
     if ( $Open != $Close ) {
         $Self->{LogObject}->Log(
-            Priority => 'Error',
+            Priority => 'notice',
             Message  => "Invalid condition '$Param{Value}', $Open open and $Close close!",
         );
-        return;
+        return "1=0";
     }
 
     return $SQL;
@@ -1347,7 +1449,10 @@ sub QueryStringEscape {
     # check needed stuff
     for my $Key (qw(QueryString)) {
         if ( !defined $Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Key!"
+            );
             return;
         }
     }
