@@ -1,8 +1,6 @@
 # --
 # Kernel/System/DynamicField.pm - DynamicFields configuration backend
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: DynamicField.pm,v 1.56.2.1 2012/04/26 23:02:46 cr Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,17 +12,12 @@ package Kernel::System::DynamicField;
 use strict;
 use warnings;
 
-use YAML;
+use Kernel::System::YAML;
 
 use Kernel::System::Cache;
-use Kernel::System::SysConfig;
-use Kernel::System::Time;
 use Kernel::System::Valid;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.56.2.1 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField
@@ -96,10 +89,10 @@ sub new {
     # create additional objects
     $Self->{CacheObject} = Kernel::System::Cache->new( %{$Self} );
     $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
+    $Self->{YAMLObject}  = Kernel::System::YAML->new( %{$Self} );
 
     # get the cache TTL (in seconds)
-    $Self->{CacheTTL}
-        = int( $Self->{ConfigObject}->Get('DynamicField::CacheTTL') || 3600 );
+    $Self->{CacheTTL} = int( $Self->{ConfigObject}->Get('DynamicField::CacheTTL') || 3600 );
 
     # set lower if database is case sensitive
     $Self->{Lower} = '';
@@ -117,6 +110,7 @@ add new Dynamic Field config
 returns id of new Dynamic field if successful or undef otherwise
 
     my $ID = $DynamicFieldObject->DynamicFieldAdd(
+        InternalField => 0,             # optional, 0 or 1, internal fields are protected
         Name        => 'NameForField',  # mandatory
         Label       => 'a description', # mandatory, label to show
         FieldOrder  => 123,             # mandatory, display order
@@ -142,15 +136,14 @@ sub DynamicFieldAdd {
     # check needed stuff
     for my $Key (qw(Name Label FieldOrder FieldType ObjectType Config ValidID UserID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Key!"
+            );
             return;
         }
     }
 
-    # Create SysConfig object locally just for this function, to save some performance.
-    $Self->{TimeObject}      ||= Kernel::System::Time->new( %{$Self} );
-    $Self->{SysConfigObject} ||= Kernel::System::SysConfig->new( %{$Self} );
-
     # check needed structure for some fields
     if ( $Param{Name} !~ m{ \A [a-z|A-Z|\d]+ \z }xms ) {
         $Self->{LogObject}->Log(
@@ -189,20 +182,23 @@ sub DynamicFieldAdd {
     }
 
     # dump config as string
-    my $Config = YAML::Dump( $Param{Config} );
+    my $Config = $Self->{YAMLObject}->Dump( Data => $Param{Config} );
 
     # Make sure the resulting string has the UTF-8 flag. YAML only sets it if
     #   part of the data already had it.
     utf8::upgrade($Config);
 
+    my $InternalField = $Param{InternalField} ? 1 : 0;
+
     # sql
     return if !$Self->{DBObject}->Do(
         SQL =>
-            'INSERT INTO dynamic_field (name, label, field_Order, field_type, object_type,' .
+            'INSERT INTO dynamic_field (internal_field, name, label, field_Order, field_type, object_type,'
+            .
             'config, valid_id, create_time, create_by, change_time, change_by)' .
-            ' VALUES (?, ?, ?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
+            ' VALUES (?, ?, ?, ?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
-            \$Param{Name}, \$Param{Label}, \$Param{FieldOrder}, \$Param{FieldType},
+            \$InternalField, \$Param{Name}, \$Param{Label}, \$Param{FieldOrder}, \$Param{FieldType},
             \$Param{ObjectType}, \$Config, \$Param{ValidID}, \$Param{UserID}, \$Param{UserID},
         ],
     );
@@ -218,25 +214,6 @@ sub DynamicFieldAdd {
 
     return if !$DynamicField->{ID};
 
-    # Add this field to the list of X-Headers that the postmaster filters should scan.
-    my @PostMasterXHeader = @{ $Self->{ConfigObject}->Get('PostmasterX-Header') || [] };
-    if (@PostMasterXHeader) {
-
-        # Check if fields are already present.
-        if ( !grep { $_ eq "X-OTRS-DynamicField-$Param{Name}" } @PostMasterXHeader ) {
-            push @PostMasterXHeader, "X-OTRS-DynamicField-$Param{Name}";
-        }
-        if ( !grep { $_ eq "X-OTRS-FollowUp-DynamicField-$Param{Name}" } @PostMasterXHeader ) {
-            push @PostMasterXHeader, "X-OTRS-FollowUp-DynamicField-$Param{Name}";
-        }
-
-        $Self->{SysConfigObject}->ConfigItemUpdate(
-            Valid => 1,
-            Key   => 'PostmasterX-Header',
-            Value => \@PostMasterXHeader,
-        );
-    }
-
     if ( !exists $Param{Reorder} || $Param{Reorder} ) {
 
         # re-order field list
@@ -262,16 +239,17 @@ get Dynamic Field attributes
 Returns:
 
     $DynamicField = {
-        ID          => 123,
-        Name        => 'NameForField',
-        Label       => 'The label to show',
-        FieldOrder  => 123,
-        FieldType   => 'Text',
-        ObjectType  => 'Article',
-        Config      => $ConfigHashRef,
-        ValidID     => 1,
-        CreateTime  => '2011-02-08 15:08:00',
-        ChangeTime  => '2011-06-11 17:22:00',
+        ID            => 123,
+        InternalField => 0,
+        Name          => 'NameForField',
+        Label         => 'The label to show',
+        FieldOrder    => 123,
+        FieldType     => 'Text',
+        ObjectType    => 'Article',
+        Config        => $ConfigHashRef,
+        ValidID       => 1,
+        CreateTime    => '2011-02-08 15:08:00',
+        ChangeTime    => '2011-06-11 17:22:00',
     };
 
 =cut
@@ -281,7 +259,10 @@ sub DynamicFieldGet {
 
     # check needed stuff
     if ( !$Param{ID} && !$Param{Name} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need ID or Name!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need ID or Name!'
+        );
         return;
     }
 
@@ -304,7 +285,8 @@ sub DynamicFieldGet {
     if ( $Param{ID} ) {
         return if !$Self->{DBObject}->Prepare(
             SQL =>
-                'SELECT id, name, label, field_order, field_type, object_type, config,' .
+                'SELECT id, internal_field, name, label, field_order, field_type, object_type, config,'
+                .
                 ' valid_id, create_time, change_time ' .
                 'FROM dynamic_field WHERE id = ?',
             Bind => [ \$Param{ID} ],
@@ -313,7 +295,8 @@ sub DynamicFieldGet {
     else {
         return if !$Self->{DBObject}->Prepare(
             SQL =>
-                'SELECT id, name, label, field_order, field_type, object_type, config,' .
+                'SELECT id, internal_field, name, label, field_order, field_type, object_type, config,'
+                .
                 ' valid_id, create_time, change_time ' .
                 'FROM dynamic_field WHERE name = ?',
             Bind => [ \$Param{Name} ],
@@ -322,19 +305,20 @@ sub DynamicFieldGet {
 
     my %Data;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
-        my $Config = YAML::Load( $Data[6] ) || {};
+        my $Config = $Self->{YAMLObject}->Load( Data => $Data[7] ) || {};
 
         %Data = (
-            ID         => $Data[0],
-            Name       => $Data[1],
-            Label      => $Data[2],
-            FieldOrder => $Data[3],
-            FieldType  => $Data[4],
-            ObjectType => $Data[5],
-            Config     => $Config,
-            ValidID    => $Data[7],
-            CreateTime => $Data[8],
-            ChangeTime => $Data[9],
+            ID            => $Data[0],
+            InternalField => $Data[1],
+            Name          => $Data[2],
+            Label         => $Data[3],
+            FieldOrder    => $Data[4],
+            FieldType     => $Data[5],
+            ObjectType    => $Data[6],
+            Config        => $Config,
+            ValidID       => $Data[8],
+            CreateTime    => $Data[9],
+            ChangeTime    => $Data[10],
         );
     }
 
@@ -378,18 +362,21 @@ sub DynamicFieldUpdate {
     # check needed stuff
     for my $Key (qw(ID Name Label FieldOrder FieldType ObjectType Config ValidID UserID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Key!"
+            );
             return;
         }
     }
 
     my $Reorder;
-    if ( !exists $Param{Reorder} or $Param{Reorder} eq 1 ) {
+    if ( !exists $Param{Reorder} || $Param{Reorder} eq 1 ) {
         $Reorder = 1;
     }
 
     # dump config as string
-    my $Config = YAML::Dump( $Param{Config} );
+    my $Config = $Self->{YAMLObject}->Dump( Data => $Param{Config} );
 
     # Make sure the resulting string has the UTF-8 flag. YAML only sets it if
     #    part of the data already had it.
@@ -409,7 +396,7 @@ sub DynamicFieldUpdate {
         SQL => "SELECT id FROM dynamic_field "
             . "WHERE $Self->{Lower}(name) = $Self->{Lower}(?) "
             . "AND id != ?",
-        Bind => [ \$Param{Name}, \$Param{ID} ],
+        Bind  => [ \$Param{Name}, \$Param{ID} ],
         LIMIT => 1,
     );
 
@@ -496,7 +483,10 @@ sub DynamicFieldDelete {
     # check needed stuff
     for my $Key (qw(ID UserID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Key!"
+            );
             return;
         }
     }
@@ -587,7 +577,7 @@ sub DynamicFieldList {
 
         # fill the fieldIDs whitelist
         FIELDNAME:
-        for my $FieldName ( keys %{ $Param{FieldFilter} } ) {
+        for my $FieldName ( sort keys %{ $Param{FieldFilter} } ) {
             next FIELDNAME if !$Param{FieldFilter}->{$FieldName};
 
             my $FieldConfig = $Self->DynamicFieldGet( Name => $FieldName );
@@ -616,8 +606,7 @@ sub DynamicFieldList {
     my $ResultType = $Param{ResultType} || 'ARRAY';
     $ResultType = $ResultType eq 'HASH' ? 'HASH' : 'ARRAY';
 
-    my $CacheKey
-        = 'DynamicFieldList::Valid::'
+    my $CacheKey = 'DynamicFieldList::Valid::'
         . $Valid
         . '::ObjectType::'
         . $ObjectType
@@ -665,7 +654,7 @@ sub DynamicFieldList {
         else {
 
             FIELDID:
-            for my $FieldID ( keys %{$Cache} ) {
+            for my $FieldID ( sort keys %{$Cache} ) {
                 next FIELDID if !$AllowedFieldIDs{$FieldID};
 
                 $FilteredData->{$FieldID} = $Cache->{$FieldID}
@@ -750,7 +739,7 @@ sub DynamicFieldList {
 
             my %FilteredData;
             FIELDID:
-            for my $FieldID ( keys %Data ) {
+            for my $FieldID ( sort keys %Data ) {
                 next FIELDID if !$AllowedFieldIDs{$FieldID};
 
                 $FilteredData{$FieldID} = $Data{$FieldID};
@@ -834,6 +823,7 @@ Returns:
     $List = (
         {
             ID          => 123,
+            InternalField => 0,
             Name        => 'nameforfield',
             Label       => 'The label to show',
             FieldType   => 'Text',
@@ -844,15 +834,16 @@ Returns:
             ChangeTime  => '2011-06-11 17:22:00',
         },
         {
-            ID          => 321,
-            Name        => 'fieldname',
-            Label       => 'It is not a label',
-            FieldType   => 'Text',
-            ObjectType  => 'Ticket',
-            Config      => $ConfigHashRef,
-            ValidID     => 1,
-            CreateTime  => '2010-09-11 10:08:00',
-            ChangeTime  => '2011-01-01 01:01:01',
+            ID            => 321,
+            InternalField => 0,
+            Name          => 'fieldname',
+            Label         => 'It is not a label',
+            FieldType     => 'Text',
+            ObjectType    => 'Ticket',
+            Config        => $ConfigHashRef,
+            ValidID       => 1,
+            CreateTime    => '2010-09-11 10:08:00',
+            ChangeTime    => '2011-01-01 01:01:01',
         },
         ...
     );
@@ -1143,7 +1134,10 @@ sub _DynamicFieldReorder {
     # check needed stuff
     for my $Needed (qw(ID FieldOrder Mode)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => 'Need $Needed!' );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => 'Need $Needed!'
+            );
             return;
         }
     }
@@ -1152,7 +1146,10 @@ sub _DynamicFieldReorder {
 
         # check needed stuff
         if ( !$Param{OldFieldOrder} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => 'Need OldFieldOrder!' );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => 'Need OldFieldOrder!'
+            );
             return;
         }
     }
@@ -1308,7 +1305,7 @@ sub _DynamicFieldReorder {
     return 1;
 }
 
-1;
+=end Internal:
 
 =back
 
@@ -1322,8 +1319,4 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
-=head1 VERSION
-
-$Revision: 1.56.2.1 $ $Date: 2012/04/26 23:02:46 $
-
-=cut
+1;
