@@ -1,6 +1,6 @@
 # --
 # Kernel/System/DynamicField/Backend/Date.pm - Delegate for DynamicField Date backend
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +17,6 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::Time;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.61 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField::Backend::Date
@@ -59,8 +56,7 @@ sub new {
     # create additional objects
     $Self->{DynamicFieldValueObject} = Kernel::System::DynamicFieldValue->new( %{$Self} );
     $Self->{TimeObject}              = Kernel::System::Time->new( %{$Self} );
-    $Self->{BackendCommonObject}
-        = Kernel::System::DynamicField::Backend::BackendCommon->new( %{$Self} );
+    $Self->{BackendCommonObject}     = Kernel::System::DynamicField::Backend::BackendCommon->new( %{$Self} );
 
     return $Self;
 }
@@ -227,9 +223,7 @@ sub EditFieldRender {
     }
 
     # extract the dynamic field value form the web request
-    # TransformDates is always needed from EditFieldRender Bug#8452
     my $FieldValues = $Self->EditFieldValueGet(
-        TransformDates       => 1,
         ReturnValueStructure => 1,
         %Param,
     );
@@ -280,6 +274,7 @@ sub EditFieldRender {
         %{$FieldConfig},
         %SplitedFieldValues,
         %YearsPeriodRange,
+        OverrideTimeZone => 1,
     );
 
     if ( $Param{Mandatory} ) {
@@ -361,17 +356,6 @@ sub EditFieldValueGet {
         && !$DynamicFieldValues{ $Prefix . 'Month' }
         && !$DynamicFieldValues{ $Prefix . 'Day' };
 
-    # check if need and can transform dates
-    # transform the dates early for ReturnValueStructure or ManualTimeStamp Bug#8452
-    if ( $Param{TransformDates} && $Param{LayoutObject} ) {
-
-        # transform time stamp based on user time zone
-        %DynamicFieldValues = $Param{LayoutObject}->TransformDateSelection(
-            %DynamicFieldValues,
-            Prefix => $Prefix,
-        );
-    }
-
     # check if return value structure is nedded
     if ( defined $Param{ReturnValueStructure} && $Param{ReturnValueStructure} eq '1' ) {
         return \%DynamicFieldValues;
@@ -395,8 +379,7 @@ sub EditFieldValueGet {
                 && $DynamicFieldValues{ $Prefix . $Type } !~ m{\A 0 \d \z}smx
                 )
             {
-                $DynamicFieldValues{ $Prefix . $Type }
-                    = '0' . $DynamicFieldValues{ $Prefix . $Type };
+                $DynamicFieldValues{ $Prefix . $Type } = '0' . $DynamicFieldValues{ $Prefix . $Type };
             }
         }
 
@@ -463,7 +446,9 @@ sub DisplayValueRender {
     if ( defined $Param{Value} ) {
         $Value = $Param{LayoutObject}->Output(
             Template => '$Date{"$Data{"Value"}"}',
-            Data => { Value => $Param{Value}, },
+            Data     => {
+                Value => $Param{Value},
+            },
         );
     }
 
@@ -537,8 +522,7 @@ sub SearchFieldRender {
     my $FieldClass = 'DynamicFieldDateTime';
 
     # set as checked if necessary
-    my $FieldChecked
-        = ( defined $Value->{$FieldName} && $Value->{$FieldName} == 1 ? 'checked="checked"' : '' );
+    my $FieldChecked = ( defined $Value->{$FieldName} && $Value->{$FieldName} == 1 ? 'checked="checked"' : '' );
 
     my $HTMLString = <<"EOF";
     <input type="hidden" id="$FieldName" name="$FieldName" value="1"/>
@@ -625,8 +609,7 @@ sub SearchFieldValueGet {
                 # return if value was not checked (useful in customer interface)
                 return if !$Param{Profile}->{$Prefix};
 
-                $DynamicFieldValues{ $Prefix . $Type . $Part }
-                    = $Param{Profile}->{ $Prefix . $Type . $Part };
+                $DynamicFieldValues{ $Prefix . $Type . $Part } = $Param{Profile}->{ $Prefix . $Type . $Part };
             }
             else {
                 return;
@@ -666,8 +649,7 @@ sub SearchFieldValueGet {
                 && length $DynamicFieldValues{ $Prefix . $Type . $Part } == 1
                 )
             {
-                $DynamicFieldValues{ $Prefix . $Type . $Part }
-                    = '0' . $DynamicFieldValues{ $Prefix . $Type . $Part };
+                $DynamicFieldValues{ $Prefix . $Type . $Part } = '0' . $DynamicFieldValues{ $Prefix . $Type . $Part };
             }
         }
     }
@@ -715,29 +697,25 @@ sub SearchFieldParameterBuild {
 
         my $Prefix = 'Search_DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
-        my $ValueStart
-            = $Value->{ValueStart}->{ $Prefix . 'StartYear' } . '-'
+        my $ValueStart = $Value->{ValueStart}->{ $Prefix . 'StartYear' } . '-'
             . $Value->{ValueStart}->{ $Prefix . 'StartMonth' } . '-'
             . $Value->{ValueStart}->{ $Prefix . 'StartDay' } . ' '
             . $Value->{ValueStart}->{ $Prefix . 'StartHour' } . ':'
             . $Value->{ValueStart}->{ $Prefix . 'StartMinute' } . ':'
             . $Value->{ValueStart}->{ $Prefix . 'StartSecond' };
 
-        my $ValueStop
-            = $Value->{ValueStop}->{ $Prefix . 'StopYear' } . '-'
+        my $ValueStop = $Value->{ValueStop}->{ $Prefix . 'StopYear' } . '-'
             . $Value->{ValueStop}->{ $Prefix . 'StopMonth' } . '-'
             . $Value->{ValueStop}->{ $Prefix . 'StopDay' } . ' '
             . $Value->{ValueStop}->{ $Prefix . 'StopHour' } . ':'
             . $Value->{ValueStop}->{ $Prefix . 'StopMinute' } . ':'
             . $Value->{ValueStop}->{ $Prefix . 'StopSecond' };
 
-        my $DisplayValueStart
-            = $Value->{ValueStart}->{ $Prefix . 'StartYear' } . '-'
+        my $DisplayValueStart = $Value->{ValueStart}->{ $Prefix . 'StartYear' } . '-'
             . $Value->{ValueStart}->{ $Prefix . 'StartMonth' } . '-'
             . $Value->{ValueStart}->{ $Prefix . 'StartDay' };
 
-        my $DisplayValueStop
-            = $Value->{ValueStop}->{ $Prefix . 'StopYear' } . '-'
+        my $DisplayValueStop = $Value->{ValueStop}->{ $Prefix . 'StopYear' } . '-'
             . $Value->{ValueStop}->{ $Prefix . 'StopMonth' } . '-'
             . $Value->{ValueStop}->{ $Prefix . 'StopDay' };
 
@@ -899,9 +877,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.61 $ $Date: 2013-01-10 16:26:46 $
-
-=cut
