@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Email/Sendmail.pm - the global email send module
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,9 +12,6 @@ package Kernel::System::Email::Sendmail;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.35 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -39,7 +36,10 @@ sub Send {
     # check needed stuff
     for (qw(Header Body ToArray)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -114,10 +114,16 @@ sub Check {
     my $SendmailBinary = $Sendmail;
     $SendmailBinary =~ s/^(.+?)\s.+?$/$1/;
     if ( !-f $SendmailBinary ) {
-        return ( Successful => 0, Message => "No such binary: $SendmailBinary!" );
+        return (
+            Successful => 0,
+            Message    => "No such binary: $SendmailBinary!"
+        );
     }
     else {
-        return ( Successful => 1, Sendmail => $Sendmail );
+        return (
+            Successful => 1,
+            Sendmail   => $Sendmail
+        );
     }
 }
 
