@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Encode.pm - character encodings
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Encode.pm,v 1.52 2012/11/20 15:34:38 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,9 +13,10 @@ use strict;
 use warnings;
 
 use Encode;
+use Encode::Locale;
+use IO::Interactive qw(is_interactive);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.52 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -35,7 +34,7 @@ This module will use Perl's Encode module (Perl 5.8.0 or higher is required).
 
 =item new()
 
-create a language object
+create an encode object
 
     use Kernel::System::Encode;
 
@@ -53,8 +52,25 @@ sub new {
     # 0=off; 1=on;
     $Self->{Debug} = 0;
 
-    # encode STDOUT and STDERR
-    $Self->SetIO( \*STDOUT, \*STDERR );
+    # check if the encodeobject is used from the command line
+    # if so, we need to decode @ARGV
+    if ( !is_interactive() ) {
+
+        # encode STDOUT and STDERR
+        $Self->SetIO( \*STDOUT, \*STDERR );
+    }
+    else {
+        # use "locale" as an arg to encode/decode
+        if ( is_interactive(*STDIN) ) {
+            @ARGV = map { decode( locale => $_, 1 ) } @ARGV;
+        }
+        if ( is_interactive(*STDOUT) ) {
+            binmode STDOUT, ":encoding(console_out)";
+        }
+        if ( is_interactive(*STDERR) ) {
+            binmode STDERR, ":encoding(console_out)";
+        }
+    }
 
     return $Self;
 }
@@ -137,6 +153,29 @@ sub Convert {
         Encode::_utf8_off( $Param{Text} );
     }
 
+    # this is a workaround for following bug in Encode::HanExtra
+    # https://rt.cpan.org/Public/Bug/Display.html?id=71720
+    # see also http://bugs.otrs.org/show_bug.cgi?id=10121
+    # distributed charsets by Encode::HanExtra
+    # http://search.cpan.org/~jhi/perl-5.8.1/ext/Encode/lib/Encode/Supported.pod
+    my %AdditionalChineseCharsets = (
+        'big5ext'  => 1,
+        'big5plus' => 1,
+        'cccii'    => 1,
+        'euc-tw'   => 1,
+        'gb18030'  => 1,
+    );
+
+    # check if one of the Encode::HanExtra charsets occurs
+    if ( $AdditionalChineseCharsets{ $Param{From} } ) {
+
+        # require module, print error if module was not found
+        if ( !eval "require Encode::HanExtra" ) {    ## no critic
+            print STDERR
+                "Charset '$Param{From}' requires Encode::HanExtra, which is not installed!\n";
+        }
+    }
+
     # check if encoding exists
     if ( !Encode::resolve_alias( $Param{From} ) ) {
         my $Fallback = 'iso-8859-1';
@@ -300,7 +339,9 @@ sub SetIO {
         next ROW if ref $Row ne 'GLOB';
 
         # set binmode
-        binmode( $Row, ':utf8' );
+        # http://www.perlmonks.org/?node_id=644786
+        # http://bugs.otrs.org/show_bug.cgi?id=5158
+        binmode( $Row, ':encoding(utf8)' );
     }
 
     return;
@@ -349,9 +390,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.52 $ $Date: 2012/11/20 15:34:38 $
-
-=cut
