@@ -2,8 +2,6 @@
 # Kernel/System/PostMaster/Filter/FollowUpArticleTypeCheck.pm - sub part of PostMaster.pm
 # Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: FollowUpArticleTypeCheck.pm,v 1.7 2011-12-08 14:06:42 mg Exp $
-# --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
@@ -14,9 +12,6 @@ package Kernel::System::PostMaster::Filter::FollowUpArticleTypeCheck;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.7 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -40,7 +35,10 @@ sub Run {
     # check needed stuff
     for (qw(TicketID JobConfig GetParam)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
