@@ -1,6 +1,6 @@
 # --
 # Kernel/System/ProcessManagement/TransitionAction/TicketTypeSet.pm - A Module to set the type of a process ticket
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,9 +15,6 @@ use Kernel::System::VariableCheck qw(:all);
 
 use utf8;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.2 $) [1];
-
 =head1 NAME
 
 Kernel::System::ProcessManagement::TransitionAction::TicketTypeSet - A Module to set the type of a Ticket
@@ -113,12 +110,18 @@ sub new {
     Run Data
 
     my $TicketTypeSetResult = $TicketTypeSetActionObject->Run(
-        UserID      => 123,
-        Ticket      => \%Ticket, # required
-        Config      => {
+        UserID                   => 123,
+        Ticket                   => \%Ticket,   # required
+        ProcessEntityID          => 'P123',     # optional
+        ActivityEntityID         => 'A123',     # optional
+        TransitionEntityID       => 'T123',     # optional
+        TransitionActionEntityID => 'TA123',    # optional
+        Config                   => {
             Type => 'Default',
             # or
             TypeID => 1,
+            UserID => 123,                      # optional, to override the UserID from the logged user
+
         }
     );
     Ticket contains the result of TicketGet including DynamicFields
@@ -142,11 +145,36 @@ sub Run {
         }
     }
 
+    # define a common message to output in case of any error
+    my $CommonMessage;
+    if ( $Param{ProcessEntityID} ) {
+        $CommonMessage .= "Process: $Param{ProcessEntityID}";
+    }
+    if ( $Param{ActivityEntityID} ) {
+        $CommonMessage .= " Activity: $Param{ActivityEntityID}";
+    }
+    if ( $Param{TransitionEntityID} ) {
+        $CommonMessage .= " Transition: $Param{TransitionEntityID}";
+    }
+    if ( $Param{TransitionActionEntityID} ) {
+        $CommonMessage .= " TransitionAction: $Param{TransitionActionEntityID}";
+    }
+    if ($CommonMessage) {
+
+        # add a separator
+        $CommonMessage .= " - ";
+    }
+    else {
+
+        # otherwise at least define it to prevent errors
+        $CommonMessage = '';
+    }
+
     # Check if we have Ticket to deal with
     if ( !IsHashRefWithData( $Param{Ticket} ) ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "Ticket has no values!",
+            Message  => $CommonMessage . "Ticket has no values!",
         );
         return;
     }
@@ -155,15 +183,21 @@ sub Run {
     if ( !IsHashRefWithData( $Param{Config} ) ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "Config has no values!",
+            Message  => $CommonMessage . "Config has no values!",
         );
         return;
     }
 
+    # override UserID if specified as a parameter in the TA config
+    if ( IsNumber( $Param{Config}->{UserID} ) ) {
+        $Param{UserID} = $Param{Config}->{UserID};
+        delete $Param{Config}->{UserID};
+    }
+
     if ( !$Param{Config}->{TypeID} && !$Param{Config}->{Type} ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "No Type or TypeID configured!",
+            Message  => $CommonMessage . "No Type or TypeID configured!",
         );
         return;
     }
@@ -171,7 +205,7 @@ sub Run {
     if ( !$Self->{ConfigObject}->Get('Ticket::Type') ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "Ticket::Type SysConfig setting is not enabled!",
+            Message  => $CommonMessage . "Ticket::Type SysConfig setting is not enabled!",
         );
         return;
     }
@@ -206,9 +240,19 @@ sub Run {
     }
 
     if ( !$Success ) {
+        my $CustomMessage;
+        if ( defined $Param{Config}->{Type} ) {
+            $CustomMessage = "Type: $Param{Config}->{Type},";
+        }
+        else {
+            $CustomMessage = "TypeID: $Param{Config}->{TypeID},";
+        }
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => 'Ticket type could not be updated for Ticket: '
+            Message  => $CommonMessage
+                . 'Ticket type could not be updated to '
+                . $CustomMessage
+                . ' for Ticket: '
                 . $Param{Ticket}->{TicketID} . '!',
         );
         return;
@@ -228,8 +272,4 @@ This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
-=head1 VERSION
-
-$Revision: 1.2 $ $Date: 2013-01-11 21:53:23 $
-
 =cut
