@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Service.pm - all service function
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Service.pm,v 1.60 2012/11/20 15:38:02 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,8 +17,7 @@ use Kernel::System::Valid;
 use Kernel::System::CacheInternal;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.60 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -135,9 +132,14 @@ sub ServiceList {
     }
 
     # read cache
-    my $CacheKey = 'ServiceList::' . $Param{Valid};
+    my $CacheKey = 'ServiceList::Valid::' . $Param{Valid};
+
+    if ( defined $Param{KeepChildren} && $Param{KeepChildren} eq '1' ) {
+        $CacheKey .= '::KeepChildren::' . $Param{KeepChildren};
+    }
+
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return %{$Cache} if $Cache;
+    return %{$Cache} if ref $Cache eq 'HASH';
 
     # ask database
     $Self->{DBObject}->Prepare(
@@ -153,7 +155,10 @@ sub ServiceList {
     }
 
     if ( !$Param{Valid} ) {
-        $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%ServiceList );
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => \%ServiceList
+        );
         return %ServiceList if !$Param{Valid};
     }
 
@@ -182,20 +187,25 @@ sub ServiceList {
     }
 
     # delete invalid services and childs
-    for my $ServiceID ( sort keys %ServiceList ) {
+    if ( !defined $Param{KeepChildren} || !$Param{KeepChildren} ) {
+        for my $ServiceID ( sort keys %ServiceList ) {
 
-        INVALIDNAME:
-        for my $InvalidName ( sort keys %ServiceInvalidList ) {
+            INVALIDNAME:
+            for my $InvalidName ( sort keys %ServiceInvalidList ) {
 
-            if ( $ServiceList{$ServiceID} =~ m{ \A \Q$InvalidName\E :: }xms ) {
-                delete $ServiceList{$ServiceID};
-                last INVALIDNAME;
+                if ( $ServiceList{$ServiceID} =~ m{ \A \Q$InvalidName\E :: }xms ) {
+                    delete $ServiceList{$ServiceID};
+                    last INVALIDNAME;
+                }
             }
         }
     }
 
     # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%ServiceList );
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \%ServiceList
+    );
 
     return %ServiceList;
 }
@@ -400,7 +410,7 @@ sub ServiceGet {
     # check cached results
     my $CacheKey = 'Cache::ServiceGet::' . $Param{ServiceID};
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return %{$Cache} if $Cache;
+    return %{$Cache} if ref $Cache eq 'HASH';
 
     # get service from db
     $Self->{DBObject}->Prepare(
@@ -600,7 +610,9 @@ sub ServiceAdd {
 
     # get parent name
     if ( $Param{ParentID} ) {
-        my $ParentName = $Self->ServiceLookup( ServiceID => $Param{ParentID}, );
+        my $ParentName = $Self->ServiceLookup(
+            ServiceID => $Param{ParentID},
+        );
         if ($ParentName) {
             $Param{FullName} = $ParentName . '::' . $Param{Name};
         }
@@ -706,7 +718,9 @@ sub ServiceUpdate {
     }
 
     # get old name of service
-    my $OldServiceName = $Self->ServiceLookup( ServiceID => $Param{ServiceID}, );
+    my $OldServiceName = $Self->ServiceLookup(
+        ServiceID => $Param{ServiceID},
+    );
 
     if ( !$OldServiceName ) {
         $Self->{LogObject}->Log(
@@ -792,7 +806,7 @@ sub ServiceUpdate {
     for my $Child (@Childs) {
         $Child->{Name} =~ s{ \A ( \Q$OldServiceName\E ) :: }{$Param{FullName}::}xms;
         $Self->{DBObject}->Do(
-            SQL => 'UPDATE service SET name = ? WHERE id = ?',
+            SQL  => 'UPDATE service SET name = ? WHERE id = ?',
             Bind => [ \$Child->{Name}, \$Child->{ServiceID} ],
         );
     }
@@ -833,8 +847,7 @@ sub ServiceSearch {
     $Param{Limit} ||= 1000;
 
     # create sql query
-    my $SQL
-        = "SELECT id FROM service WHERE valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
+    my $SQL = "SELECT id FROM service WHERE valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
 
     if ( $Param{Name} ) {
 
@@ -908,8 +921,7 @@ sub CustomerUserServiceMemberList {
     }
 
     # get options for default services for unknown customers
-    my $DefaultServiceUnknownCustomer
-        = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
+    my $DefaultServiceUnknownCustomer = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
     if (
         $DefaultServiceUnknownCustomer
         && $Param{DefaultServices}
@@ -942,10 +954,10 @@ sub CustomerUserServiceMemberList {
     # check cache
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
     if ( $Param{Result} eq 'HASH' ) {
-        return %{$Cache} if $Cache;
+        return %{$Cache} if ref $Cache eq 'HASH';
     }
     else {
-        return @{$Cache} if $Cache;
+        return @{$Cache} if ref $Cache eq 'ARRAY';
     }
 
     # db quote
@@ -1003,7 +1015,10 @@ sub CustomerUserServiceMemberList {
 
     # return result
     if ( $Param{Result} eq 'HASH' ) {
-        $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Data );
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => \%Data
+        );
         return %Data;
     }
     if ( $Param{Result} eq 'Name' ) {
@@ -1012,7 +1027,10 @@ sub CustomerUserServiceMemberList {
     else {
         @Data = keys %Data;
     }
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \@Data );
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \@Data
+    );
     return @Data;
 }
 
@@ -1045,7 +1063,7 @@ sub CustomerUserServiceMemberAdd {
 
     # delete existing relation
     return if !$Self->{DBObject}->Do(
-        SQL => 'DELETE FROM service_customer_user WHERE customer_user_login = ? AND service_id = ?',
+        SQL  => 'DELETE FROM service_customer_user WHERE customer_user_login = ? AND service_id = ?',
         Bind => [ \$Param{CustomerUserLogin}, \$Param{ServiceID} ],
     );
 
@@ -1140,7 +1158,7 @@ sub ServiceParentsGet {
     # read cache
     my $CacheKey = 'ServiceParentsGet::' . $Param{ServiceID};
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return %{$Cache} if $Cache;
+    return $Cache if ref $Cache;
 
     # get the list of services
     my $ServiceList = $Self->ServiceListGet(
@@ -1183,7 +1201,10 @@ sub ServiceParentsGet {
     my @Data = reverse @ServiceParents;
 
     # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \@Data );
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \@Data
+    );
 
     return \@Data;
 }
@@ -1201,9 +1222,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.60 $ $Date: 2012/11/20 15:38:02 $
-
-=cut
