@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Stats/Dynamic/Ticket.pm - all advice functions
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Ticket.pm,v 1.32.4.1 2012/02/28 09:55:07 jp Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,9 +17,9 @@ use Kernel::System::Service;
 use Kernel::System::SLA;
 use Kernel::System::Ticket;
 use Kernel::System::Type;
-
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.32.4.1 $) [1];
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -37,15 +35,23 @@ sub new {
     {
         $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
     }
-    $Self->{QueueObject}    = Kernel::System::Queue->new( %{$Self} );
-    $Self->{TicketObject}   = Kernel::System::Ticket->new( %{$Self} );
-    $Self->{StateObject}    = Kernel::System::State->new( %{$Self} );
-    $Self->{PriorityObject} = Kernel::System::Priority->new( %{$Self} );
-    $Self->{LockObject}     = Kernel::System::Lock->new( %{$Self} );
-    $Self->{CustomerUser}   = Kernel::System::CustomerUser->new( %{$Self} );
-    $Self->{ServiceObject}  = Kernel::System::Service->new( %{$Self} );
-    $Self->{SLAObject}      = Kernel::System::SLA->new( %{$Self} );
-    $Self->{TypeObject}     = Kernel::System::Type->new( %{$Self} );
+    $Self->{QueueObject}        = Kernel::System::Queue->new( %{$Self} );
+    $Self->{TicketObject}       = Kernel::System::Ticket->new( %{$Self} );
+    $Self->{StateObject}        = Kernel::System::State->new( %{$Self} );
+    $Self->{PriorityObject}     = Kernel::System::Priority->new( %{$Self} );
+    $Self->{LockObject}         = Kernel::System::Lock->new( %{$Self} );
+    $Self->{CustomerUser}       = Kernel::System::CustomerUser->new( %{$Self} );
+    $Self->{ServiceObject}      = Kernel::System::Service->new( %{$Self} );
+    $Self->{SLAObject}          = Kernel::System::SLA->new( %{$Self} );
+    $Self->{TypeObject}         = Kernel::System::Type->new( %{$Self} );
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+
+    # get the dynamic fields for ticket object
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid      => 1,
+        ObjectType => ['Ticket'],
+    );
 
     return $Self;
 }
@@ -449,72 +455,85 @@ sub GetObjectAttributes {
         push @ObjectAttributes, \%ObjectAttribute;
     }
 
-    FREEKEY:
-    for my $FreeKey ( 1 .. 16 ) {
+    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
 
-        # get ticket free key config
-        my $TicketFreeKey = $Self->{ConfigObject}->Get( 'TicketFreeKey' . $FreeKey );
-
-        next FREEKEY if ref $TicketFreeKey ne 'HASH';
-
-        my @FreeKey = keys %{$TicketFreeKey};
-        my $Name    = '';
-
-        if ( scalar @FreeKey == 1 ) {
-            $Name = $TicketFreeKey->{ $FreeKey[0] };
-        }
-        else {
-            $Name = 'TicketFreeText' . $FreeKey;
-
-            my %ObjectAttribute = (
-                Name             => 'TicketFreeKey' . $FreeKey,
-                UseAsXvalue      => 1,
-                UseAsValueSeries => 1,
-                UseAsRestriction => 1,
-                Element          => 'TicketFreeKey' . $FreeKey,
-                Block            => 'MultiSelectField',
-                Values           => $TicketFreeKey,
-                Translation      => 0,
-            );
-
-            push @ObjectAttributes, \%ObjectAttribute;
-        }
-
-        # get ticket free text
-        my $TicketFreeText = $Self->{TicketObject}->TicketFreeTextGet(
-            Type   => 'TicketFreeText' . $FreeKey,
-            Action => 'AgentStats',
-            FillUp => 1,
-            UserID => 1,
+        my %ObjectAttribute = (
+            Name             => 'Archive Search',
+            UseAsXvalue      => 0,
+            UseAsValueSeries => 0,
+            UseAsRestriction => 1,
+            Element          => 'SearchInArchive',
+            Block            => 'SelectField',
+            Translation      => 1,
+            Values           => {
+                ArchivedTickets    => 'Archived tickets',
+                NotArchivedTickets => 'Unarchived tickets',
+                AllTickets         => 'All tickets',
+            },
         );
 
-        if ($TicketFreeText) {
+        push @ObjectAttributes, \%ObjectAttribute;
+    }
 
-            my %ObjectAttribute = (
-                Name             => $Name,
-                UseAsXvalue      => 1,
-                UseAsValueSeries => 1,
-                UseAsRestriction => 1,
-                Element          => 'TicketFreeText' . $FreeKey,
-                Block            => 'MultiSelectField',
-                Values           => $TicketFreeText,
-                Translation      => 0,
-            );
+    # cycle trough the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
-            push @ObjectAttributes, \%ObjectAttribute;
+        my $PossibleValuesFilter;
+
+        # convert possible values key => value to key => key for ACLs usign a Hash slice
+        my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} || {} };
+        @AclData{ keys %AclData } = keys %AclData;
+
+        # set possible values filter from ACLs
+        my $ACL = $Self->{TicketObject}->TicketAcl(
+            Action        => 'AgentStats',
+            Type          => 'DynamicField_' . $DynamicFieldConfig->{Name},
+            ReturnType    => 'Ticket',
+            ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
+            Data          => \%AclData || {},
+            UserID        => 1,
+        );
+        if ($ACL) {
+            my %Filter = $Self->{TicketObject}->TicketAclData();
+
+            # convert Filer key => key back to key => value using map
+            %{$PossibleValuesFilter} = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} } keys %Filter;
         }
-        else {
 
-            my %ObjectAttribute = (
-                Name             => $Name,
-                UseAsXvalue      => 0,
-                UseAsValueSeries => 0,
-                UseAsRestriction => 1,
-                Element          => 'TicketFreeText' . $FreeKey,,
-                Block            => 'InputField',
-            );
+        # get field html
+        my $DynamicFieldStatsParameter = $Self->{BackendObject}->StatsFieldParameterBuild(
+            DynamicFieldConfig   => $DynamicFieldConfig,
+            PossibleValuesFilter => $PossibleValuesFilter,
+        );
 
-            push @ObjectAttributes, \%ObjectAttribute;
+        if ( IsHashRefWithData($DynamicFieldStatsParameter) ) {
+            if ( IsHashRefWithData( $DynamicFieldStatsParameter->{Values} ) ) {
+
+                my %ObjectAttribute = (
+                    Name             => $DynamicFieldStatsParameter->{Name},
+                    UseAsXvalue      => 1,
+                    UseAsValueSeries => 1,
+                    UseAsRestriction => 1,
+                    Element          => $DynamicFieldStatsParameter->{Element},
+                    Block            => 'MultiSelectField',
+                    Values           => $DynamicFieldStatsParameter->{Values},
+                    Translation      => 0,
+                );
+                push @ObjectAttributes, \%ObjectAttribute;
+            }
+            else {
+                my %ObjectAttribute = (
+                    Name             => $DynamicFieldStatsParameter->{Name},
+                    UseAsXvalue      => 0,
+                    UseAsValueSeries => 0,
+                    UseAsRestriction => 1,
+                    Element          => $DynamicFieldStatsParameter->{Element},
+                    Block            => 'InputField',
+                );
+                push @ObjectAttributes, \%ObjectAttribute;
+            }
         }
     }
 
@@ -528,41 +547,58 @@ sub GetStatElement {
     # escape search attributes for ticket search
     #
     my %AttributesToEscape = (
-        'CustomerID'       => 1,
-        'Title'            => 1,
-        'TicketFreeText1'  => 1,
-        'TicketFreeText2'  => 1,
-        'TicketFreeText3'  => 1,
-        'TicketFreeText4'  => 1,
-        'TicketFreeText5'  => 1,
-        'TicketFreeText6'  => 1,
-        'TicketFreeText7'  => 1,
-        'TicketFreeText8'  => 1,
-        'TicketFreeText9'  => 1,
-        'TicketFreeText10' => 1,
-        'TicketFreeText11' => 1,
-        'TicketFreeText12' => 1,
-        'TicketFreeText13' => 1,
-        'TicketFreeText14' => 1,
-        'TicketFreeText15' => 1,
-        'TicketFreeText16' => 1,
+        'CustomerID' => 1,
+        'Title'      => 1,
     );
 
-    ATTRIBUTE:
-    for my $Key ( keys %Param ) {
+    for my $ParameterName ( sort keys %Param ) {
+        if ( $ParameterName =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
 
-        next ATTRIBUTE if !$AttributesToEscape{$Key};
+            # loop over the dynamic fields configured
+            DYNAMICFIELD:
+            for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+                next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+                next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
-        if ( ref $Param{$Key} ) {
-            if ( ref $Param{$Key} eq 'ARRAY' ) {
-                $Param{$Key} = [
-                    map { $Self->{DBObject}->QueryStringEscape( QueryString => $_ ) }
-                        @{ $Param{$Key} }
-                ];
+                # skip all fields that does not match with current field name ($1)
+                # without the 'DynamicField_' prefix
+                next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
+
+                # get new search parameter
+                my $DynamicFieldStatsSearchParameter = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
+                    DynamicFieldConfig => $DynamicFieldConfig,
+                    Value              => $Param{$ParameterName},
+                );
+
+                # add new search parameter
+                $Param{$ParameterName} = $DynamicFieldStatsSearchParameter;
             }
         }
+        elsif ( $AttributesToEscape{$ParameterName} ) {
+            if ( ref $Param{$ParameterName} ) {
+                if ( ref $Param{$ParameterName} eq 'ARRAY' ) {
+                    $Param{$ParameterName} = [
+                        map { $Self->{DBObject}->QueryStringEscape( QueryString => $_ ) }
+                            @{ $Param{$ParameterName} }
+                    ];
+                }
+            }
+            else {
+                $Param{$ParameterName} = $Self->{DBObject}->QueryStringEscape( QueryString => $Param{$ParameterName} );
+            }
+        }
+    }
+
+    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+        $Param{SearchInArchive} ||= '';
+        if ( $Param{SearchInArchive} eq 'AllTickets' ) {
+            $Param{ArchiveFlags} = [ 'y', 'n' ];
+        }
+        elsif ( $Param{SearchInArchive} eq 'ArchivedTickets' ) {
+            $Param{ArchiveFlags} = ['y'];
+        }
         else {
-            $Param{$Key} = $Self->{DBObject}->QueryStringEscape( QueryString => $Param{$Key} );
+            $Param{ArchiveFlags} = ['n'];
         }
     }
 
@@ -611,7 +647,7 @@ sub ExportWrapper {
                 }
             }
             elsif (
-                $ElementName    eq 'OwnerIDs'
+                $ElementName eq 'OwnerIDs'
                 || $ElementName eq 'CreatedUserIDs'
                 || $ElementName eq 'ResponsibleIDs'
                 )
@@ -645,8 +681,7 @@ sub ImportWrapper {
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
                     if ( $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} ) ) {
-                        $ID->{Content}
-                            = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
+                        $ID->{Content} = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
                     }
                     else {
                         $Self->{LogObject}->Log(
@@ -681,7 +716,7 @@ sub ImportWrapper {
             elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
                 my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
                 my %PriorityIDs;
-                for my $Key ( keys %PriorityList ) {
+                for my $Key ( sort keys %PriorityList ) {
                     $PriorityIDs{ $PriorityList{$Key} } = $Key;
                 }
                 ID:
@@ -701,7 +736,7 @@ sub ImportWrapper {
                 }
             }
             elsif (
-                $ElementName    eq 'OwnerIDs'
+                $ElementName eq 'OwnerIDs'
                 || $ElementName eq 'CreatedUserIDs'
                 || $ElementName eq 'ResponsibleIDs'
                 )
