@@ -18,7 +18,10 @@ sub ArticleIndexBuild {
     # check needed stuff
     for my $Needed (qw(ArticleID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -80,7 +83,10 @@ sub ArticleIndexDelete {
     # check needed stuff
     for my $Needed (qw(ArticleID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -100,7 +106,10 @@ sub ArticleIndexDeleteTicket {
     # check needed stuff
     for my $Needed (qw(TicketID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -118,7 +127,10 @@ sub _ArticleIndexQuerySQL {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Data} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need Data!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need Data!"
+        );
         return;
     }
 
@@ -143,7 +155,10 @@ sub _ArticleIndexQuerySQLExt {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Data} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need Data!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need Data!"
+        );
         return;
     }
 
@@ -173,10 +188,11 @@ sub _ArticleIndexQuerySQLExt {
         if ( $Param{Data}->{ConditionInline} ) {
             $FullTextSQL .= $Self->{DBObject}->QueryCondition(
                 Key          => $FieldSQLMapFullText{$Key},
-                Value        => $Param{Data}->{$Key},
+                Value        => lc $Param{Data}->{$Key},
                 SearchPrefix => $Param{Data}->{ContentSearchPrefix},
                 SearchSuffix => $Param{Data}->{ContentSearchSuffix},
                 Extended     => 1,
+                CaseSensitive => 1,    # data in article_search are already stored in lower cases
             );
         }
         else {
@@ -215,7 +231,10 @@ sub _ArticleIndexString {
     my ( $Self, %Param ) = @_;
 
     if ( !defined $Param{String} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need String!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need String!"
+        );
         return;
     }
 
@@ -261,7 +280,10 @@ sub _ArticleIndexStringToWord {
 
     # check needed stuff
     if ( !defined $Param{String} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need String!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need String!"
+        );
         return;
     }
 
