@@ -1,8 +1,6 @@
 # --
 # Kernel/System/VariableCheck.pm - helpers to check variables
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: VariableCheck.pm,v 1.6 2011-11-08 09:43:04 mg Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,11 +12,10 @@ package Kernel::System::VariableCheck;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION @EXPORT_OK %EXPORT_TAGS);
-$VERSION = qw($Revision: 1.6 $) [1];
+use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
 
 use Exporter;
-%EXPORT_TAGS = (
+%EXPORT_TAGS = (    ## no critic
     all => [
         'IsArrayRefWithData',
         'IsHashRefWithData',
@@ -51,7 +48,7 @@ input data validation, for example.
 Call this module directly without instantiating:
 
     use Kernel::System::VariableCheck qw(:all);             # export all functions into the calling package
-    use Kernel::System::VariableCheck qw(IsHashRefWitData); # export just one funciton
+    use Kernel::System::VariableCheck qw(IsHashRefWitData); # export just one function
 
     if (IsHashRefWithData($HashRef)) {
         ...
@@ -148,7 +145,7 @@ sub IsStringWithData {
 
 =item IsArrayRefWithData()
 
-test supplied data to deterine if it is an array reference and contains at least one key
+test supplied data to determine if it is an array reference and contains at least one key
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -164,7 +161,7 @@ returns 1 if data matches criteria or undef otherwise
 sub IsArrayRefWithData {
     my $TestData = $_[0];
 
-    return if scalar @_     ne 1;
+    return if scalar @_ ne 1;
     return if ref $TestData ne 'ARRAY';
     return if !@{$TestData};
 
@@ -173,7 +170,7 @@ sub IsArrayRefWithData {
 
 =item IsHashRefWithData()
 
-test supplied data to deterine if it is a hash reference and contains at least one key/value pair
+test supplied data to determine if it is a hash reference and contains at least one key/value pair
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -189,7 +186,7 @@ returns 1 if data matches criteria or undef otherwise
 sub IsHashRefWithData {
     my $TestData = $_[0];
 
-    return if scalar @_     ne 1;
+    return if scalar @_ ne 1;
     return if ref $TestData ne 'HASH';
     return if !%{$TestData};
 
@@ -287,7 +284,7 @@ sub IsIPv4Address {
 
         # allow numbers 0 to 255, no leading zeroes
         return if $Part !~ m{
-            \A (?: \d | [1-9] \d | [1] \d\{2\} | [2][0-4]\d | [2][5][0-5] ) \z
+            \A (?: \d | [1-9] \d | [1] \d{2} | [2][0-4]\d | [2][5][0-5] ) \z
         }xms;
     }
 
@@ -473,7 +470,10 @@ sub DataIsDifferent {
 
             if ( $A[$Count] ne $B[$Count] ) {
                 if ( ref $A[$Count] eq 'ARRAY' || ref $A[$Count] eq 'HASH' ) {
-                    return 1 if DataIsDifferent( Data1 => $A[$Count], Data2 => $B[$Count] );
+                    return 1 if DataIsDifferent(
+                        Data1 => $A[$Count],
+                        Data2 => $B[$Count]
+                    );
                     next;
                 }
                 return 1;
@@ -488,7 +488,7 @@ sub DataIsDifferent {
         my %B = %{ $Param{Data2} };
 
         # compare %A with %B and remove it if checked
-        for my $Key ( keys %A ) {
+        for my $Key ( sort keys %A ) {
 
             # Check if both are undefined
             if ( !defined $A{$Key} && !defined $B{$Key} ) {
@@ -508,7 +508,10 @@ sub DataIsDifferent {
 
             # return if values are different
             if ( ref $A{$Key} eq 'ARRAY' || ref $A{$Key} eq 'HASH' ) {
-                return 1 if DataIsDifferent( Data1 => $A{$Key}, Data2 => $B{$Key} );
+                return 1 if DataIsDifferent(
+                    Data1 => $A{$Key},
+                    Data2 => $B{$Key}
+                );
                 delete $A{$Key};
                 delete $B{$Key};
                 next;
@@ -522,7 +525,10 @@ sub DataIsDifferent {
     }
 
     if ( ref $Param{Data1} eq 'REF' && ref $Param{Data2} eq 'REF' ) {
-        return 1 if DataIsDifferent( Data1 => ${ $Param{Data1} }, Data2 => ${ $Param{Data2} } );
+        return 1 if DataIsDifferent(
+            Data1 => ${ $Param{Data1} },
+            Data2 => ${ $Param{Data2} }
+        );
         return;
     }
 
@@ -542,9 +548,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.6 $ $Date: 2011-11-08 09:43:04 $
-
-=cut
