@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Web/UploadCache/DB.pm - a db upload cache
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: DB.pm,v 1.26 2012/11/20 16:02:21 mh Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +14,6 @@ use warnings;
 
 use MIME::Base64;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.26 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -49,7 +44,10 @@ sub FormIDRemove {
 
     for (qw(FormID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -65,7 +63,10 @@ sub FormIDAddFile {
 
     for (qw(FormID Filename Content ContentType)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -108,7 +109,10 @@ sub FormIDRemoveFile {
 
     for (qw(FormID FileID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -117,7 +121,7 @@ sub FormIDRemoveFile {
     $Param{Filename} = $Index[$ID]->{Filename};
 
     return if !$Self->{DBObject}->Do(
-        SQL => 'DELETE FROM web_upload_cache WHERE form_id = ? AND filename = ?',
+        SQL  => 'DELETE FROM web_upload_cache WHERE form_id = ? AND filename = ?',
         Bind => [ \$Param{FormID}, \$Param{Filename} ],
     );
     return 1;
@@ -130,7 +134,10 @@ sub FormIDGetAllFilesData {
     my @Data;
     for (qw(FormID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -138,7 +145,7 @@ sub FormIDGetAllFilesData {
         SQL => 'SELECT filename, content_type, content_size, content, content_id'
             . ' FROM web_upload_cache '
             . ' WHERE form_id = ? ORDER BY create_time_unix',
-        Bind => [ \$Param{FormID} ],
+        Bind   => [ \$Param{FormID} ],
         Encode => [ 1, 1, 1, 0, 1 ],
     );
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
@@ -185,7 +192,10 @@ sub FormIDGetAllFilesMeta {
     my @Data;
     for (qw(FormID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
