@@ -1,9 +1,7 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 # --
 # bin/otrs.AddUser2Group.pl - Add User to a Group
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: otrs.AddUser2Group.pl,v 1.4 2011-11-03 21:00:04 mb Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -17,7 +15,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -27,6 +25,8 @@ use warnings;
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
+use lib dirname($RealBin) . '/Kernel/cpan-lib';
+use lib dirname($RealBin) . '/Custom';
 
 use Kernel::Config;
 use Kernel::System::Encode;
@@ -37,18 +37,7 @@ use Kernel::System::Main;
 use Kernel::System::User;
 use Kernel::System::Group;
 
-my %Param;
 my %CommonObject;
-my %Opts;
-
-use Getopt::Std;
-getopt( 'guph', \%Opts );
-
-if ( $Opts{h} || !$Opts{g} || !$Opts{u} || !$Opts{p} ) {
-    print STDERR
-        "Usage: $0 -g groupname -u username -p ro|rw\n";
-    exit;
-}
 
 # create common objects
 $CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
@@ -63,6 +52,18 @@ $CommonObject{DBObject}    = Kernel::System::DB->new(%CommonObject);
 $CommonObject{UserObject}  = Kernel::System::User->new(%CommonObject);
 $CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
 
+my %Param;
+my %Opts;
+
+use Getopt::Std;
+getopt( 'guph', \%Opts );
+
+if ( $Opts{h} || !$Opts{g} || !$Opts{u} || !$Opts{p} ) {
+    print STDERR
+        "Usage: $0 -g groupname -u username -p ro|rw\n";
+    exit;
+}
+
 # user id
 $Param{UserID} = '1';
 
@@ -74,8 +75,7 @@ $Param{UserLogin}                = $Opts{u};
 $Param{Group}                    = $Opts{g};
 
 unless (
-    $Param{UID}
-    =
+    $Param{UID} =
     $CommonObject{UserObject}->UserLookup( UserLogin => $Param{UserLogin} )
     )
 {
