@@ -1,9 +1,7 @@
 #!/usr/bin/perl
 # --
 # bin/otrs.CreateTranslationFile.pl - create new translation file
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: otrs.CreateTranslationFile.pl,v 1.39 2013/01/22 10:14:09 mg Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -30,9 +28,6 @@ use lib dirname($RealBin);
 use lib dirname($RealBin) . '/Kernel/cpan-lib';
 use lib dirname($RealBin) . '/Custom';
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.39 $) [1];
-
 use Getopt::Std qw();
 
 use Kernel::Config;
@@ -47,7 +42,7 @@ use Kernel::System::SysConfig;
 sub PrintUsage {
     print <<"EOF";
 
-otrs.CreateTranslationFile.pl <Revision $VERSION> - update translation files
+otrs.CreateTranslationFile.pl - update translation files
 Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 
 Translating OTRS
@@ -137,13 +132,23 @@ my $BreakLineAfterChars = 60;
         );
     }
 
-    print "\n\nTranslation statistics:\n";
+    my %Summary;
     for my $Language ( sort keys %Stats ) {
-        my $Strings = scalar keys %{ $Stats{$Language} };
-        my $Translations = scalar grep {$_} values %{ $Stats{$Language} };
+        $Summary{$Language}->{Translated} = scalar grep {$_} values %{ $Stats{$Language} };
+        $Summary{$Language}->{Total} = scalar values %{ $Stats{$Language} };
+    }
+
+    print "\n\nTranslation statistics:\n";
+    for my $Language (
+        sort { $Summary{$b}->{Translated} <=> $Summary{$a}->{Translated} }
+        keys %Stats
+        )
+    {
+        my $Strings      = $Summary{$Language}->{Total};
+        my $Translations = $Summary{$Language}->{Translated};
         print "\t" . sprintf( "%7s", $Language ) . ": ";
         print sprintf( "%02d", int( ( $Translations / $Strings ) * 100 ) );
-        print "% ($Translations/$Strings)\n";
+        print sprintf( "%% (%4d/%4d)\n", $Translations, $Strings );
 
     }
 
@@ -222,8 +227,7 @@ sub HandleLanguage {
     my $Data = '';
     my %UsedWords;
     my %UsedWordsMisc;
-    my $Directory
-        = $IsSubTranslation
+    my $Directory = $IsSubTranslation
         ? "$ModuleDirectory/Kernel/Output/HTML/$DefaultTheme"
         : "$Home/Kernel/Output/HTML/$DefaultTheme";
 
@@ -235,7 +239,7 @@ sub HandleLanguage {
     print "\nReading template files:\n";
 
     for my $File (@List) {
-        if ( open my $In, '<', $File ) {
+        if ( open my $In, '<', $File ) {    ## no critic
             my $Content = '';
             while ( my $Line = <$In> ) {
                 if ( $Line !~ /^#/ ) {
@@ -362,8 +366,7 @@ sub HandleLanguage {
         $UsedWordsMisc{$String} = 1;
 
         # lookup for existing translation
-        $UsedWords{$String}
-            = ( $IsSubTranslation ? $LanguageObject : $LanguageCoreObject )->{Translation}
+        $UsedWords{$String} = ( $IsSubTranslation ? $LanguageObject : $LanguageCoreObject )->{Translation}
             ->{$String};
 
         my $Translation = $UsedWords{$String} || '';
@@ -412,7 +415,7 @@ sub HandleLanguage {
 
             my $Translation = $LanguageObject->{Translation}->{$Key};
             $Translation =~ s/'/\\'/g;
-            $Key         =~ s/'/\\'/g;
+            $Key =~ s/'/\\'/g;
 
             # if a string was previously in a DTL, but has not yet been translated,
             # there's no need to preserve it in the translation file.
@@ -456,9 +459,7 @@ sub HandleLanguage {
         $NewOut = <<"EOF";
 $Separator
 # Kernel/Language/${Language}_$Module.pm - translation file
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-$Separator
-# \$Id\$
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 $Separator
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -480,7 +481,7 @@ EOF
 
     # translating the core
     else {
-        open( my $In, '<', $LanguageFile ) || die "Can't open: $LanguageFile\n";
+        open( my $In, '<', $LanguageFile ) || die "Can't open: $LanguageFile\n";    ## no critic
         while (<$In>) {
             if ( !$MetaData{DataPrinted} ) {
                 $NewOut .= $_;
@@ -488,10 +489,9 @@ EOF
             if ( $_ =~ /\$\$START\$\$/ && !$MetaData{DataPrinted} ) {
                 $MetaData{DataPrinted} = 1;
 
-                my ( $Sec, $Min, $Hour, $Day, $Month, $Year )
-                    = $CommonObject{TimeObject}->SystemTime2Date(
+                my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $CommonObject{TimeObject}->SystemTime2Date(
                     SystemTime => $CommonObject{TimeObject}->SystemTime(),
-                    );
+                );
 
                 $NewOut .= <<"EOF";
     # Last translation file sync: $Year-$Month-$Day $Hour:$Min:$Sec
@@ -543,7 +543,7 @@ EOF
     }
 
     print "Writing $TargetFile\n";
-    open( my $Out, '>', $TargetFile ) || die $!;
+    open( my $Out, '>', $TargetFile ) || die $!;    ## no critic
     print $Out $NewOut;
     close $Out;
 }
